<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version
 * @author Marcelo Mottalli	marcelo@gforgegroup.com
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

/**
 * Cronjob that updates the trove_link_count table
 */
require_once('system/Cronjob.php');
require_once('lib/core/DiskUsage.php');

class CalcDiskUsageCronjob extends Cronjob {
	public function __construct() {
		$this->jobname = basename(__FILE__);
		parent::__construct();
	}
	
	public function run() {
		$con = Propel::getConnection(DiskUsagePeer::DATABASE_NAME);
		$stmt = $con->createStatement();

		$disk_data = array();
		$plugins = ActionManager::notify('GET_DISK_USAGE', array());
		
		$sqls = array();
		foreach ($plugins as $plugin) {
			$sql = $plugin->getResult();
			$sqls[] = $sql;
		}

		// Kind of hackish -- get the usage status for the files uploaded
		// with FCKEditor. We have to do it here because we don't have any
		// plugin for this.
		$sqls[] = "SELECT ref_id AS project_id, SUM(file_size) AS usage FROM filesystem
				WHERE section='htmleditor' AND ref_id <> 0
				GROUP BY ref_id";
		
		foreach ($sqls as $sql) {
			$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
			if ($rs->getRecordCount() > 0) {
				while ($rs->next()) {
					$project_id = $rs->getInt('project_id');
					$usage = $rs->getFloat('usage');
					if (!isset($disk_data[$project_id])) {
						$disk_data[$project_id] = 0;
					}
					$disk_data[$project_id] += $usage;
				}
			}
		}
		
		
		// Delete today's data if it already exists
		$stmt->executeQuery("DELETE FROM disk_usage WHERE check_date=CURRENT_DATE");
		foreach ($disk_data as $project_id => $usage) {
			$DiskUsage = new DiskUsage();
			$DiskUsage->setProjectId($project_id);
			$DiskUsage->setCheckDate(null);
			$DiskUsage->setBytesUsed($usage);	
			$DiskUsage->save();
		}
	}
}

$cronjob = new CalcDiskUsageCronjob();
$cronjob->run();
?>
