<?php
require_once('initialize.php');

class DatabaseUpdater {
	private $con;
	private $path;
	
	function __construct() {
		$this->con = Propel::getConnection();
		$this->path = dirname(__FILE__).'/updates/';
	}

	public function run() {
		$scripts = $this->getScripts();
		$date = $this->getStartPoint();
		$this->runScripts($scripts, $date);
	}
	
	private function getStartPoint() {
		$date = 0;
		$stmt = $this->con->createStatement();
		$sql = 'SELECT MAX(filedate) As maxdate FROM database_changes ORDER BY maxdate DESC';
		try {
			$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
			if ($rs->getRecordCount() > 0) {
				$rs->next();
				$date = $rs->getInt('maxdate');
			} else {
				$date = ((int) '20060612');
			}
		} catch (Exception $e) {
			$rs = $stmt->executeQuery('create table database_changes (filename text, filedate text)');
			$rs = $stmt->executeQuery('insert into database_changes (filename, filedate) values (\'20060612.sql\',\'20060612\')');
			$this->show('ERROR: ' . $e->getMessage());
			exit();
		}
		return $date;
	}

	private function getScripts() {
		$data = array();
		$this->show('Reading directory: ' . $this->path);

		if (is_dir($this->path) && ($dirhnd = opendir($this->path))) {
			while (($file = readdir($dirhnd)) !== false) {
				$pos = strrpos($file, '.');
				if ($pos !== false && $pos > 0) {
					$name = substr($file, 0, $pos);
					if (strlen($name) >= 8) {
						$date = (int) substr($name, 0, 8);
						$type = strtolower(substr($file, $pos + 1));
						if ($date > 20000000 && ($type == 'sql' || $type == 'php')) {
							$data[] = array('date'=>$date, 'filename'=>$file, 'ext'=>$type);
						}
					}
				}
			}
			closedir($dirhnd);
			sort($data);
			reset($data);
		}
		return $data;
	}

	private function runScripts($scripts, $date) {
		$stmt = $this->con->createStatement();

		foreach ($scripts as $script) {
			if ($script['date'] > $date) {
				$sql = "SELECT * FROM database_changes WHERE filename='".pg_escape_string($script['filename'])."'";
				try {
					$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
					if ($rs->getRecordCount() == 0) {
						if ($script['ext'] == 'php') {
							$this->show("Running PHP script: {$script['filename']}");
							$result = $this->runPHPScript($script);
						} else if ($script['ext'] == 'sql') {
							$this->show("Running SQL script: {$script['filename']}");
							$result = $this->runSQLScript($script);
						} else {
							$result = false;
							$this->show("\nThe script {$script['filename']} is not a PHP file nor an SQL file. Something went wrong. Please report this bug");
							exit();
						}
	
						if ($result) {
							$sql = "INSERT INTO database_changes (filename, filedate) ";
							$sql .="VALUES ('".pg_escape_string($script['filename'])."', '{$script['date']}')";
							try {
								$rs = $stmt->executeQuery($sql);
							} catch (Exception $e) {
								$this->show('ERROR: could insert data into database_changes');
								$this->show($e->getMessage());
								exit();
							}
						} else {
							exit();
						}
					} else {	
						$this->show("Skipping script: {$script['filename']}");
					}
				} catch (Exception $e) {
					$this->show('ERROR: ' . $e->getMessage());
					exit();
				}
			}
		}
	}
	
	private function runPHPScript($script) {
		$return = false;
		$filename = $script['filename'];
		$result = array();
		$exec = 'php -f '.$this->path.$filename;

		// run the php script
		exec($exec, $result);
		if (count($result)) { // the script produced an output
			$failed = strtolower($result[count($result)-1]);
			if ($this->inString($failed,'failed')) {
				$this->show($this->path.$filename." FAILED!\n");
				foreach ($result as $line) {
					$this->show($line);
				}
			} else {
				$this->show($this->path.$filename." ran correctly\n");
				$return = true;
			}
		}
		return $return;
	}

	private function runSQLScript($script) {
		$filename = $script['filename'];
		$sql_file = $this->path.$filename;
		$file = @fopen($sql_file, 'rb');
		if (!$file) {
			return false;
		}
		$content = fread($file, filesize($sql_file));
		fclose($file);
		
		$content = preg_replace("/--(.*)/", '', $content);
		
		$parts = explode(';', $content);
		$queries = array();
		$query_temp = '';
		$is_function = false;
		$is_copy_stdin = false;
		
		for ($i=0;$i<count($parts);$i++) {
			$q = $parts[$i];
			// Check if it's a function
			if (($this->inString($q, 'create function') || $this->inString($q, 'create or replace function') ||
				$this->inString($q, 'replace function')) && !$this->inString($q, 'language plpgsql') &&
				!$this->inString($q, 'language \'plpgsql\'') && !$this->inString($q, 'language \'c\'') &&
				!$this->inString($q, 'language c')) {
	
				while (!$this->inString($q, 'language plpgsql') && !$this->inString($q, 'language \'plpgsql\'')) {
					$i++;
					$q = $q.';'.$parts[$i];
				}
				$queries[] = trim($q);
			// Check if it is a COPY FROM stdin
			} else if ($this->inString($q, 'copy') && $this->inString($q, 'from stdin')) {
				while (!$this->inString($q, '\.')) {
					$i++;
					$q = $q.';'.$parts[$i];
				}
				$aux = explode('\.', $q, 2);
				$queries[] = ltrim($aux[0]."\\.\n");
				if (trim($aux[1]) != '') {
					$queries[] = trim($aux[1]);
				}
			// Else, we just add it up
			} else {
				if (trim($q) != '') {
					$queries[] = trim($q);
				}
			}
		}
	
		$i = 0;
		foreach ($queries as $query) {
			// Check if it is a DROP TABLE
			if ($this->inString($query, 'drop table')) {
				$aux = explode(' ', trim($query));
				if (count($aux) == 3 || count($aux) == 4) { // PERFECT!
					if (isset($aux[3]) && strtolower(trim($aux[3])) == 'cascade' ) {
						$this->dropCascadeTableIfExists($aux[2]);
					} else {
						$this->dropTableIfExists($aux[2]);
					}
					continue;
				}
			// Check if it is a DROP SEQUENCE
			} else if ($this->inString($query, 'drop sequence')) {
				$aux = explode(' ', trim($query));
				if (count($aux) == 3) { // PERFECT!
					$this->dropSeqIfExists($aux[2]);
					continue;
				}
			// Check if it is a DROP TRIGGER
			} else if ($this->inString($query, 'drop trigger')) {
				$aux = explode(' ', trim($query));
				if (count($aux) == 5 || count($aux) == 6) { // PERFECT!
					$this->dropTriggerIfExists($aux[2], $aux[4]);
					continue;
				}
			// Check if it is a DROP VIEW
			} else if ($this->inString($query, 'drop view')) {
				$aux = explode(' ', trim($query));
				if (count($aux) == 3 || count($aux) == 4) { // PERFECT!
					$this->dropViewIfExists($aux[2]);
					continue;
				}
			}
			
			$stmt = $this->con->createStatement();
			try {
				$rs = $stmt->executeQuery($query, ResultSet::FETCHMODE_ASSOC);
			} catch (Exception $e) {
				$this->show('ERROR: ' . $e->getMessage());
				$this->show("\nContinue executing ([Y]es/[N]o)?");
				// Read the input
				$answer = strtolower(trim(fgets(STDIN)));
				if ($answer != 'y' && $answer != 'yes') {
					return false;
				}
			}
		}
		return true;
	}

	private function dropViewIfExists($name) {
		return $this->dropIfExists($name, 'DROP VIEW', 'v');
	}
	
	private function dropSeqIfExists($name) {
		return $this->dropIfExists($name, 'DROP SEQUENCE', 'S');
	}
	
	private function dropTableIfExists($name) {
		return $this->dropIfExists($name, 'DROP TABLE', 'r');
	}

	private function dropIfExists($name, $command, $kind) {
		$stmt = $this->con->createStatement();
		$sql = "SELECT * FROM pg_class WHERE relname='$name' AND relkind='$kind'";
		try {
			$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
			if ($rs->getRecordCount() > 0) {
				$sql = "$command $name";
				try {
					$rs = $stmt->executeQuery($sql);
				} catch (Exception $e) {
					$this->show("ERROR: " . $e->getMessage());
				}
			}
		} catch (Exception $e) {
			$this->show("ERROR: Could not check if $kind $name exists.");
			$this->show($e->getMessage());
			return false;
		}
		return true;
	}

	private function dropCascadeTableIfExists($name) {
		return $this->dropCascadeIfExists($name, 'DROP TABLE', 'r');
	}
	
	private function dropCascadeIfExists($name, $command, $kind) {
		$stmt = $this->con->createStatement();
		$sql = "SELECT * FROM pg_class WHERE relname='$name' AND relkind='$kind'";
		try {
			$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
			if ($rs->getRecordCount() > 0) {
				$sql = "$command $name CASCADE";
				try {
					$rs = $stmt->executeQuery($sql);
				} catch (Exception $e) {
					$this->show("ERROR: " . $e->getMessage());
				}
			}
		} catch (Exception $e) {
			$this->show("ERROR: Could not check if $kind $name exists.");
			$this->show($e->getMessage());
			return false;
		}
		return true;
	}

	
	private function dropTriggerIfExists($name, $on) {
		$stmt = $this->con->createStatement();
		$sql = "SELECT * FROM pg_trigger WHERE tgname='$name'";
		try {
			$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
			if ($rs->getRecordCount() > 0) {
				$sql = "DROP TRIGGER $name ON $on";
				try {
					$rs = $stmt->executeQuery($sql);
				} catch (Exception $e) {
					$this->show("ERROR: " . $e->getMessage());
				}
			}
		} catch (Exception $e) {
			$this->show("ERROR: Could not check if $kind $name exists.");
			$this->show($e->getMessage());
			return false;
		}
		return true;
	}

	private function inString($haystack, $needle, $case_sensitive = false) {
		if (!$case_sensitive) {
			$result = stripos($haystack, $needle);
		} else {
			$result = strpos($haystack, $needle);
		}
	
		if ($result !== false) {
			return true;
		} else {
			return false;
		}
	}
	
	private function show($text, $newLine = true) {
		if ($newLine) {
			$text = $text . "\n";
		}
		fwrite(STDOUT, $text);
	}
}

$dbUpdater = new DatabaseUpdater();
$dbUpdater->run();

?>
