--
-- PostgreSQL database dump
--

SET client_encoding = 'UNICODE';
SET check_function_bodies = false;

SET search_path = public, pg_catalog;

--
-- TOC entry 278 (OID 94758)
-- Name: plpgsql_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


--
-- TOC entry 277 (OID 94759)
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;


--
-- TOC entry 7 (OID 94760)
-- Name: deleted_project; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE deleted_project (
    unix_group_name character varying(30) NOT NULL,
    delete_date timestamp with time zone DEFAULT now(),
    isdeleted boolean DEFAULT false
);


--
-- TOC entry 8 (OID 94766)
-- Name: project; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE project (
    project_id serial NOT NULL,
    project_name character varying(40),
    unix_name character varying(30) NOT NULL,
    homepage_url text,
    is_public boolean DEFAULT true,
    status integer DEFAULT 0,
    description text,
    register_purpose text,
    register_license_other text,
    create_date timestamp with time zone DEFAULT now(),
    template_project_id integer,
    is_template boolean DEFAULT false
);


--
-- TOC entry 9 (OID 94776)
-- Name: country_code; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE country_code (
    country_name character varying(80),
    ccode character(2) NOT NULL
);


--
-- TOC entry 10 (OID 94780)
-- Name: theme; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE theme (
    theme_id serial NOT NULL,
    dirname text NOT NULL,
    fullname text NOT NULL
);


--
-- TOC entry 11 (OID 94788)
-- Name: language; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE "language" (
    language_id serial NOT NULL,
    name text NOT NULL,
    filename text NOT NULL,
    language_code character(5)
);


--
-- TOC entry 12 (OID 94796)
-- Name: user; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE "user" (
    user_id serial NOT NULL,
    unix_name text NOT NULL,
    email text NOT NULL,
    status integer DEFAULT 0,
    password_md5 character varying(32) NOT NULL,
    password_crypt character varying(40) NOT NULL,
    create_date timestamp with time zone DEFAULT now() NOT NULL,
    confirm_hash character varying(32),
    email_new text,
    timezone text,
    date_format text,
    address text,
    address2 text,
    phone text,
    fax text,
    title text,
    firstname text,
    lastname text,
    ccode character(2) NOT NULL,
    language_id integer NOT NULL,
    theme_id integer NOT NULL,
    external_id text,
    last_login timestamp with time zone DEFAULT now()
);


--
-- TOC entry 13 (OID 94805)
-- Name: site_admin; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE site_admin (
    user_id integer NOT NULL
);


--
-- TOC entry 14 (OID 94809)
-- Name: filesystem; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE filesystem (
    filesystem_id serial NOT NULL,
    section character varying(20),
    ref_id integer,
    file_name text,
    file_name_safe text,
    file_type text,
    file_size integer,
    deleted boolean DEFAULT false,
    posted_by integer NOT NULL,
    download_count integer DEFAULT 0,
    strings text
);


--
-- TOC entry 15 (OID 94817)
-- Name: stats_project_page_view; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE stats_project_page_view (
    project_id integer NOT NULL,
    count_date date NOT NULL,
    count_views integer NOT NULL
);


--
-- TOC entry 16 (OID 94819)
-- Name: stats_site_page_view; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE stats_site_page_view (
    count_date date NOT NULL,
    count_views integer NOT NULL
);


--
-- TOC entry 17 (OID 94821)
-- Name: monitor; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE monitor (
    section character varying(20) NOT NULL,
    ref_id integer DEFAULT 0 NOT NULL,
    user_id integer NOT NULL
);


--
-- TOC entry 18 (OID 94826)
-- Name: audit_trail; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE audit_trail (
    audit_trail_id serial NOT NULL,
    change_date timestamp with time zone DEFAULT now(),
    user_id integer NOT NULL,
    section character varying(20),
    ref_id integer DEFAULT 0,
    field_name character varying(20),
    new_value text,
    old_value text
);


--
-- TOC entry 19 (OID 94836)
-- Name: unix_shell; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE unix_shell (
    unix_shell_id serial NOT NULL,
    shell_name text,
    "path" text
);


--
-- TOC entry 20 (OID 94842)
-- Name: user_unix; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_unix (
    user_id integer NOT NULL,
    unix_shell_id integer NOT NULL,
    unix_uid integer DEFAULT 0 NOT NULL,
    unix_gid integer DEFAULT 0,
    unix_box character varying(10) DEFAULT 'shell1'::character varying NOT NULL,
    authorized_keys text
);


--
-- TOC entry 21 (OID 94852)
-- Name: scm_server; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_server (
    scm_server_id serial NOT NULL,
    scm_type text,
    hostname text
);


--
-- TOC entry 22 (OID 94860)
-- Name: docman_folder; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE docman_folder (
    docman_folder_id serial NOT NULL,
    project_id integer NOT NULL,
    folder_name text,
    is_public boolean DEFAULT true,
    parent_folder_id integer DEFAULT 0,
    doc_count integer DEFAULT 0
);


--
-- TOC entry 23 (OID 94869)
-- Name: project_scm; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE project_scm (
    project_id integer NOT NULL,
    enable_anonread boolean DEFAULT true,
    scm_server_id integer NOT NULL,
    controlled boolean DEFAULT true,
    hostname text,
    root_directory text,
    external_browse_url text,
    browse_text text,
    access_text text
);


--
-- TOC entry 24 (OID 94878)
-- Name: forum; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE forum (
    forum_id serial NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    forum_name text NOT NULL,
    is_public boolean DEFAULT true,
    description text,
    send_all_posts_to text,
    thread_count integer DEFAULT 0,
    message_count integer DEFAULT 0,
    most_recent_date timestamp with time zone DEFAULT now(),
    moderation_level integer DEFAULT 0
);


--
-- TOC entry 25 (OID 94891)
-- Name: forum_thread; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE forum_thread (
    forum_thread_id serial NOT NULL,
    forum_id integer NOT NULL,
    created_by integer NOT NULL,
    thread_name text,
    message_count integer DEFAULT 0,
    most_recent_date timestamp with time zone DEFAULT now()
);


--
-- TOC entry 26 (OID 94901)
-- Name: forum_message; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE forum_message (
    forum_message_id serial NOT NULL,
    forum_thread_id integer NOT NULL,
    created_by integer NOT NULL,
    subject text NOT NULL,
    body text NOT NULL,
    post_date timestamp with time zone DEFAULT now(),
    parent_forum_message_id integer DEFAULT 0,
    mail_msg_id text,
    mail_sender text,
    is_approved boolean DEFAULT true
);


--
-- TOC entry 27 (OID 94912)
-- Name: user_blog; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_blog (
    user_blog_id serial NOT NULL,
    user_id integer NOT NULL,
    subject text NOT NULL,
    content text NOT NULL,
    post_date timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 28 (OID 94921)
-- Name: frs_package; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE frs_package (
    frs_package_id serial NOT NULL,
    project_id integer NOT NULL,
    package_name text,
    status_id integer DEFAULT 1,
    is_public boolean DEFAULT true,
    require_login boolean DEFAULT false
);


--
-- TOC entry 29 (OID 94932)
-- Name: frs_release; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE frs_release (
    frs_release_id serial NOT NULL,
    frs_package_id integer NOT NULL,
    release_name text,
    release_notes text,
    changes text,
    status_id integer DEFAULT 1,
    preformatted boolean DEFAULT false,
    release_date timestamp with time zone DEFAULT now(),
    released_by integer NOT NULL
);


--
-- TOC entry 30 (OID 94941)
-- Name: filesystem_download; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE filesystem_download (
    ip_address text,
    filesystem_id integer,
    download_date timestamp with time zone DEFAULT now(),
    user_id integer
);


--
-- TOC entry 31 (OID 94947)
-- Name: deleted_mailing_list; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE deleted_mailing_list (
    delete_date timestamp with time zone DEFAULT now(),
    isdeleted boolean DEFAULT false,
    mailing_list_name text NOT NULL
);


--
-- TOC entry 32 (OID 94956)
-- Name: mailman; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE mailman (
    mailman_id serial NOT NULL,
    project_id integer NOT NULL,
    list_name text,
    is_public boolean DEFAULT true,
    list_password character varying(16),
    created_by integer NOT NULL,
    status integer DEFAULT 1,
    list_description text,
    create_date timestamp with time zone DEFAULT now()
);


--
-- TOC entry 33 (OID 94967)
-- Name: news; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE news (
    news_id serial NOT NULL,
    project_id integer NOT NULL,
    submitted_by integer NOT NULL,
    is_approved boolean DEFAULT false,
    post_date timestamp with time zone DEFAULT now(),
    summary text,
    details text
);


--
-- TOC entry 34 (OID 94975)
-- Name: user_session; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_session (
    user_id integer NOT NULL,
    session_hash character(32) NOT NULL,
    ip_addr character(15) NOT NULL,
    login_time timestamp with time zone DEFAULT now()
);


--
-- TOC entry 35 (OID 94980)
-- Name: snippet; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE snippet (
    snippet_id serial NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    created_by integer NOT NULL,
    create_date timestamp with time zone DEFAULT now(),
    snippet_name text,
    snippet_description text
);


--
-- TOC entry 36 (OID 94989)
-- Name: survey_question; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE survey_question (
    survey_question_id serial NOT NULL,
    project_id integer NOT NULL,
    question text NOT NULL,
    question_type integer NOT NULL
);


--
-- TOC entry 37 (OID 94997)
-- Name: survey; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE survey (
    survey_id serial NOT NULL,
    project_id integer NOT NULL,
    survey_title text NOT NULL,
    survey_questions text NOT NULL,
    is_active boolean DEFAULT true
);


--
-- TOC entry 38 (OID 95004)
-- Name: survey_response; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE survey_response (
    user_id integer NOT NULL,
    survey_id integer DEFAULT 0 NOT NULL,
    question_id integer DEFAULT 0 NOT NULL,
    response text NOT NULL,
    post_date timestamp with time zone DEFAULT now() NOT NULL
);


--
-- TOC entry 39 (OID 95014)
-- Name: trove_category; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE trove_category (
    trove_category_id serial NOT NULL,
    root_trove_category_id integer NOT NULL,
    parent_trove_category_id integer NOT NULL,
    alias text NOT NULL,
    category_name text NOT NULL,
    description text NOT NULL
);


--
-- TOC entry 40 (OID 95020)
-- Name: trove_link; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE trove_link (
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    trove_category_id integer NOT NULL
);


--
-- TOC entry 41 (OID 95024)
-- Name: role; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE role (
    role_id serial NOT NULL,
    project_id integer NOT NULL,
    role_name text NOT NULL
);


--
-- TOC entry 42 (OID 95030)
-- Name: role_setting; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE role_setting (
    role_id integer NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    value integer
);


--
-- TOC entry 43 (OID 95032)
-- Name: user_project; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_project (
    user_id integer NOT NULL,
    project_id integer NOT NULL,
    join_date timestamp with time zone DEFAULT now(),
    user_project_id integer DEFAULT nextval('user_project_user_project_id_seq'::text)
);


--
-- TOC entry 44 (OID 95036)
-- Name: user_preference; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_preference (
    user_id integer NOT NULL,
    preference_name character varying(20) NOT NULL,
    set_date timestamp with time zone DEFAULT now(),
    preference_value text
);


--
-- TOC entry 45 (OID 95044)
-- Name: tracker; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker (
    tracker_id serial NOT NULL,
    project_id integer NOT NULL,
    tracker_name text,
    description text,
    is_public boolean DEFAULT true,
    restrict_browse boolean DEFAULT true,
    email_all_updates boolean DEFAULT false,
    email_address text,
    due_period integer DEFAULT 2592000,
    submit_instructions text,
    browse_instructions text,
    datatype integer,
    item_total integer DEFAULT 0,
    open_count integer DEFAULT 0
);


--
-- TOC entry 46 (OID 95058)
-- Name: tracker_item; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item (
    tracker_item_id serial NOT NULL,
    tracker_id integer NOT NULL,
    status_id integer DEFAULT 1,
    priority integer DEFAULT 3,
    submitted_by integer NOT NULL,
    open_date timestamp with time zone DEFAULT now(),
    close_date timestamp with time zone,
    summary text NOT NULL,
    details text NOT NULL,
    last_modified_date timestamp with time zone DEFAULT now(),
    last_modified_by integer DEFAULT 0,
    sort_order integer DEFAULT 0,
    parent_id integer DEFAULT 0
);


--
-- TOC entry 47 (OID 95073)
-- Name: tracker_time_code; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_time_code (
    tracker_time_code_id serial NOT NULL,
    time_name text
);


--
-- TOC entry 48 (OID 95081)
-- Name: tracker_item_time; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item_time (
    tracker_item_time_id serial NOT NULL,
    date_entry date DEFAULT now() NOT NULL,
    user_id integer NOT NULL,
    tracker_item_id integer NOT NULL,
    hours double precision,
    tracker_time_code_id integer NOT NULL
);


--
-- TOC entry 49 (OID 95085)
-- Name: tracker_item_relation; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item_relation (
    tracker_item_id integer NOT NULL,
    related_tracker_item_id integer NOT NULL,
    link_type character(2) DEFAULT 'FS'::bpchar
);


--
-- TOC entry 50 (OID 95088)
-- Name: tracker_item_assignee; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item_assignee (
    tracker_item_id integer NOT NULL,
    assignee integer NOT NULL,
    percent_utilization integer DEFAULT 100
);


--
-- TOC entry 51 (OID 95093)
-- Name: tracker_item_message; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item_message (
    tracker_item_message_id serial NOT NULL,
    tracker_item_id integer NOT NULL,
    submitted_by integer NOT NULL,
    adddate timestamp with time zone DEFAULT now(),
    body text NOT NULL
);


--
-- TOC entry 52 (OID 95102)
-- Name: tracker_canned_response; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_canned_response (
    tracker_canned_response_id serial NOT NULL,
    tracker_id integer NOT NULL,
    title text NOT NULL,
    body text NOT NULL
);


--
-- TOC entry 279 (OID 95108)
-- Name: forum_insertdelete_agg(); Type: FUNCTION; Schema: public; Owner: gforge
--

CREATE FUNCTION forum_insertdelete_agg() RETURNS "trigger"
    AS '
DECLARE
	forumrec record;
BEGIN
	IF TG_OP=''INSERT'' THEN
		FOR forumrec IN SELECT * FROM forum_thread WHERE forum_thread_id=NEW.forum_thread_id LOOP
			UPDATE forum SET message_count=message_count+1, most_recent_date=now()
				WHERE forum_id=forumrec.forum_id;
		END LOOP;
	ELSE
		FOR forumrec IN SELECT * FROM forum_thread WHERE forum_thread_id=OLD.forum_thread_id LOOP
			UPDATE forum SET message_count=message_count-1
				WHERE forum_id=forumrec.forum_id;
		END LOOP;
	END IF;
        RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 280 (OID 95109)
-- Name: tracker_update_agg(); Type: FUNCTION; Schema: public; Owner: gforge
--

CREATE FUNCTION tracker_update_agg() RETURNS "trigger"
    AS '
BEGIN
	--
	-- see if they are moving to a new trackertype
	-- if so, its a more complex operation
	--
	IF NEW.tracker_id <> OLD.tracker_id THEN
		--
		-- transferred trackers always have a status of 1
		-- so we will increment the new trackertypes sums
		--
		IF OLD.status_id=0 THEN
			UPDATE tracker SET item_total=item_total-1 
				WHERE tracker_id=OLD.tracker_id;
		ELSE 
			IF OLD.status_id=1 THEN
				UPDATE tracker SET item_total=item_total-1,open_count=open_count-1 
					WHERE tracker_id=OLD.tracker_id;
			END IF;
		END IF;

		IF NEW.status_id=0 THEN
			UPDATE tracker SET item_total=item_total+1 
				WHERE tracker_id=NEW.tracker_id;
		ELSE
			IF NEW.status_id=1 THEN
				UPDATE tracker SET item_total=item_total+1, open_count=open_count+1 
					WHERE tracker_id=NEW.tracker_id;
			END IF;
		END IF;
	ELSE
		--
		-- just need to evaluate the status flag and 
		-- increment/decrement the counter as necessary
		--
		IF NEW.status_id <> OLD.status_id THEN
			IF NEW.status_id = 1 THEN
				IF OLD.status_id=0 THEN
					UPDATE tracker SET open_count=open_count+1 
						WHERE tracker_id=NEW.tracker_id;
				END IF;
			ELSE
				IF NEW.status_id = 0 THEN
					IF OLD.status_id=1 THEN
						UPDATE tracker SET open_count=open_count-1 
							WHERE tracker_id=NEW.tracker_id;
					END IF;
				END IF;
			END IF;
		END IF;	
	END IF;
	RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 53 (OID 95112)
-- Name: notification_queue; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE notification_queue (
    notification_queue_id serial NOT NULL,
    section character varying(20),
    ref_id integer NOT NULL,
    user_id integer NOT NULL,
    subject text,
    body text,
    queue_date timestamp with time zone DEFAULT now(),
    send_date timestamp with time zone DEFAULT now()
);


--
-- TOC entry 54 (OID 95120)
-- Name: scm_user_stats; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_user_stats (
    stat_date date NOT NULL,
    project_id integer NOT NULL,
    user_id integer NOT NULL,
    checkouts integer NOT NULL,
    commits integer NOT NULL,
    adds integer NOT NULL
);


--
-- TOC entry 55 (OID 95122)
-- Name: scm_project_stats; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_project_stats (
    stat_date date NOT NULL,
    project_id integer NOT NULL,
    checkouts integer NOT NULL,
    commits integer NOT NULL,
    adds integer NOT NULL
);


--
-- TOC entry 56 (OID 95124)
-- Name: activity_log; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE activity_log (
    activity_date timestamp with time zone DEFAULT now() NOT NULL,
    project_id integer DEFAULT 0,
    page text,
    activity_type integer DEFAULT 0
);


--
-- TOC entry 57 (OID 95134)
-- Name: plugin; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE plugin (
    plugin_id serial NOT NULL,
    plugin_name text NOT NULL,
    plugin_desc text NOT NULL,
    plugin_type text NOT NULL,
    plugin_order integer DEFAULT 0,
    exclusive_type text
);


--
-- TOC entry 58 (OID 95141)
-- Name: plugin_dependency; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE plugin_dependency (
    plugin_id integer NOT NULL,
    dependson_plugin_id integer NOT NULL
);


--
-- TOC entry 59 (OID 95143)
-- Name: project_plugin; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE project_plugin (
    project_id integer NOT NULL,
    plugin_id integer NOT NULL,
    plugin_order integer
);


--
-- TOC entry 60 (OID 95145)
-- Name: user_plugin; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_plugin (
    user_id integer NOT NULL,
    plugin_id integer NOT NULL,
    plugin_order integer DEFAULT 0
);


--
-- TOC entry 61 (OID 95148)
-- Name: user_relation; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_relation (
    user_id integer NOT NULL,
    related_user_id integer NOT NULL
);


--
-- TOC entry 62 (OID 95150)
-- Name: user_watched_project; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_watched_project (
    user_id integer NOT NULL,
    project_id integer NOT NULL
);


--
-- TOC entry 63 (OID 95152)
-- Name: cron_history; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cron_history (
    rundate timestamp with time zone DEFAULT now(),
    job text,
    output text
);


--
-- TOC entry 64 (OID 95160)
-- Name: tracker_extra_field; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field (
    tracker_extra_field_id serial NOT NULL,
    tracker_id integer NOT NULL,
    field_name text NOT NULL,
    field_type integer NOT NULL,
    attribute1 integer DEFAULT 0,
    attribute2 integer DEFAULT 0,
    is_required boolean DEFAULT false,
    alias text NOT NULL,
    field_order integer DEFAULT 0,
    use_in_quick_browse boolean DEFAULT false,
    show_on_submit boolean DEFAULT false,
    use_auto_assign boolean DEFAULT false,
    use_workflow boolean DEFAULT false
);


--
-- TOC entry 65 (OID 95176)
-- Name: tracker_extra_field_element; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_element (
    element_id serial NOT NULL,
    tracker_extra_field_id integer NOT NULL,
    element_name text NOT NULL,
    status_id integer DEFAULT 1,
    default_selected boolean DEFAULT false,
    sort_order integer DEFAULT 0,
    auto_assign_to integer DEFAULT 100
);


--
-- TOC entry 66 (OID 95188)
-- Name: tracker_extra_field_data; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_data (
    tracker_extra_field_data_id serial NOT NULL,
    tracker_item_id integer NOT NULL,
    field_data text,
    tracker_extra_field_id integer NOT NULL
);


--
-- TOC entry 67 (OID 95194)
-- Name: project_join_request; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE project_join_request (
    project_id integer NOT NULL,
    user_id integer NOT NULL,
    comments text,
    request_date timestamp with time zone DEFAULT now()
);


--
-- TOC entry 281 (OID 95200)
-- Name: update_last_modified_date(); Type: FUNCTION; Schema: public; Owner: gforge
--

CREATE FUNCTION update_last_modified_date() RETURNS "trigger"
    AS '
BEGIN
NEW.last_modified_date = NOW();
RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 68 (OID 95203)
-- Name: scm_module; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_module (
    scm_module_id serial NOT NULL,
    project_id integer NOT NULL,
    "path" text
);


--
-- TOC entry 69 (OID 95209)
-- Name: scm_preference; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_preference (
    project_id integer NOT NULL,
    require_tracker_item_id boolean DEFAULT false NOT NULL,
    mail_commits boolean DEFAULT false
);


--
-- TOC entry 70 (OID 95215)
-- Name: scm_commit; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_commit (
    scm_commit_id serial NOT NULL,
    project_id integer NOT NULL,
    commit_date timestamp with time zone DEFAULT now(),
    message_log text,
    user_id integer NOT NULL
);


--
-- TOC entry 71 (OID 95222)
-- Name: tracker_item_scm_commit; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_item_scm_commit (
    tracker_item_id integer NOT NULL,
    scm_commit_id integer NOT NULL
);


--
-- TOC entry 72 (OID 95224)
-- Name: scm_commit_file; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_commit_file (
    scm_commit_id integer NOT NULL,
    modified_file text NOT NULL,
    prev_version text,
    new_version text
);


--
-- TOC entry 73 (OID 95231)
-- Name: tracker_query; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_query (
    tracker_query_id serial NOT NULL,
    tracker_id integer NOT NULL,
    user_id integer NOT NULL,
    query_name text NOT NULL,
    is_shared boolean DEFAULT false
);


--
-- TOC entry 74 (OID 95238)
-- Name: tracker_query_field; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_query_field (
    tracker_query_id integer NOT NULL,
    query_field_type text NOT NULL,
    query_field_id integer NOT NULL,
    query_field_values text NOT NULL
);


--
-- TOC entry 75 (OID 95245)
-- Name: wiki_page; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE wiki_page (
    wiki_page_id serial NOT NULL,
    section character varying(30) NOT NULL,
    ref_id integer NOT NULL,
    pagename character varying(50) NOT NULL,
    flags integer,
    latest_version integer NOT NULL
);


--
-- TOC entry 76 (OID 95250)
-- Name: wiki_version; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE wiki_version (
    wiki_version_id serial NOT NULL,
    wiki_page_id integer NOT NULL,
    page_version integer NOT NULL,
    posted_by integer NOT NULL,
    refs text,
    last_modified_date timestamp with time zone DEFAULT now(),
    score integer,
    hits integer,
    create_date timestamp with time zone
);


--
-- TOC entry 77 (OID 95257)
-- Name: wiki_page_link; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE wiki_page_link (
    from_wiki_page_id integer NOT NULL,
    to_wiki_page_id integer NOT NULL
);


--
-- TOC entry 78 (OID 95261)
-- Name: project_activity_vw; Type: VIEW; Schema: public; Owner: gforge
--

CREATE VIEW project_activity_vw AS
    (((SELECT f.ref_id AS project_id, 'forum'::text AS section, f.forum_id AS ref_id, fm.forum_message_id AS subref_id, fm.subject AS description, fm.post_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM forum f, forum_thread ft, forum_message fm, "user" u WHERE ((((u.user_id = fm.created_by) AND (ft.forum_thread_id = fm.forum_thread_id)) AND (ft.forum_id = f.forum_id)) AND ((f.section)::text = 'project'::text)) UNION SELECT t.project_id, 'trackeropen'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.open_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE ((u.user_id = ti.submitted_by) AND (ti.tracker_id = t.tracker_id))) UNION SELECT t.project_id, 'trackerclose'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.close_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE (((u.user_id = ti.last_modified_by) AND (ti.tracker_id = t.tracker_id)) AND (ti.close_date IS NOT NULL))) UNION SELECT t.project_id, 'trackermod'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.last_modified_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE ((u.user_id = ti.last_modified_by) AND (ti.tracker_id = t.tracker_id))) UNION SELECT sc.project_id, 'scmcommit'::text AS section, sc.scm_commit_id AS ref_id, 0 AS subref_id, sc.message_log AS description, sc.commit_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM scm_commit sc, "user" u WHERE (u.user_id = sc.user_id);


--
-- TOC entry 79 (OID 95263)
-- Name: trove_link_count; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE trove_link_count (
    trove_category_id integer NOT NULL,
    section character varying(20) NOT NULL,
    link_count integer NOT NULL
);


--
-- TOC entry 80 (OID 95267)
-- Name: docman_file; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE docman_file (
    docman_file_id serial NOT NULL,
    docman_folder_id integer NOT NULL,
    description text,
    is_locked boolean DEFAULT true
);


--
-- TOC entry 81 (OID 95276)
-- Name: docman_file_version; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE docman_file_version (
    docman_file_version_id serial NOT NULL,
    docman_file_id integer NOT NULL,
    create_date timestamp with time zone DEFAULT now() NOT NULL,
    changes text,
    version_number double precision,
    created_by integer NOT NULL
);


--
-- TOC entry 82 (OID 95283)
-- Name: scm_module_user; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE scm_module_user (
    scm_module_id integer NOT NULL,
    user_id integer NOT NULL,
    "access" integer DEFAULT 0
);


--
-- TOC entry 83 (OID 95286)
-- Name: cruisecontrol; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol (
    project_id integer NOT NULL,
    builder text NOT NULL,
    log_type text NOT NULL,
    developer integer NOT NULL,
    last_modified_date timestamp with time zone DEFAULT now()
);


--
-- TOC entry 84 (OID 95292)
-- Name: cruisecontrol_publisher; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_publisher (
    project_id integer NOT NULL,
    tracker_id integer NOT NULL
);


--
-- TOC entry 85 (OID 95294)
-- Name: cruisecontrol_assignee; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_assignee (
    project_id integer NOT NULL,
    assignee integer NOT NULL
);


--
-- TOC entry 86 (OID 95296)
-- Name: cruisecontrol_preference; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_preference (
    project_id integer NOT NULL,
    name text NOT NULL,
    value text NOT NULL
);


--
-- TOC entry 87 (OID 95301)
-- Name: cruisecontrol_module; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_module (
    project_id integer NOT NULL,
    scm_module_id integer NOT NULL
);


--
-- TOC entry 88 (OID 95303)
-- Name: database_changes; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE database_changes (
    filename text,
    filedate text
);


--
-- TOC entry 89 (OID 95310)
-- Name: tracker_extra_field_element_transition; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_element_transition (
    tracker_extra_field_element_transition_id serial NOT NULL,
    element_id integer NOT NULL,
    to_element_id integer NOT NULL,
    notification_message text
);


--
-- TOC entry 90 (OID 95316)
-- Name: tracker_extra_field_element_transition_role; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_element_transition_role (
    tracker_extra_field_element_transition_id integer NOT NULL,
    role_id integer NOT NULL
);


--
-- TOC entry 91 (OID 95318)
-- Name: tracker_extra_field_element_transition_field; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_element_transition_field (
    tracker_extra_field_element_transition_id integer NOT NULL,
    required_tracker_extra_field_id integer NOT NULL
);


--
-- TOC entry 92 (OID 95320)
-- Name: project_activity; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE project_activity (
    activity_date date NOT NULL,
    project_id integer NOT NULL,
    measure double precision
);


--
-- TOC entry 93 (OID 95322)
-- Name: tracker_extra_field_element_transition_notify; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE tracker_extra_field_element_transition_notify (
    tracker_extra_field_element_transition_id integer NOT NULL,
    role_id integer NOT NULL
);


--
-- TOC entry 5 (OID 95324)
-- Name: user_project_user_project_id_seq; Type: SEQUENCE; Schema: public; Owner: gforge
--

CREATE SEQUENCE user_project_user_project_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 94 (OID 95326)
-- Name: user_project_role; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE user_project_role (
    user_project_id integer,
    role_id integer
);


--
-- TOC entry 95 (OID 95330)
-- Name: cruisecontrol_platform; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_platform (
    cruisecontrol_platform_id serial NOT NULL,
    project_id integer NOT NULL,
    name text NOT NULL
);


--
-- TOC entry 96 (OID 95336)
-- Name: cruisecontrol_platform_tracker_item; Type: TABLE; Schema: public; Owner: gforge
--

CREATE TABLE cruisecontrol_platform_tracker_item (
    cruisecontrol_platform_id integer NOT NULL,
    tracker_item_id integer NOT NULL
);


--
-- Data for TOC entry 282 (OID 94760)
-- Name: deleted_project; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY deleted_project (unix_group_name, delete_date, isdeleted) FROM stdin;
\.


--
-- Data for TOC entry 283 (OID 94766)
-- Name: project; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY project (project_id, project_name, unix_name, homepage_url, is_public, status, description, register_purpose, register_license_other, create_date, template_project_id, is_template) FROM stdin;
2	Basic project with CVS support	cvs_project	\N	f	1	Basic template project with CVS support	\N	\N	2006-06-12 12:37:11.787754-03	\N	t
3	Basic project with SVN support	svn_project	\N	f	1	Basic template project with SVN support	\N	\N	2006-06-12 12:37:11.797093-03	\N	t
1	Empty project	empty_project	\N	f	1	Bare-bones project. Use this when you want to manually create tracker items, configure SCM, etc	\N	\N	2006-06-12 12:37:11.799691-03	\N	t
\.


--
-- Data for TOC entry 284 (OID 94776)
-- Name: country_code; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY country_code (country_name, ccode) FROM stdin;
AFGHANISTAN	AF
ALBANIA	AL
ALGERIA	DZ
AMERICAN SAMOA	AS
ANDORRA	AD
ANGOLA	AO
ANGUILLA	AI
ANTARCTICA	AQ
ANTIGUA AND BARBUDA	AG
ARGENTINA	AR
ARMENIA	AM
ARUBA	AW
AUSTRALIA	AU
AUSTRIA	AT
AZERBAIJAN	AZ
BAHAMAS	BS
BAHRAIN	BH
BANGLADESH	BD
BARBADOS	BB
BELARUS	BY
BELGIUM	BE
BELIZE	BZ
BENIN	BJ
BERMUDA	BM
BHUTAN	BT
BOLIVIA	BO
BOSNIA AND HERZEGOVINA	BA
BOTSWANA	BW
BOUVET ISLAND	BV
BRAZIL	BR
BRITISH INDIAN OCEAN TERRITORY	IO
BRUNEI DARUSSALAM	BN
BULGARIA	BG
BURKINA FASO	BF
BURUNDI	BI
CAMBODIA	KH
CAMEROON	CM
CANADA	CA
CAPE VERDE	CV
CAYMAN ISLANDS	KY
CENTRAL AFRICAN REPUBLIC	CF
CHAD	TD
CHILE	CL
CHINA	CN
CHRISTMAS ISLAND	CX
COCOS (KEELING) ISLANDS	CC
COLOMBIA	CO
COMOROS	KM
CONGO	CG
CONGO, THE DEMOCRATIC REPUBLIC OF THE	CD
COOK ISLANDS	CK
COSTA RICA	CR
COTE D'IVOIRE	CI
CROATIA	HR
CUBA	CU
CYPRUS	CY
CZECH REPUBLIC	CZ
DENMARK	DK
DJIBOUTI	DJ
DOMINICA	DM
DOMINICAN REPUBLIC	DO
EAST TIMOR	TP
ECUADOR	EC
EGYPT	EG
EL SALVADOR	SV
EQUATORIAL GUINEA	GQ
ERITREA	ER
ESTONIA	EE
ETHIOPIA	ET
FALKLAND ISLANDS (MALVINAS)	FK
FAROE ISLANDS	FO
FIJI	FJ
FINLAND	FI
FRANCE	FR
FRENCH GUIANA	GF
FRENCH POLYNESIA	PF
FRENCH SOUTHERN TERRITORIES	TF
GABON	GA
GAMBIA	GM
GEORGIA	GE
GERMANY	DE
GHANA	GH
GIBRALTAR	GI
GREECE	GR
GREENLAND	GL
GRENADA	GD
GUADELOUPE	GP
GUAM	GU
GUATEMALA	GT
GUINEA	GN
GUINEA-BISSAU	GW
GUYANA	GY
HAITI	HT
HEARD ISLAND AND MCDONALD ISLANDS	HM
HOLY SEE (VATICAN CITY STATE)	VA
HONDURAS	HN
HONG KONG	HK
HUNGARY	HU
ICELAND	IS
INDIA	IN
INDONESIA	ID
IRAN, ISLAMIC REPUBLIC OF	IR
IRAQ	IQ
IRELAND	IE
ISRAEL	IL
ITALY	IT
JAMAICA	JM
JAPAN	JP
JORDAN	JO
KAZAKSTAN	KZ
KENYA	KE
KIRIBATI	KI
KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF	KP
KOREA, REPUBLIC OF	KR
KUWAIT	KW
KYRGYZSTAN	KG
LAO PEOPLE'S DEMOCRATIC REPUBLIC	LA
LATVIA	LV
LEBANON	LB
LESOTHO	LS
LIBERIA	LR
LIBYAN ARAB JAMAHIRIYA	LY
LIECHTENSTEIN	LI
LITHUANIA	LT
LUXEMBOURG	LU
MACAU	MO
MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF	MK
MADAGASCAR	MG
MALAWI	MW
MALAYSIA	MY
MALDIVES	MV
MALI	ML
MALTA	MT
MARSHALL ISLANDS	MH
MARTINIQUE	MQ
MAURITANIA	MR
MAURITIUS	MU
MAYOTTE	YT
MEXICO	MX
MICRONESIA, FEDERATED STATES OF	FM
MOLDOVA, REPUBLIC OF	MD
MONACO	MC
MONGOLIA	MN
MONTSERRAT	MS
MOROCCO	MA
MOZAMBIQUE	MZ
MYANMAR	MM
NAMIBIA	NA
NAURU	NR
NEPAL	NP
NETHERLANDS	NL
NETHERLANDS ANTILLES	AN
NEW CALEDONIA	NC
NEW ZEALAND	NZ
NICARAGUA	NI
NIGER	NE
NIGERIA	NG
NIUE	NU
NORFOLK ISLAND	NF
NORTHERN MARIANA ISLANDS	MP
NORWAY	NO
OMAN	OM
PAKISTAN	PK
PALAU	PW
PALESTINIAN TERRITORY, OCCUPIED	PS
PANAMA	PA
PAPUA NEW GUINEA	PG
PARAGUAY	PY
PERU	PE
PHILIPPINES	PH
PITCAIRN	PN
POLAND	PL
PORTUGAL	PT
PUERTO RICO	PR
QATAR	QA
REUNION	RE
ROMANIA	RO
RUSSIAN FEDERATION	RU
RWANDA	RW
SAINT HELENA	SH
SAINT KITTS AND NEVIS	KN
SAINT LUCIA	LC
SAINT PIERRE AND MIQUELON	PM
SAINT VINCENT AND THE GRENADINES	VC
SAMOA	WS
SAN MARINO	SM
SAO TOME AND PRINCIPE	ST
SAUDI ARABIA	SA
SENEGAL	SN
SEYCHELLES	SC
SIERRA LEONE	SL
SINGAPORE	SG
SLOVAKIA	SK
SLOVENIA	SI
SOLOMON ISLANDS	SB
SOMALIA	SO
SOUTH AFRICA	ZA
SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS	GS
SPAIN	ES
SRI LANKA	LK
SUDAN	SD
SURINAME	SR
SVALBARD AND JAN MAYEN	SJ
SWAZILAND	SZ
SWEDEN	SE
SWITZERLAND	CH
SYRIAN ARAB REPUBLIC	SY
TAIWAN, PROVINCE OF CHINA	TW
TAJIKISTAN	TJ
TANZANIA, UNITED REPUBLIC OF	TZ
THAILAND	TH
TOGO	TG
TOKELAU	TK
TONGA	TO
TRINIDAD AND TOBAGO	TT
TUNISIA	TN
TURKEY	TR
TURKMENISTAN	TM
TURKS AND CAICOS ISLANDS	TC
TUVALU	TV
UGANDA	UG
UKRAINE	UA
UNITED ARAB EMIRATES	AE
UNITED STATES	US
UNITED STATES MINOR OUTLYING ISLANDS	UM
URUGUAY	UY
UZBEKISTAN	UZ
VANUATU	VU
VENEZUELA	VE
VIET NAM	VN
VIRGIN ISLANDS, BRITISH	VG
VIRGIN ISLANDS, U.S.	VI
WALLIS AND FUTUNA	WF
WESTERN SAHARA	EH
YEMEN	YE
YUGOSLAVIA	YU
ZAMBIA	ZM
ZIMBABWE	ZW
UNITED KINGDOM	UK
\.


--
-- Data for TOC entry 285 (OID 94780)
-- Name: theme; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY theme (theme_id, dirname, fullname) FROM stdin;
1	gforge5	GForge 5 default theme
\.


--
-- Data for TOC entry 286 (OID 94788)
-- Name: language; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY "language" (language_id, name, filename, language_code) FROM stdin;
1	English	Base.tab	en   
2	Spanish	Spanish.tab	es   
3	French	French.tab	fr   
4	Simplified Chinese	SimplifiedChinese.tab	zh   
5	Korean	Korean.tab	ko   
\.


--
-- Data for TOC entry 287 (OID 94796)
-- Name: user; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY "user" (user_id, unix_name, email, status, password_md5, password_crypt, create_date, confirm_hash, email_new, timezone, date_format, address, address2, phone, fax, title, firstname, lastname, ccode, language_id, theme_id, external_id, last_login) FROM stdin;
100	none	root@localhost.localdomain	2			2006-06-12 12:37:11.763059-03	\N	\N	GMT	MDY	\N	\N	\N	\N	\N	Nobody	User	US	1	1	\N	2006-08-30 15:00:33.581535-03
101	gforgeadmin	root@localhost.localdomain	1			2006-06-12 12:37:11.774331-03	\N	\N	GMT	MDY	\N	\N	\N	\N	\N	GForge Admin	User	US	1	1	\N	2006-08-30 15:00:33.581535-03
\.


--
-- Data for TOC entry 288 (OID 94805)
-- Name: site_admin; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY site_admin (user_id) FROM stdin;
101
\.


--
-- Data for TOC entry 289 (OID 94809)
-- Name: filesystem; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY filesystem (filesystem_id, section, ref_id, file_name, file_name_safe, file_type, file_size, deleted, posted_by, download_count, strings) FROM stdin;
1	project	2	homepage	homepage	text	8	f	100	1	\N
2	project	3	homepage	homepage	text	8	f	100	1	\N
3	project	1	homepage	homepage	text	8	f	100	1	\N
\.


--
-- Data for TOC entry 290 (OID 94817)
-- Name: stats_project_page_view; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY stats_project_page_view (project_id, count_date, count_views) FROM stdin;
\.


--
-- Data for TOC entry 291 (OID 94819)
-- Name: stats_site_page_view; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY stats_site_page_view (count_date, count_views) FROM stdin;
\.


--
-- Data for TOC entry 292 (OID 94821)
-- Name: monitor; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY monitor (section, ref_id, user_id) FROM stdin;
\.


--
-- Data for TOC entry 293 (OID 94826)
-- Name: audit_trail; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY audit_trail (audit_trail_id, change_date, user_id, section, ref_id, field_name, new_value, old_value) FROM stdin;
\.


--
-- Data for TOC entry 294 (OID 94836)
-- Name: unix_shell; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY unix_shell (unix_shell_id, shell_name, "path") FROM stdin;
1	Bash	/bin/bash
2	Restricted CVS Shell	/bin/cvssh.pl
\.


--
-- Data for TOC entry 295 (OID 94842)
-- Name: user_unix; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_unix (user_id, unix_shell_id, unix_uid, unix_gid, unix_box, authorized_keys) FROM stdin;
\.


--
-- Data for TOC entry 296 (OID 94852)
-- Name: scm_server; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_server (scm_server_id, scm_type, hostname) FROM stdin;
1	CVS	cvs.
2	SVN	svn.
\.


--
-- Data for TOC entry 297 (OID 94860)
-- Name: docman_folder; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY docman_folder (docman_folder_id, project_id, folder_name, is_public, parent_folder_id, doc_count) FROM stdin;
\.


--
-- Data for TOC entry 298 (OID 94869)
-- Name: project_scm; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY project_scm (project_id, enable_anonread, scm_server_id, controlled, hostname, root_directory, external_browse_url, browse_text, access_text) FROM stdin;
2	t	1	t	\N	\N	\N	\N	\N
3	t	2	t	\N	\N	\N	\N	\N
\.


--
-- Data for TOC entry 299 (OID 94878)
-- Name: forum; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY forum (forum_id, section, ref_id, forum_name, is_public, description, send_all_posts_to, thread_count, message_count, most_recent_date, moderation_level) FROM stdin;
1	project	2	Open discussion	t	General discussion	\N	0	0	2006-06-12 12:37:11.820658-03	0
2	project	2	Help	t	Get public help	\N	0	0	2006-06-12 12:37:11.823305-03	0
3	project	3	Open discussion	t	General discussion	\N	0	0	2006-06-12 12:37:11.825298-03	0
4	project	3	Help	t	Get public help	\N	0	0	2006-06-12 12:37:11.827242-03	0
5	mailman	1	mailman-1	t	cvs_project-commits	\N	0	0	2006-06-12 12:37:13.334246-03	0
6	mailman	2	mailman-2	t	svn_project-commits	\N	0	0	2006-06-12 12:37:13.341101-03	0
\.


--
-- Data for TOC entry 300 (OID 94891)
-- Name: forum_thread; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY forum_thread (forum_thread_id, forum_id, created_by, thread_name, message_count, most_recent_date) FROM stdin;
\.


--
-- Data for TOC entry 301 (OID 94901)
-- Name: forum_message; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY forum_message (forum_message_id, forum_thread_id, created_by, subject, body, post_date, parent_forum_message_id, mail_msg_id, mail_sender, is_approved) FROM stdin;
\.


--
-- Data for TOC entry 302 (OID 94912)
-- Name: user_blog; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_blog (user_blog_id, user_id, subject, content, post_date) FROM stdin;
\.


--
-- Data for TOC entry 303 (OID 94921)
-- Name: frs_package; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY frs_package (frs_package_id, project_id, package_name, status_id, is_public, require_login) FROM stdin;
\.


--
-- Data for TOC entry 304 (OID 94932)
-- Name: frs_release; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY frs_release (frs_release_id, frs_package_id, release_name, release_notes, changes, status_id, preformatted, release_date, released_by) FROM stdin;
\.


--
-- Data for TOC entry 305 (OID 94941)
-- Name: filesystem_download; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY filesystem_download (ip_address, filesystem_id, download_date, user_id) FROM stdin;
\N	1	2006-08-30 15:05:09.108354-03	101
\N	2	2006-08-30 15:22:54.967619-03	101
\N	3	2006-08-30 15:26:56.843335-03	101
\.


--
-- Data for TOC entry 306 (OID 94947)
-- Name: deleted_mailing_list; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY deleted_mailing_list (delete_date, isdeleted, mailing_list_name) FROM stdin;
\.


--
-- Data for TOC entry 307 (OID 94956)
-- Name: mailman; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY mailman (mailman_id, project_id, list_name, is_public, list_password, created_by, status, list_description, create_date) FROM stdin;
1	2	cvs_project-commits	f	commitspassword	100	1	Commits list for template project	2006-06-12 12:37:13.334246-03
2	3	svn_project-commits	f	commitspassword	100	1	Commits list for template project	2006-06-12 12:37:13.341101-03
\.


--
-- Data for TOC entry 308 (OID 94967)
-- Name: news; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY news (news_id, project_id, submitted_by, is_approved, post_date, summary, details) FROM stdin;
\.


--
-- Data for TOC entry 309 (OID 94975)
-- Name: user_session; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_session (user_id, session_hash, ip_addr, login_time) FROM stdin;
\.


--
-- Data for TOC entry 310 (OID 94980)
-- Name: snippet; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY snippet (snippet_id, section, ref_id, created_by, create_date, snippet_name, snippet_description) FROM stdin;
\.


--
-- Data for TOC entry 311 (OID 94989)
-- Name: survey_question; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY survey_question (survey_question_id, project_id, question, question_type) FROM stdin;
\.


--
-- Data for TOC entry 312 (OID 94997)
-- Name: survey; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY survey (survey_id, project_id, survey_title, survey_questions, is_active) FROM stdin;
\.


--
-- Data for TOC entry 313 (OID 95004)
-- Name: survey_response; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY survey_response (user_id, survey_id, question_id, response, post_date) FROM stdin;
\.


--
-- Data for TOC entry 314 (OID 95014)
-- Name: trove_category; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY trove_category (trove_category_id, root_trove_category_id, parent_trove_category_id, alias, category_name, description) FROM stdin;
0	0	0	root	Root Cat	Root Category
1	0	0	audience	Intended Audience	The main class of people likely to be interested in this resource.
2	1	1	endusers	End Users/Desktop	Programs and resources for software end users. Software for the desktop.
3	1	1	developers	Developers	Programs and resources for software developers, to include libraries.
4	1	1	sysadmins	System Administrators	Programs and resources for people who administer computers and networks.
5	1	1	other	Other Audience	Programs and resources for an unlisted audience.
6	0	0	developmentstatus	Development Status	An indication of the development status of the software or resource.
7	6	6	planning	1 - Planning	This resource is in the planning stages only. There is no code.
8	6	6	prealpha	2 - Pre-Alpha	There is code for this project, but it is not usable except for further development.
9	6	6	alpha	3 - Alpha	Resource is in early development, and probably incomplete and/or extremely buggy.
10	6	6	beta	4 - Beta	Resource is in late phases of development. Deliverables are essentially complete, but may still have significant bugs.
11	6	6	production	5 - Production/Stable	Deliverables are complete and usable by the intended audience.
12	6	6	mature	6 - Mature	This resource has an extensive history of successful use and has probably undergone several stable revisions.
13	0	0	license	License	License terms under which the resource is distributed.
197	13	13	publicdomain	Public Domain	Public Domain. No author-retained rights.
196	13	13	other	Other/Proprietary License	Non OSI-Approved/Proprietary license.
14	13	13	osi	OSI Approved	Licenses that have been approved by OSI as approved
303	13	14	nethack	Nethack General Public License	Nethack General Public License
121	18	113	mixers	Mixers	Programs to mix audio.
120	18	113	editors	Editors	Programs to edit/manipulate sound data.
119	18	113	conversion	Conversion	Programs to convert between audio formats.
116	18	113	cdaudio	CD Audio	Programs to play and manipulate audio CDs.
117	18	116	cdplay	CD Playing	CD Playing software, to include jukebox software.
118	18	116	cdripping	CD Ripping	Software to convert CD Audio to other digital formats.
125	18	99	video	Video	Video capture, editing, and playback.
127	18	125	conversion	Conversion	Programs which convert between video formats.
128	18	125	display	Display	Programs which display various video formats.
256	18	125	nonlineareditor	Non-Linear Editor	Video Non-Linear Editors
126	18	125	capture	Capture	Video capture tools.
100	18	99	graphics	Graphics	Tools and resources for computer graphics.
101	18	100	capture	Capture	Support for scanners, cameras, and screen capture.
102	18	101	scanners	Scanners	Support for graphic scanners.
103	18	101	cameras	Digital Camera	Digital Camera
104	18	101	screencapture	Screen Capture	Screen capture tools and processors.
105	18	100	conversion	Graphics Conversion	Programs which convert between graphics formats.
106	18	100	editors	Editors	Drawing, painting, and structured editing programs.
107	18	106	vector	Vector-Based	Vector-Based drawing programs.
108	18	106	raster	Raster-Based	Raster/Bitmap based drawing programs.
17	13	14	artistic	Artistic License	The Perl Artistic License
109	18	100	3dmodeling	3D Modeling	Programs for working with 3D Models.
110	18	100	3drendering	3D Rendering	Programs which render 3D models.
111	18	100	presentation	Presentation	Tools for generating presentation graphics and slides.
112	18	100	viewers	Viewers	Programs that can display various graphics formats.
86	18	80	mud	Multi-User Dungeons (MUD)	Massively-multiplayer text based games.
85	18	80	simulation	Simulation	Simulation games
84	18	80	rpg	Role-Playing	Role-Playing games
83	18	80	turnbasedstrategy	Turn Based Strategy	Turn Based Strategy
82	18	80	firstpersonshooters	First Person Shooters	First Person Shooters.
81	18	80	realtimestrategy	Real Time Strategy	Real Time strategy games
288	18	80	sidescrolling	Side-Scrolling/Arcade Games	Arcade-style side-scrolling games
282	18	18	Sociology	Sociology	Social / Informational - Family / etc.
284	18	282	Genealogy	Genealogy	Family History / Genealogy
283	18	282	History	History	History / Informational
55	18	18	desktop	Desktop Environment	Accessories, managers, and utilities for your GUI desktop.
62	18	55	screensavers	Screen Savers	Screen savers and lockers.
56	18	55	windowmanagers	Window Managers	Programs that provide window control and application launching.
59	18	56	enlightenment	Enlightenment	Software for the Enlightenment window manager.
60	18	59	themes	Themes	Themes for the Enlightenment window manager.
57	18	55	kde	K Desktop Environment (KDE)	Software for the KDE desktop.
61	18	57	themes	Themes	Themes for KDE.
58	18	55	gnome	Gnome	Software for the Gnome desktop.
45	18	18	development	Software Development	Software used to aid software development.
52	18	45	versioncontrol	Version Control	Tools for managing multiple versions of evolving sources or documents.
53	18	52	cvs	CVS	Tools for CVS (Concurrent Versioning System).
54	18	52	rcs	RCS	Tools for RCS (Revision Control System).
260	18	52	SCCS	SCCS	SCCS
259	18	45	codegen	Code Generators	Code Generators
46	18	45	build	Build Tools	Software for the build process.
47	18	45	debuggers	Debuggers	Programs for controlling and monitoring the execution of compiled binaries.
48	18	45	compilers	Compilers	Programs for compiling high-level languges into machine code.
49	18	45	interpreters	Interpreters	Programs for interpreting and executing high-level languages directly.
50	18	45	objectbrokering	Object Brokering	Object brokering libraries and tools.
51	18	50	corba	CORBA	Tools for implementation and use of CORBA.
99	18	18	multimedia	Multimedia	Graphics, sound, video, and multimedia.
113	18	99	sound	Sound/Audio	Tools for generating, editing, analyzing, and playing sound.
115	18	113	capture	Capture/Recording	Sound capture and recording.
114	18	113	analysis	Analysis	Sound analysis tools, to include frequency analysis.
249	18	113	synthesis	Sound Synthesis	Software for creation and synthesis of sound.
248	18	113	midi	MIDI	Software related to MIDI synthesis and playback.
124	18	113	speech	Speech	Speech manipulation and intepretation tools.
122	18	113	players	Players	Programs to play audio files to a sound device.
123	18	122	mp3	MP3	Programs to play MP3 audio files.
67	18	66	engines	Database Engines/Servers	Programs that manage data and provide control via some query language.
68	18	66	frontends	Front-Ends	Clients and front-ends for generating queries to database engines.
63	18	18	editors	Text Editors	Programs for editing code and documents.
64	18	63	emacs	Emacs	GNU Emacs and its imitators and tools.
65	18	63	ide	Integrated Development Environments (IDE)	Complete editing environments for code, including cababilities such as compilation and code building assistance.
69	18	63	documentation	Documentation	Tools for the creation and use of documentation.
70	18	63	wordprocessors	Word Processors	WYSIWYG word processors.
285	18	63	textprocessing	Text Processing	Programs or libraries that are designed to batch process text documents
43	18	18	security	Security	Security-related software, to include system administration and cryptography.
44	18	43	cryptography	Cryptography	Cryptography programs, algorithms, and libraries.
97	18	18	scientific	Scientific/Engineering	Scientific applications, to include research, applied and pure mathematics and sciences.
98	18	97	mathematics	Mathematics	Software to support pure and applied mathematics.
272	18	97	HMI	Human Machine Interfaces	This applies to the Factory/Machine control/Automation fields where there are already thousands of applications and millions of installations.
266	18	97	medical	Medical Science Apps.	Medical / BioMedical Science Apps.
252	18	97	bioinformatics	Bio-Informatics	Category for gene software (e.g. Gene Ontology)
246	18	97	eda	Electronic Design Automation (EDA)	Tools for circuit design, schematics, board layout, and more.
135	18	97	visualization	Visualization	Software for scientific visualization.
134	18	97	astronomy	Astronomy	Software and tools related to astronomy.
133	18	97	ai	Artificial Intelligence	Artificial Intelligence.
89	18	87	ftp	File Transfer Protocol (FTP)	Programs and tools for file transfer via FTP.
90	18	87	www	WWW/HTTP	Programs and tools for the World Wide Web.
91	18	90	browsers	Browsers	Web Browsers
92	18	90	dynamic	Dynamic Content	Common Gateway Interface scripting and server-side parsing.
94	18	92	counters	Page Counters	Scripts to count numbers of pageviews.
95	18	92	messageboards	Message Boards	Online message boards
96	18	92	cgi	CGI Tools/Libraries	Tools for the Common Gateway Interface
93	18	90	indexing	Indexing/Search	Indexing and search tools for the Web.
243	18	90	sitemanagement	Site Management	Tools for maintanance and management of web sites.
244	18	243	linkchecking	Link Checking	Tools to assist in checking for broken links.
250	18	90	httpservers	HTTP Servers	Software designed to serve content via the HTTP protocol.
149	18	87	dns	Name Service (DNS)	Domain name system servers and utilities.
245	18	87	loganalysis	Log Analysis	Software to help analyze various log files.
270	18	87	WAP	WAP	Wireless Access Protocol
88	18	87	finger	Finger	The Finger protocol for getting information about users.
80	18	18	games	Games/Entertainment	Games and Entertainment software.
287	18	80	boardgames	Board Games	Board Games
268	18	80	Puzzles	Puzzle Games	Puzzle Games
158	18	156	virtual	Terminal Emulators/X Terminals	Programs to handle multiple terminal sessions. Includes terminal emulations for X and other window systems.
159	18	156	telnet	Telnet	Support for telnet; terminal sessions across Internet links.
154	18	18	printing	Printing	Tools, daemons, and utilities for printer control.
136	18	18	system	System	Operating system core and administration utilities.
141	18	136	clustering	Clustering/Distributed Networks	Tools for automatically distributing computation across a network.
139	18	136	boot	Boot	Programs for bootstrapping your OS.
140	18	139	init	Init	Init-time programs to start system services after boot.
138	18	136	benchmark	Benchmark	Programs for benchmarking system performance.
74	18	136	emulators	Emulators	Emulations of foreign operating systme and machines.
19	18	136	archiving	Archiving	Tools for maintaining and searching software or document archives.
41	18	19	packaging	Packaging	Tools for packing and unpacking multi-file formats. Includes data-only formats and software package systems.
42	18	19	compression	Compression	Tools and libraries for data compression.
137	18	19	backup	Backup	Programs to manage and sequence system backup.
294	18	136	shells	System Shells	System Shells
257	18	136	softwaredist	Software Distribution	Systems software for distributing other software.
253	18	136	sysadministration	Systems Administration	Systems Administration Software (e.g. configuration apps.)
289	18	253	authentication	Authentication/Directory	Authentication and directory services
290	18	289	nis	NIS	NIS services
291	18	289	ldap	LDAP	Leightweight directory access protocol
153	18	136	power	Power (UPS)	Code for communication with uninterruptible power supplies.
150	18	136	networking	Networking	Network configuration and administration.
151	18	150	firewalls	Firewalls	Firewalls and filtering systems.
152	18	150	monitoring	Monitoring	System monitoring, traffic analysis, and sniffers.
155	18	152	watchdog	Hardware Watchdog	Software to monitor and perform actions or shutdown on hardware trouble detection.
148	18	136	logging	Logging	Utilities for clearing, rotating, and digesting system logs.
147	18	136	setup	Installation/Setup	Tools for installation and setup of the operating system and other programs.
146	18	136	hardware	Hardware	Tools for direct, non-kernel control and configuration of hardware.
292	18	146	drivers	Hardware Drivers	Hardware Drivers
144	18	136	kernels	Operating System Kernels	OS Kernels, patches, modules, and tools.
143	18	144	linux	Linux	The Linux kernel, patches, and modules.
145	18	144	bsd	BSD	Code relating to any of the BSD kernels.
239	18	144	gnuhurd	GNU Hurd	Kernel code and modules for GNU Hurd.
142	18	136	filesystems	Filesystems	Support for creating, editing, reading, and writing file systems.
71	18	18	education	Education	Programs and tools for educating yourself or others.
72	18	71	cai	Computer Aided Instruction (CAI)	Programs for authoring or using Computer Aided Instrution courses.
73	18	71	testing	Testing	Tools for testing someone's knowledge on a subject.
66	18	18	database	Database	Front ends, engines, and tools for database work.
18	0	0	topic	Topic	Topic categorization.
20	18	18	communications	Communications	Programs intended to facilitate communication between people.
27	18	20	conferencing	Conferencing	Software to support real-time conferencing over the Internet.
22	18	20	chat	Chat	Programs to support real-time communication over the Internet.
23	18	22	icq	ICQ	Programs to support ICQ.
24	18	22	irc	Internet Relay Chat	Programs to support Internet Relay Chat.
25	18	22	talk	Unix Talk	Programs to support Unix Talk protocol.
26	18	22	aim	AOL Instant Messanger	Programs to support AOL Instant Messanger.
21	18	20	bbs	BBS	Bulletin Board systems.
251	18	20	filesharing	File Sharing	Software for person-to-person online file sharing.
286	18	251	gnutella	Gnutella	Projects based around the gnutella protocol.
241	18	251	napster	Napster	Clients and servers for the Napster file sharing protocol.
247	18	20	telephony	Telephony	Telephony related applications, to include automated voice response systems.
40	18	20	internetphone	Internet Phone	Software to support real-time speech communication over the Internet.
39	18	20	usenet	Usenet News	Software to support USENET news.
38	18	20	hamradio	Ham Radio	Tools and resources for amateur radio.
37	18	20	fido	FIDO	Tools for FIDOnet mail and echoes.
36	18	20	fax	Fax	Tools for sending and receiving facsimile messages.
28	18	20	email	Email	Programs for sending, processing, and handling electronic mail.
29	18	28	filters	Filters	Content-driven filters and dispatchers for Email.
30	18	28	listservers	Mailing List Servers	Tools for managing electronic mailing lists.
31	18	28	mua	Email Clients (MUA)	Programs for interactively reading and sending Email.
32	18	28	mta	Mail Transport Agents	Email transport and gatewaying software.
301	13	14	nosl	Nokia Open Source License	Nokia Open Source License
299	13	14	iosl	Intel Open Source License	Intel Open Source License
297	13	14	vsl	Vovida Software License	Vovida Software License
195	13	14	zlib	zlib/libpng License	zlib/libpng License
194	13	14	python	Python License	Python License
193	13	14	ricoh	Ricoh Source Code Public License	Ricoh Source Code Public License
192	13	14	cvw	MITRE Collaborative Virtual Workspace License (CVW)	MITRE Collaborative Virtual Workspace License (CVW)
191	13	14	ibm	IBM Public License	IBM Public License
190	13	14	qpl	QT Public License (QPL)	QT Public License
189	13	14	mpl	Mozilla Public License (MPL)	Mozilla Public License (MPL)
305	13	189	mpl11	Mozilla Public License 1.1	Mozilla Public License 1.1
199	0	0	os	Operating System	What operating system the program requires to run, if any.
200	199	199	posix	POSIX	POSIX plus standard Berkeley socket facilities. Don't list a more specific OS unless your program requires it.
33	18	28	postoffice	Post-Office	Programs to support post-office protocols, including POP and IMAP.
201	199	200	linux	Linux	Any version of Linux. Don't specify a subcategory unless the program requires a particular distribution.
202	199	200	bsd	BSD	Any variant of BSD. Don't specify a subcategory unless the program requires a particular BSD flavor.
203	199	202	freebsd	FreeBSD	FreeBSD
204	199	202	netbsd	NetBSD	NetBSD
205	199	202	openbsd	OpenBSD	OpenBSD
206	199	202	bsdos	BSD/OS	BSD/OS
207	199	200	sun	SunOS/Solaris	Any Sun Microsystems OS.
208	199	200	sco	SCO	SCO
209	199	200	hpux	HP-UX	HP-UX
210	199	200	aix	AIX	AIX
211	199	200	irix	IRIX	IRIX
212	199	200	other	Other	Other specific POSIX OS, specified in description.
34	18	33	pop3	POP3	Programs to support POP3 (Post-Office Protocol, version 3).
214	199	199	microsoft	Microsoft	Microsoft operating systems.
215	199	214	msdos	MS-DOS	Microsoft Disk Operating System (DOS)
216	199	214	windows	Windows	Windows software, not specific to any particular version of Windows.
217	199	216	win31	Windows 3.1 or Earlier	Windows 3.1 or Earlier
218	199	216	win95	Windows 95/98/2000	Windows 95, Windows 98, and Windows 2000.
219	199	216	winnt	Windows NT/2000	Windows NT and Windows 2000.
220	199	199	os2	OS/2	OS/2
221	199	199	macos	MacOS	MacOS
222	199	216	wince	Windows CE	Windows CE
223	199	199	palmos	PalmOS	PalmOS (for Palm Pilot)
224	199	199	beos	BeOS	BeOS
225	0	0	environment	Environment	Run-time environment required for this program.
226	225	225	console	Console (Text Based)	Console-based programs.
227	225	226	curses	Curses	Curses-based software.
228	225	226	newt	Newt	Newt
229	225	225	x11	X11 Applications	Programs that run in an X windowing environment.
230	225	225	win32	Win32 (MS Windows)	Programs designed to run in a graphical Microsoft Windows environment.
231	225	229	gnome	Gnome	Programs designed to run in a Gnome environment.
232	225	229	kde	KDE	Programs designed to run in a KDE environment.
233	225	225	other	Other Environment	Programs designed to run in an environment other than one listed.
35	18	33	imap	IMAP	Programs to support IMAP protocol (Internet Message Access Protocol).
235	199	199	independent	OS Independent	This software does not depend on any particular operating system.
236	199	199	other	Other OS	Program is designe for a nonlisted operating system.
237	225	225	web	Web Environment	This software is designed for a web environment.
238	225	225	daemon	No Input/Output (Daemon)	This program has no input or output, but is intended to run in the background as a daemon.
132	18	18	religion	Religion	Programs relating to religion and sacred texts.
240	199	200	gnuhurd	GNU Hurd	GNU Hurd
129	18	18	office	Office/Business	Software for assisting and organizing work at your desk.
75	18	129	financial	Financial	Programs related to finance.
76	18	75	accounting	Accounting	Checkbook balancers and accounting programs.
77	18	75	investment	Investment	Programs for assisting in financial investment.
78	18	75	spreadsheet	Spreadsheet	Spreadsheet applications.
79	18	75	pointofsale	Point-Of-Sale	Point-Of-Sale applications.
130	18	129	scheduling	Scheduling	Projects for scheduling time, to include project management.
131	18	129	suites	Office Suites	Integrated office suites (word processing, presentation, spreadsheet, database, etc).
234	18	18	other	Other/Nonlisted Topic	Topic does not fit into any listed category.
160	0	0	language	Programming Language	Language in which this program was written, or was meant to support.
161	160	160	apl	APL	APL
164	160	160	c	C	C
162	160	160	assembly	Assembly	Assembly-level programs. Platform specific.
163	160	160	ada	Ada	Ada
165	160	160	cpp	C++	C++
166	160	160	eiffel	Eiffel	Eiffel
167	160	160	euler	Euler	Euler
168	160	160	forth	Forth	Forth
169	160	160	fortran	Fortran	Fortran
170	160	160	lisp	Lisp	Lisp
171	160	160	logo	Logo	Logo
172	160	160	ml	ML	ML
173	160	160	modula	Modula	Modula-2 or Modula-3
174	160	160	objectivec	Objective C	Objective C
175	160	160	pascal	Pascal	Pascal
176	160	160	perl	Perl	Perl
177	160	160	prolog	Prolog	Prolog
178	160	160	python	Python	Python
179	160	160	rexx	Rexx	Rexx
180	160	160	simula	Simula	Simula
181	160	160	smalltalk	Smalltalk	Smalltalk
182	160	160	tcl	Tcl	Tcl
183	160	160	php	PHP	PHP
263	160	160	euphoria	Euphoria	Euphoria programming language - http://www.rapideuphoria.com/
264	160	160	erlang	Erlang	Erlang - developed by Ericsson - http://www.erlang.org/
267	160	160	zope	Zope	Zope Object Publishing
269	160	160	asm	Assembly	ASM programming
271	160	160	csharp	C#	Microsoft's C++/Java Language
273	160	160	Pike	Pike	Pike, see http://pike.roxen.com/.
184	160	160	asp	ASP	Active Server Pages
185	160	160	shell	Unix Shell	Unix Shell
186	160	160	visualbasic	Visual Basic	Visual Basic
198	160	160	java	Java	Java
213	160	160	other	Other	Other programming language, specified in description.
242	160	160	scheme	Scheme	Scheme programming language.
254	160	160	plsql	PL/SQL	PL/SQL Programming Language
255	160	160	progress	PROGRESS	PROGRESS Programming Language
258	160	160	objectpascal	Object Pascal	Object Pascal
261	160	160	xbasic	XBasic	XBasic programming language
262	160	160	coldfusion	Cold Fusion	Cold Fusion Language
304	13	189	mpl10	Mozilla Public License 1.0	Mozilla Public License 1.0
188	13	14	mit	MIT/X Consortium License	MIT License, also the X Consortium License.
187	13	14	bsd	BSD License	BSD License
156	18	18	terminals	Terminals	Terminal emulators, terminal programs, and terminal session utilities.
16	13	14	lgpl	GNU Lesser General Public License (LGPL)	GNU Lesser General Public License
15	13	14	gpl	GNU General Public License (GPL)	GNU General Public License.
280	160	160	JavaScript	JavaScript	Java Scripting Language
281	160	160	REBOL	REBOL	REBOL Programming Language
265	160	160	Delphi	Delphi/Kylix	Borland/Inprise Delphi or other Object-Pascal based languages
293	160	160	ruby	Ruby	Ruby programming language
157	18	156	serial	Serial	Dialup, terminal emulation, and file transfer over serial lines.
87	18	18	internet	Internet	Tools to assist human access to the Internet.
296	13	14	asl	Apache Software License	Apache Software License
274	0	0	natlanguage	Natural Language	The oral/written language for the development and use of this software.
295	274	274	russian	Russian	Projects having something to do with Russian Language
275	274	274	english	English	English
276	274	274	french	French	French
277	274	274	spanish	Spanish	Spanish
278	274	274	japanese	Japanese	Projects using the Japanese language
279	274	274	german	German	Projects using the German language
298	13	14	sissl	Sun Internet Standards Source License	Sun Internet Standards Source License
300	13	14	josl	Jabber Open Source License	Jabber Open Source License
302	13	14	sleepycat	Sleepycat License	Sleepycat License
\.


--
-- Data for TOC entry 315 (OID 95020)
-- Name: trove_link; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY trove_link (section, ref_id, trove_category_id) FROM stdin;
\.


--
-- Data for TOC entry 316 (OID 95024)
-- Name: role; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY role (role_id, project_id, role_name) FROM stdin;
1	2	Admin
2	2	Doc Writer
3	2	Junior Developer
4	2	Product Manager
5	2	Project Manager
6	2	QA Tester
7	2	Senior Developer
8	2	Support Tech
9	3	Admin
10	3	Doc Writer
11	3	Junior Developer
12	3	Product Manager
13	3	Project Manager
14	3	QA Tester
15	3	Senior Developer
16	3	Support Tech
17	1	Admin
\.


--
-- Data for TOC entry 317 (OID 95030)
-- Name: role_setting; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY role_setting (role_id, section, ref_id, value) FROM stdin;
1	projectadmin	0	1
1	tracker	0	3
1	tracker	1	2
1	tracker	2	2
1	tracker	3	2
1	tracker	4	2
2	projectadmin	0	0
2	forum	0	-1
2	forum	1	0
2	forum	2	0
2	tracker	0	-1
2	tracker	1	0
2	tracker	2	0
2	tracker	3	0
2	tracker	4	0
2	docman	0	1
2	frs	0	0
2	scm	0	0
3	projectadmin	0	0
3	forum	0	-1
3	forum	1	1
3	forum	2	1
3	tracker	0	-1
3	tracker	1	1
3	tracker	2	1
3	tracker	3	1
3	tracker	4	1
3	docman	0	0
3	frs	0	0
3	scm	0	1
4	projectadmin	0	0
4	forum	0	-1
4	forum	1	1
4	forum	2	1
4	tracker	1	0
4	tracker	2	0
4	tracker	3	0
4	tracker	4	0
4	docman	0	0
4	frs	0	0
4	scm	0	0
5	projectadmin	0	0
5	forum	0	-1
5	forum	1	1
5	forum	2	1
5	tracker	0	3
5	docman	0	1
5	frs	0	1
5	scm	0	0
6	projectadmin	0	0
6	forum	0	-1
6	forum	1	1
6	forum	2	1
6	tracker	0	-1
6	tracker	1	1
6	tracker	2	1
6	tracker	3	1
6	tracker	4	1
6	docman	0	0
6	frs	0	0
6	scm	0	0
7	projectadmin	0	0
7	forum	0	-1
7	forum	1	1
7	forum	2	1
7	tracker	0	-1
7	tracker	1	1
7	tracker	2	1
7	tracker	3	1
7	tracker	4	1
7	docman	0	0
7	frs	0	0
7	scm	0	1
8	projectadmin	0	0
8	forum	0	-1
8	forum	1	0
8	forum	2	0
8	tracker	0	-1
8	tracker	1	0
8	tracker	2	2
8	tracker	3	0
8	tracker	4	0
8	docman	0	0
8	frs	0	0
8	scm	0	0
9	projectadmin	0	1
9	tracker	0	3
9	tracker	5	2
9	tracker	6	2
9	tracker	7	2
9	tracker	8	2
10	projectadmin	0	0
10	forum	0	-1
10	forum	3	0
10	forum	4	0
10	tracker	0	-1
10	tracker	5	0
10	tracker	6	0
10	tracker	7	0
10	tracker	8	0
10	docman	0	1
10	frs	0	0
10	scm	0	0
11	projectadmin	0	0
11	forum	0	-1
11	forum	3	1
11	forum	4	1
11	tracker	0	-1
11	tracker	5	1
11	tracker	6	1
11	tracker	7	1
11	tracker	8	1
11	docman	0	0
11	frs	0	0
11	scm	0	1
12	projectadmin	0	0
12	forum	0	-1
12	forum	3	1
12	forum	4	1
12	tracker	0	3
12	tracker	5	0
12	tracker	6	0
12	tracker	7	0
12	tracker	8	0
12	docman	0	0
12	frs	0	0
12	scm	0	0
4	tracker	0	3
13	projectadmin	0	0
13	forum	0	-1
13	forum	3	1
13	forum	4	1
13	tracker	0	3
13	docman	0	1
13	frs	0	1
13	scm	0	0
14	projectadmin	0	0
14	forum	0	-1
14	forum	3	1
14	forum	4	1
14	tracker	0	-1
14	tracker	5	1
14	tracker	6	1
14	tracker	7	1
14	tracker	8	1
14	docman	0	0
14	frs	0	0
14	scm	0	0
15	projectadmin	0	0
15	forum	0	-1
15	forum	3	1
15	forum	4	1
15	tracker	0	-1
15	tracker	5	1
15	tracker	6	1
15	tracker	7	1
15	tracker	8	1
15	docman	0	0
15	frs	0	0
15	scm	0	1
16	projectadmin	0	0
16	forum	0	-1
16	forum	3	0
16	forum	4	0
16	tracker	0	-1
16	tracker	5	0
16	tracker	6	2
16	tracker	7	0
16	tracker	8	0
16	docman	0	0
16	frs	0	0
16	scm	0	0
17	projectadmin	0	1
3	tracker	9	1
6	tracker	9	1
7	tracker	9	1
9	tracker	10	1
10	tracker	10	1
11	tracker	10	1
12	tracker	10	1
13	tracker	10	1
14	tracker	10	1
15	tracker	10	1
16	tracker	10	1
11	tracker	11	1
14	tracker	11	1
15	tracker	11	1
1	tracker	9	2
2	tracker	9	0
4	tracker	9	0
8	tracker	9	0
9	forum	0	2
9	forum	3	2
9	forum	4	2
9	tracker	11	2
9	docman	0	1
9	frs	0	1
9	scm	0	1
10	tracker	11	0
12	tracker	11	0
16	tracker	11	0
1	forum	0	2
1	forum	1	2
1	forum	2	2
1	docman	0	1
1	frs	0	1
1	scm	0	1
5	tracker	1	2
5	tracker	2	2
5	tracker	3	2
5	tracker	4	2
5	tracker	9	2
13	tracker	5	2
13	tracker	6	2
13	tracker	7	2
13	tracker	8	2
13	tracker	11	2
\.


--
-- Data for TOC entry 318 (OID 95032)
-- Name: user_project; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_project (user_id, project_id, join_date, user_project_id) FROM stdin;
\.


--
-- Data for TOC entry 319 (OID 95036)
-- Name: user_preference; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_preference (user_id, preference_name, set_date, preference_value) FROM stdin;
\.


--
-- Data for TOC entry 320 (OID 95044)
-- Name: tracker; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker (tracker_id, project_id, tracker_name, description, is_public, restrict_browse, email_all_updates, email_address, due_period, submit_instructions, browse_instructions, datatype, item_total, open_count) FROM stdin;
1	2	Bugs	Bug Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
2	2	Support	Tech Support Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
3	2	Patches	Patch Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
4	2	Feature Requests	Feature Request Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
5	3	Bugs	Bug Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
6	3	Support	Tech Support Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
7	3	Patches	Patch Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
8	3	Feature Requests	Feature Request Tracking System	t	t	f	\N	2592000	Y	\N	1	0	0
9	2	To-Do	To-Do tasks for this project	t	f	f		1296000			2	0	0
11	3	To-Do	To-Do tasks for this project	t	f	f		1296000			2	0	0
\.


--
-- Data for TOC entry 321 (OID 95058)
-- Name: tracker_item; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item (tracker_item_id, tracker_id, status_id, priority, submitted_by, open_date, close_date, summary, details, last_modified_date, last_modified_by, sort_order, parent_id) FROM stdin;
\.


--
-- Data for TOC entry 322 (OID 95073)
-- Name: tracker_time_code; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_time_code (tracker_time_code_id, time_name) FROM stdin;
\.


--
-- Data for TOC entry 323 (OID 95081)
-- Name: tracker_item_time; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item_time (tracker_item_time_id, date_entry, user_id, tracker_item_id, hours, tracker_time_code_id) FROM stdin;
\.


--
-- Data for TOC entry 324 (OID 95085)
-- Name: tracker_item_relation; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item_relation (tracker_item_id, related_tracker_item_id, link_type) FROM stdin;
\.


--
-- Data for TOC entry 325 (OID 95088)
-- Name: tracker_item_assignee; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item_assignee (tracker_item_id, assignee, percent_utilization) FROM stdin;
\.


--
-- Data for TOC entry 326 (OID 95093)
-- Name: tracker_item_message; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item_message (tracker_item_message_id, tracker_item_id, submitted_by, adddate, body) FROM stdin;
\.


--
-- Data for TOC entry 327 (OID 95102)
-- Name: tracker_canned_response; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_canned_response (tracker_canned_response_id, tracker_id, title, body) FROM stdin;
\.


--
-- Data for TOC entry 328 (OID 95112)
-- Name: notification_queue; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY notification_queue (notification_queue_id, section, ref_id, user_id, subject, body, queue_date, send_date) FROM stdin;
\.


--
-- Data for TOC entry 329 (OID 95120)
-- Name: scm_user_stats; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_user_stats (stat_date, project_id, user_id, checkouts, commits, adds) FROM stdin;
\.


--
-- Data for TOC entry 330 (OID 95122)
-- Name: scm_project_stats; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_project_stats (stat_date, project_id, checkouts, commits, adds) FROM stdin;
\.


--
-- Data for TOC entry 331 (OID 95124)
-- Name: activity_log; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY activity_log (activity_date, project_id, page, activity_type) FROM stdin;
\.


--
-- Data for TOC entry 332 (OID 95134)
-- Name: plugin; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY plugin (plugin_id, plugin_name, plugin_desc, plugin_type, plugin_order, exclusive_type) FROM stdin;
1	forum	Forum	project	1	\N
2	tracker	Tracker	project	2	\N
3	docman	Document manager	project	3	\N
4	news	News	project	4	\N
5	frs	File Release System	project	6	\N
6	mailman	Mailing lists	project	8	\N
7	scmcvs	CVS repository	project	9	scm
8	scmsvn	SVN repository	project	10	scm
9	snippet	Code snippets	site	1	\N
10	wiki	Wiki	project	9	\N
11	cruisecontrol	Cruise Control	project	13	\N
12	scmvss	VSS Skeleton	project	14	scm
13	scmcc	Clear Case Skeleton	project	14	scm
14	xmlcompatibility	XML Compatibility	site	2	\N
15	userwiki	User wiki	user	1	\N
16	userfiles	User files	user	2	\N
\.


--
-- Data for TOC entry 333 (OID 95141)
-- Name: plugin_dependency; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY plugin_dependency (plugin_id, dependson_plugin_id) FROM stdin;
\.


--
-- Data for TOC entry 334 (OID 95143)
-- Name: project_plugin; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY project_plugin (project_id, plugin_id, plugin_order) FROM stdin;
2	1	1
2	2	2
2	3	3
2	4	4
2	5	5
2	6	6
2	7	7
3	8	7
3	1	1
3	2	2
3	3	3
3	4	4
3	5	5
3	6	6
\.


--
-- Data for TOC entry 335 (OID 95145)
-- Name: user_plugin; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_plugin (user_id, plugin_id, plugin_order) FROM stdin;
\.


--
-- Data for TOC entry 336 (OID 95148)
-- Name: user_relation; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_relation (user_id, related_user_id) FROM stdin;
\.


--
-- Data for TOC entry 337 (OID 95150)
-- Name: user_watched_project; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_watched_project (user_id, project_id) FROM stdin;
\.


--
-- Data for TOC entry 338 (OID 95152)
-- Name: cron_history; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cron_history (rundate, job, output) FROM stdin;
\.


--
-- Data for TOC entry 339 (OID 95160)
-- Name: tracker_extra_field; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field (tracker_extra_field_id, tracker_id, field_name, field_type, attribute1, attribute2, is_required, alias, field_order, use_in_quick_browse, show_on_submit, use_auto_assign, use_workflow) FROM stdin;
22	5	Hardware	1	0	0	f	hardware	1	f	t	f	f
23	5	Product	1	0	0	f	product	2	f	t	f	f
24	5	Operating System	1	0	0	f	operating_system	3	f	t	f	f
25	5	Component	1	0	0	f	component	4	f	t	f	f
27	5	Severity	1	0	0	f	severity	6	f	t	f	f
28	5	Resolution	1	0	0	f	resolution	7	f	t	f	f
29	5	URL	4	40	100	f	url	8	f	t	f	f
30	6	Hardware	1	0	0	f	hardware	1	f	t	f	f
31	6	Product	1	0	0	f	product	2	f	t	f	f
32	6	Operating System	1	0	0	f	operating_system	3	f	t	f	f
33	6	Component	1	0	0	f	component	4	f	t	f	f
35	6	Severity	1	0	0	f	severity	6	f	t	f	f
36	6	URL	4	40	100	f	url	7	f	t	f	f
37	7	Component	1	0	0	f	component	1	f	t	f	f
39	7	Resolution	1	0	0	f	resolution	3	f	t	f	f
40	8	Product	1	0	0	f	product	1	f	t	f	f
41	8	Operating System	1	0	0	f	operating_system	2	f	t	f	f
42	8	Component	1	0	0	f	component	3	f	t	f	f
43	1	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
44	1	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
45	1	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
46	1	Status	7	0	0	t	status	0	t	t	f	f
47	2	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
48	2	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
49	2	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
50	2	Status	7	0	0	t	status	0	t	t	f	f
51	3	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
52	3	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
53	3	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
54	3	Status	7	0	0	t	status	0	t	t	f	f
55	4	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
56	4	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
57	4	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
58	4	Status	7	0	0	t	status	0	t	t	f	f
59	5	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
60	5	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
61	5	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
62	5	Status	7	0	0	t	status	0	t	t	f	f
63	6	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
64	6	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
65	6	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
66	6	Status	7	0	0	t	status	0	t	t	f	f
67	7	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
68	7	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
69	7	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
70	7	Status	7	0	0	t	status	0	t	t	f	f
71	8	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
72	8	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
73	8	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
74	8	Status	7	0	0	t	status	0	t	t	f	f
1	1	Hardware	1	0	0	f	hardware	1	f	t	f	f
2	1	Product	1	0	0	f	product	2	f	t	f	f
3	1	Operating System	1	0	0	f	operating_system	3	f	t	f	f
4	1	Component	1	0	0	f	component	4	f	t	f	f
6	1	Severity	1	0	0	f	severity	6	f	t	f	f
7	1	Resolution	1	0	0	f	resolution	7	f	t	f	f
9	2	Hardware	1	0	0	f	hardware	1	f	t	f	f
10	2	Product	1	0	0	f	product	2	f	t	f	f
14	2	Severity	1	0	0	f	severity	6	f	t	f	f
11	2	Operating System	1	0	0	f	operating_system	3	f	t	f	f
12	2	Component	1	0	0	f	component	4	f	t	f	f
16	3	Component	1	0	0	f	component	1	f	t	f	f
18	3	Resolution	1	0	0	f	resolution	3	f	t	f	f
19	4	Product	1	0	0	f	product	1	f	t	f	f
20	4	Operating System	1	0	0	f	operating_system	2	f	t	f	f
21	4	Component	1	0	0	f	component	3	f	t	f	f
15	2	URL	4	40	100	f	url	7	f	t	f	f
8	1	URL	4	40	100	f	url	8	f	t	f	f
75	1	Found In Release	8	0	0	f	foundinrelease	0	f	t	f	f
76	5	Found In Release	8	0	0	f	foundinrelease	0	f	t	f	f
77	1	Fixed In Release	8	0	0	f	fixedinrelease	0	f	t	f	f
78	5	Fixed In Release	8	0	0	f	fixedinrelease	0	f	t	f	f
79	9	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
80	9	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
81	9	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
82	9	Status	7	0	0	t	status	0	t	t	f	f
87	11	Duration (Days)	4	3	3	f	duration	0	f	t	f	f
88	11	Percent Complete (0-100)	4	3	3	f	percentcomplete	0	f	t	f	f
89	11	Estimated Effort (Hours)	4	4	4	f	estimatedeffort	0	f	t	f	f
90	11	Status	7	0	0	t	status	0	t	t	f	f
\.


--
-- Data for TOC entry 340 (OID 95176)
-- Name: tracker_extra_field_element; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_element (element_id, tracker_extra_field_id, element_name, status_id, default_selected, sort_order, auto_assign_to) FROM stdin;
2	1	Sun	0	f	2	100
3	1	SGI	0	f	3	100
4	1	PC	0	f	4	100
5	1	Macintosh	0	f	5	100
6	1	HP	0	f	6	100
7	1	DEC	0	f	7	100
8	1	All	0	f	8	100
11	3	Windows 3.1	0	f	2	100
12	3	Windows 95	0	f	3	100
13	3	Windows 98	0	f	4	100
14	3	Windows ME	0	f	5	100
15	3	Windows 2000	0	f	6	100
16	3	Windows NT	0	f	7	100
17	3	Windows XP	0	f	8	100
18	3	Windows Server 2003	0	f	9	100
19	3	Mac System 7	0	f	10	100
20	3	Mac System 7.5	0	f	11	100
21	3	Mac System 7.6.1	0	f	12	100
22	3	Mac System 8.0	0	f	13	100
23	3	Mac System 8.5	0	f	14	100
24	3	Mac System 8.6	0	f	15	100
25	3	Mac System 9.x	0	f	16	100
26	3	MacOS X	0	f	17	100
27	3	Linux	0	f	18	100
28	3	BSDI	0	f	19	100
29	3	FreeBSD	0	f	20	100
30	3	NetBSD	0	f	21	100
31	3	OpenBSD	0	f	22	100
32	3	AIX	0	f	23	100
33	3	BeOS	0	f	24	100
34	3	HP-UX	0	f	25	100
35	3	IRIX	0	f	26	100
36	3	Neutrino	0	f	27	100
37	3	OpenVMS	0	f	28	100
38	3	OS/2	0	f	29	100
39	3	OSF/1	0	f	30	100
40	3	Solaris	0	f	31	100
41	3	SunOS	0	f	32	100
42	3	other	0	f	33	100
44	4	Cog A	0	f	2	100
48	6	trivial	0	f	2	100
49	6	minor	0	f	3	100
50	6	normal	0	f	4	100
51	6	major	0	f	5	100
52	6	critical	0	f	6	100
53	6	blocker	0	f	7	100
55	7	Awaiting Response	0	f	2	100
56	7	Invalid	0	f	3	100
57	7	Won't Fix	0	f	4	100
58	7	Fixed	0	f	5	100
59	7	Accepted As Bug	0	f	6	100
61	9	Sun	0	f	2	100
62	9	SGI	0	f	3	100
63	9	PC	0	f	4	100
64	9	Macintosh	0	f	5	100
65	9	HP	0	f	6	100
66	9	DEC	0	f	7	100
67	9	All	0	f	8	100
70	11	Windows 3.1	0	f	2	100
71	11	Windows 95	0	f	3	100
72	11	Windows 98	0	f	4	100
73	11	Windows ME	0	f	5	100
74	11	Windows 2000	0	f	6	100
75	11	Windows NT	0	f	7	100
76	11	Windows XP	0	f	8	100
77	11	Windows Server 2003	0	f	9	100
78	11	Mac System 7	0	f	10	100
79	11	Mac System 7.5	0	f	11	100
80	11	Mac System 7.6.1	0	f	12	100
81	11	Mac System 8.0	0	f	13	100
82	11	Mac System 8.5	0	f	14	100
83	11	Mac System 8.6	0	f	15	100
84	11	Mac System 9.x	0	f	16	100
85	11	MacOS X	0	f	17	100
86	11	Linux	0	f	18	100
87	11	BSDI	0	f	19	100
88	11	FreeBSD	0	f	20	100
89	11	NetBSD	0	f	21	100
90	11	OpenBSD	0	f	22	100
91	11	AIX	0	f	23	100
92	11	BeOS	0	f	24	100
93	11	HP-UX	0	f	25	100
94	11	IRIX	0	f	26	100
95	11	Neutrino	0	f	27	100
96	11	OpenVMS	0	f	28	100
97	11	OS/2	0	f	29	100
98	11	OSF/1	0	f	30	100
99	11	Solaris	0	f	31	100
329	11	SunOS	0	f	32	100
101	11	other	0	f	33	100
103	12	Cog A	0	f	2	100
107	14	trivial	0	f	2	100
108	14	minor	0	f	3	100
109	14	normal	0	f	4	100
110	14	major	0	f	5	100
111	14	critical	0	f	6	100
112	14	blocker	0	f	7	100
114	16	Cog A	0	f	2	100
118	18	Out of Date	0	f	2	100
119	18	Rejected	0	f	3	100
120	18	Accepted	0	f	4	100
123	20	Windows 3.1	0	f	2	100
124	20	Windows 95	0	f	3	100
125	20	Windows 98	0	f	4	100
126	20	Windows ME	0	f	5	100
127	20	Windows 2000	0	f	6	100
128	20	Windows NT	0	f	7	100
129	20	Windows XP	0	f	8	100
130	20	Windows Server 2003	0	f	9	100
131	20	Mac System 7	0	f	10	100
132	20	Mac System 7.5	0	f	11	100
133	20	Mac System 7.6.1	0	f	12	100
134	20	Mac System 8.0	0	f	13	100
135	20	Mac System 8.5	0	f	14	100
136	20	Mac System 8.6	0	f	15	100
137	20	Mac System 9.x	0	f	16	100
138	20	MacOS X	0	f	17	100
139	20	Linux	0	f	18	100
140	20	BSDI	0	f	19	100
141	20	FreeBSD	0	f	20	100
142	20	NetBSD	0	f	21	100
143	20	OpenBSD	0	f	22	100
144	20	AIX	0	f	23	100
145	20	BeOS	0	f	24	100
146	20	HP-UX	0	f	25	100
147	20	IRIX	0	f	26	100
148	20	Neutrino	0	f	27	100
149	20	OpenVMS	0	f	28	100
150	20	OS/2	0	f	29	100
151	20	OSF/1	0	f	30	100
152	20	Solaris	0	f	31	100
153	20	SunOS	0	f	32	100
154	20	other	0	f	33	100
156	21	Cog A	0	f	2	100
158	22	Sun	0	f	2	100
159	22	SGI	0	f	3	100
160	22	PC	0	f	4	100
161	22	Macintosh	0	f	5	100
162	22	HP	0	f	6	100
163	22	DEC	0	f	7	100
164	22	All	0	f	8	100
167	24	Windows 3.1	0	f	2	100
168	24	Windows 95	0	f	3	100
169	24	Windows 98	0	f	4	100
170	24	Windows ME	0	f	5	100
171	24	Windows 2000	0	f	6	100
172	24	Windows NT	0	f	7	100
173	24	Windows XP	0	f	8	100
174	24	Windows Server 2003	0	f	9	100
175	24	Mac System 7	0	f	10	100
176	24	Mac System 7.5	0	f	11	100
177	24	Mac System 7.6.1	0	f	12	100
178	24	Mac System 8.0	0	f	13	100
179	24	Mac System 8.5	0	f	14	100
180	24	Mac System 8.6	0	f	15	100
181	24	Mac System 9.x	0	f	16	100
182	24	MacOS X	0	f	17	100
183	24	Linux	0	f	18	100
184	24	BSDI	0	f	19	100
185	24	FreeBSD	0	f	20	100
186	24	NetBSD	0	f	21	100
187	24	OpenBSD	0	f	22	100
188	24	AIX	0	f	23	100
189	24	BeOS	0	f	24	100
190	24	HP-UX	0	f	25	100
191	24	IRIX	0	f	26	100
192	24	Neutrino	0	f	27	100
193	24	OpenVMS	0	f	28	100
194	24	OS/2	0	f	29	100
195	24	OSF/1	0	f	30	100
196	24	Solaris	0	f	31	100
197	24	SunOS	0	f	32	100
198	24	other	0	f	33	100
200	25	Cog A	0	f	2	100
204	27	trivial	0	f	2	100
205	27	minor	0	f	3	100
206	27	normal	0	f	4	100
207	27	major	0	f	5	100
208	27	critical	0	f	6	100
209	27	blocker	0	f	7	100
211	28	Awaiting Response	0	f	2	100
212	28	Invalid	0	f	3	100
213	28	Won't Fix	0	f	4	100
214	28	Fixed	0	f	5	100
215	28	Accepted As Bug	0	f	6	100
217	30	Sun	0	f	2	100
218	30	SGI	0	f	3	100
219	30	PC	0	f	4	100
220	30	Macintosh	0	f	5	100
221	30	HP	0	f	6	100
222	30	DEC	0	f	7	100
223	30	All	0	f	8	100
226	32	Windows 3.1	0	f	2	100
227	32	Windows 95	0	f	3	100
228	32	Windows 98	0	f	4	100
229	32	Windows ME	0	f	5	100
230	32	Windows 2000	0	f	6	100
231	32	Windows NT	0	f	7	100
232	32	Windows XP	0	f	8	100
233	32	Windows Server 2003	0	f	9	100
234	32	Mac System 7	0	f	10	100
235	32	Mac System 7.5	0	f	11	100
236	32	Mac System 7.6.1	0	f	12	100
237	32	Mac System 8.0	0	f	13	100
238	32	Mac System 8.5	0	f	14	100
239	32	Mac System 8.6	0	f	15	100
240	32	Mac System 9.x	0	f	16	100
241	32	MacOS X	0	f	17	100
242	32	Linux	0	f	18	100
243	32	BSDI	0	f	19	100
244	32	FreeBSD	0	f	20	100
245	32	NetBSD	0	f	21	100
246	32	OpenBSD	0	f	22	100
247	32	AIX	0	f	23	100
248	32	BeOS	0	f	24	100
249	32	HP-UX	0	f	25	100
250	32	IRIX	0	f	26	100
251	32	Neutrino	0	f	27	100
252	32	OpenVMS	0	f	28	100
253	32	OS/2	0	f	29	100
254	32	OSF/1	0	f	30	100
255	32	Solaris	0	f	31	100
256	32	SunOS	0	f	32	100
257	32	other	0	f	33	100
259	33	Cog A	0	f	2	100
263	35	trivial	0	f	2	100
264	35	minor	0	f	3	100
265	35	normal	0	f	4	100
266	35	major	0	f	5	100
267	35	critical	0	f	6	100
268	35	blocker	0	f	7	100
270	37	Cog A	0	f	2	100
274	39	Out of Date	0	f	2	100
275	39	Rejected	0	f	3	100
276	39	Accepted	0	f	4	100
279	41	Windows 3.1	0	f	2	100
280	41	Windows 95	0	f	3	100
281	41	Windows 98	0	f	4	100
282	41	Windows ME	0	f	5	100
283	41	Windows 2000	0	f	6	100
284	41	Windows NT	0	f	7	100
285	41	Windows XP	0	f	8	100
286	41	Windows Server 2003	0	f	9	100
287	41	Mac System 7	0	f	10	100
288	41	Mac System 7.5	0	f	11	100
289	41	Mac System 7.6.1	0	f	12	100
290	41	Mac System 8.0	0	f	13	100
291	41	Mac System 8.5	0	f	14	100
292	41	Mac System 8.6	0	f	15	100
293	41	Mac System 9.x	0	f	16	100
294	41	MacOS X	0	f	17	100
295	41	Linux	0	f	18	100
296	41	BSDI	0	f	19	100
297	41	FreeBSD	0	f	20	100
298	41	NetBSD	0	f	21	100
299	41	OpenBSD	0	f	22	100
300	41	AIX	0	f	23	100
301	41	BeOS	0	f	24	100
302	41	HP-UX	0	f	25	100
303	41	IRIX	0	f	26	100
304	41	Neutrino	0	f	27	100
305	41	OpenVMS	0	f	28	100
306	41	OS/2	0	f	29	100
307	41	OSF/1	0	f	30	100
308	41	Solaris	0	f	31	100
309	41	SunOS	0	f	32	100
310	41	other	0	f	33	100
312	42	Cog A	0	f	2	100
1	1	Other	0	f	1	100
9	2	Software A	0	f	1	100
10	3	All	0	f	1	100
43	4	Cog B	0	f	1	100
47	6	enhancement	0	f	1	100
54	7	Works For Me	0	f	1	100
60	9	Other	0	f	1	100
68	10	Software A	0	f	1	100
69	11	All	0	f	1	100
102	12	Cog B	0	f	1	100
106	14	enhancement	0	f	1	100
113	16	Cog B	0	f	1	100
117	18	Awaiting Response	0	f	1	100
121	19	Software A	0	f	1	100
122	20	All	0	f	1	100
155	21	Cog B	0	f	1	100
157	22	Other	0	f	1	100
165	23	Software A	0	f	1	100
166	24	All	0	f	1	100
199	25	Cog B	0	f	1	100
203	27	enhancement	0	f	1	100
210	28	Works For Me	0	f	1	100
216	30	Other	0	f	1	100
224	31	Software A	0	f	1	100
225	32	All	0	f	1	100
258	33	Cog B	0	f	1	100
262	35	enhancement	0	f	1	100
269	37	Cog B	0	f	1	100
273	39	Awaiting Response	0	f	1	100
277	40	Software A	0	f	1	100
278	41	All	0	f	1	100
311	42	Cog B	0	f	1	100
313	46	Open	1	t	1	100
315	50	Open	1	t	1	100
317	54	Open	1	t	1	100
319	58	Open	1	t	1	100
321	62	Open	1	t	1	100
323	66	Open	1	t	1	100
325	70	Open	1	t	1	100
327	74	Open	1	t	1	100
314	46	Closed	0	f	2	100
316	50	Closed	0	f	2	100
318	54	Closed	0	f	2	100
320	58	Closed	0	f	2	100
322	62	Closed	0	f	2	100
324	66	Closed	0	f	2	100
326	70	Closed	0	f	2	100
328	74	Closed	0	f	2	100
330	82	Open	1	t	1	100
331	82	Closed	0	f	2	100
334	90	Open	1	t	1	100
335	90	Closed	0	f	2	100
\.


--
-- Data for TOC entry 341 (OID 95188)
-- Name: tracker_extra_field_data; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_data (tracker_extra_field_data_id, tracker_item_id, field_data, tracker_extra_field_id) FROM stdin;
\.


--
-- Data for TOC entry 342 (OID 95194)
-- Name: project_join_request; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY project_join_request (project_id, user_id, comments, request_date) FROM stdin;
\.


--
-- Data for TOC entry 343 (OID 95203)
-- Name: scm_module; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_module (scm_module_id, project_id, "path") FROM stdin;
\.


--
-- Data for TOC entry 344 (OID 95209)
-- Name: scm_preference; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_preference (project_id, require_tracker_item_id, mail_commits) FROM stdin;
\.


--
-- Data for TOC entry 345 (OID 95215)
-- Name: scm_commit; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_commit (scm_commit_id, project_id, commit_date, message_log, user_id) FROM stdin;
\.


--
-- Data for TOC entry 346 (OID 95222)
-- Name: tracker_item_scm_commit; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_item_scm_commit (tracker_item_id, scm_commit_id) FROM stdin;
\.


--
-- Data for TOC entry 347 (OID 95224)
-- Name: scm_commit_file; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_commit_file (scm_commit_id, modified_file, prev_version, new_version) FROM stdin;
\.


--
-- Data for TOC entry 348 (OID 95231)
-- Name: tracker_query; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_query (tracker_query_id, tracker_id, user_id, query_name, is_shared) FROM stdin;
\.


--
-- Data for TOC entry 349 (OID 95238)
-- Name: tracker_query_field; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_query_field (tracker_query_id, query_field_type, query_field_id, query_field_values) FROM stdin;
\.


--
-- Data for TOC entry 350 (OID 95245)
-- Name: wiki_page; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY wiki_page (wiki_page_id, section, ref_id, pagename, flags, latest_version) FROM stdin;
\.


--
-- Data for TOC entry 351 (OID 95250)
-- Name: wiki_version; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY wiki_version (wiki_version_id, wiki_page_id, page_version, posted_by, refs, last_modified_date, score, hits, create_date) FROM stdin;
\.


--
-- Data for TOC entry 352 (OID 95257)
-- Name: wiki_page_link; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY wiki_page_link (from_wiki_page_id, to_wiki_page_id) FROM stdin;
\.


--
-- Data for TOC entry 353 (OID 95263)
-- Name: trove_link_count; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY trove_link_count (trove_category_id, section, link_count) FROM stdin;
\.


--
-- Data for TOC entry 354 (OID 95267)
-- Name: docman_file; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY docman_file (docman_file_id, docman_folder_id, description, is_locked) FROM stdin;
\.


--
-- Data for TOC entry 355 (OID 95276)
-- Name: docman_file_version; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY docman_file_version (docman_file_version_id, docman_file_id, create_date, changes, version_number, created_by) FROM stdin;
\.


--
-- Data for TOC entry 356 (OID 95283)
-- Name: scm_module_user; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY scm_module_user (scm_module_id, user_id, "access") FROM stdin;
\.


--
-- Data for TOC entry 357 (OID 95286)
-- Name: cruisecontrol; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol (project_id, builder, log_type, developer, last_modified_date) FROM stdin;
\.


--
-- Data for TOC entry 358 (OID 95292)
-- Name: cruisecontrol_publisher; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_publisher (project_id, tracker_id) FROM stdin;
\.


--
-- Data for TOC entry 359 (OID 95294)
-- Name: cruisecontrol_assignee; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_assignee (project_id, assignee) FROM stdin;
\.


--
-- Data for TOC entry 360 (OID 95296)
-- Name: cruisecontrol_preference; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_preference (project_id, name, value) FROM stdin;
\.


--
-- Data for TOC entry 361 (OID 95301)
-- Name: cruisecontrol_module; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_module (project_id, scm_module_id) FROM stdin;
\.


--
-- Data for TOC entry 362 (OID 95303)
-- Name: database_changes; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY database_changes (filename, filedate) FROM stdin;
20060612.sql	20060612
20060623.sql	20060623
20060626.sql	20060626
20060627.sql	20060627
20060630.sql	20060630
20060701.sql	20060701
20060704.sql	20060704
20060708.sql	20060708
20060710.sql	20060710
20060713.sql	20060713
20060716.sql	20060716
20060717.sql	20060717
20060720.sql	20060720
20060725.sql	20060725
20060727.sql	20060727
20060802.sql	20060802
20060810.sql	20060810
20060811.sql	20060811
20060814.sql	20060814
20060822.sql	20060822
\.


--
-- Data for TOC entry 363 (OID 95310)
-- Name: tracker_extra_field_element_transition; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_element_transition (tracker_extra_field_element_transition_id, element_id, to_element_id, notification_message) FROM stdin;
\.


--
-- Data for TOC entry 364 (OID 95316)
-- Name: tracker_extra_field_element_transition_role; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_element_transition_role (tracker_extra_field_element_transition_id, role_id) FROM stdin;
\.


--
-- Data for TOC entry 365 (OID 95318)
-- Name: tracker_extra_field_element_transition_field; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_element_transition_field (tracker_extra_field_element_transition_id, required_tracker_extra_field_id) FROM stdin;
\.


--
-- Data for TOC entry 366 (OID 95320)
-- Name: project_activity; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY project_activity (activity_date, project_id, measure) FROM stdin;
\.


--
-- Data for TOC entry 367 (OID 95322)
-- Name: tracker_extra_field_element_transition_notify; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY tracker_extra_field_element_transition_notify (tracker_extra_field_element_transition_id, role_id) FROM stdin;
\.


--
-- Data for TOC entry 368 (OID 95326)
-- Name: user_project_role; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY user_project_role (user_project_id, role_id) FROM stdin;
\.


--
-- Data for TOC entry 369 (OID 95330)
-- Name: cruisecontrol_platform; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_platform (cruisecontrol_platform_id, project_id, name) FROM stdin;
\.


--
-- Data for TOC entry 370 (OID 95336)
-- Name: cruisecontrol_platform_tracker_item; Type: TABLE DATA; Schema: public; Owner: gforge
--

COPY cruisecontrol_platform_tracker_item (cruisecontrol_platform_id, tracker_item_id) FROM stdin;
\.


--
-- TOC entry 149 (OID 96627)
-- Name: filesystem_sectionrefid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX filesystem_sectionrefid ON filesystem USING btree (section, ref_id);


--
-- TOC entry 153 (OID 96628)
-- Name: audit_trail_idx; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX audit_trail_idx ON audit_trail USING btree (section, ref_id);


--
-- TOC entry 159 (OID 96629)
-- Name: docmanfolder_projectidparentfolder; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX docmanfolder_projectidparentfolder ON docman_folder USING btree (project_id, parent_folder_id);


--
-- TOC entry 162 (OID 96630)
-- Name: forum_sectionrefidispublic; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX forum_sectionrefidispublic ON forum USING btree (section, ref_id, is_public);


--
-- TOC entry 164 (OID 96631)
-- Name: forumthread_forumid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX forumthread_forumid ON forum_thread USING btree (forum_id);


--
-- TOC entry 167 (OID 96632)
-- Name: forummessage_threadidpostdate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX forummessage_threadidpostdate ON forum_message USING btree (forum_thread_id, post_date);


--
-- TOC entry 169 (OID 96633)
-- Name: userblog_useridpostdate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX userblog_useridpostdate ON user_blog USING btree (user_id, post_date);


--
-- TOC entry 171 (OID 96634)
-- Name: frspackage_projectid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX frspackage_projectid ON frs_package USING btree (project_id, package_name);


--
-- TOC entry 173 (OID 96635)
-- Name: frsrelease_packageidreleasename; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX frsrelease_packageidreleasename ON frs_release USING btree (frs_package_id, release_name);


--
-- TOC entry 174 (OID 96636)
-- Name: filesystemdownload_filesystemiddownloaddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX filesystemdownload_filesystemiddownloaddate ON filesystem_download USING btree (filesystem_id, download_date);


--
-- TOC entry 177 (OID 96637)
-- Name: mailman_projectidlistname; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX mailman_projectidlistname ON mailman USING btree (project_id, list_name);


--
-- TOC entry 179 (OID 96638)
-- Name: news_projectidpostdate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX news_projectidpostdate ON news USING btree (project_id, post_date);


--
-- TOC entry 183 (OID 96639)
-- Name: surveyquestion_projectid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX surveyquestion_projectid ON survey_question USING btree (project_id);


--
-- TOC entry 185 (OID 96640)
-- Name: survey_projectidactive; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX survey_projectidactive ON survey USING btree (project_id, is_active);


--
-- TOC entry 187 (OID 96641)
-- Name: surveyresponse_surveyidquestioniddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX surveyresponse_surveyidquestioniddate ON survey_response USING btree (survey_id, question_id, post_date);


--
-- TOC entry 189 (OID 96642)
-- Name: trovecat_parenttroveidtroveid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trovecat_parenttroveidtroveid ON trove_category USING btree (parent_trove_category_id, trove_category_id);


--
-- TOC entry 191 (OID 96643)
-- Name: trovelink_trovecatid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trovelink_trovecatid ON trove_link USING btree (trove_category_id);


--
-- TOC entry 193 (OID 96644)
-- Name: role_projectidrolename; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX role_projectidrolename ON role USING btree (project_id, role_name);


--
-- TOC entry 199 (OID 96645)
-- Name: tracker_projectiddatatypeispublic; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX tracker_projectiddatatypeispublic ON tracker USING btree (project_id, datatype, is_public);


--
-- TOC entry 207 (OID 96646)
-- Name: trackeritem_trackeridstatusid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_trackeridstatusid ON tracker_item USING btree (tracker_id, status_id, tracker_item_id);


--
-- TOC entry 208 (OID 96647)
-- Name: trackeritem_trackeridsubmittedbystatusid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_trackeridsubmittedbystatusid ON tracker_item USING btree (tracker_id, submitted_by, status_id, tracker_item_id);


--
-- TOC entry 212 (OID 96648)
-- Name: trackeritemrelation_relatedtrackeritemidtrackeritemid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritemrelation_relatedtrackeritemidtrackeritemid ON tracker_item_relation USING btree (related_tracker_item_id, tracker_item_id);


--
-- TOC entry 214 (OID 96649)
-- Name: trackeritemassignee_assigneetrackeritemid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritemassignee_assigneetrackeritemid ON tracker_item_assignee USING btree (assignee, tracker_item_id);


--
-- TOC entry 216 (OID 96650)
-- Name: trackermessage_trackeritemidaddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackermessage_trackeritemidaddate ON tracker_item_message USING btree (tracker_item_id, adddate);


--
-- TOC entry 218 (OID 96651)
-- Name: trackercannedresponse_trackerid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackercannedresponse_trackerid ON tracker_canned_response USING btree (tracker_id);


--
-- TOC entry 229 (OID 96652)
-- Name: trackerextrafield_trackeridfieldorder; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackerextrafield_trackeridfieldorder ON tracker_extra_field USING btree (tracker_id, field_order);


--
-- TOC entry 231 (OID 96653)
-- Name: trackerextrafieldelement_trackerextrafieldidsortorder; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackerextrafieldelement_trackerextrafieldidsortorder ON tracker_extra_field_element USING btree (tracker_extra_field_id, sort_order);


--
-- TOC entry 233 (OID 96654)
-- Name: trackerextrafielddata_extrafieldidtrackeritem; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackerextrafielddata_extrafieldidtrackeritem ON tracker_extra_field_data USING btree (tracker_item_id, tracker_extra_field_id);


--
-- TOC entry 240 (OID 96655)
-- Name: trackeritemscmcommit_trackeritemidscmcommitid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX trackeritemscmcommit_trackeritemidscmcommitid ON tracker_item_scm_commit USING btree (tracker_item_id, scm_commit_id);


--
-- TOC entry 243 (OID 96656)
-- Name: trackerquery_trackeriduserid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackerquery_trackeriduserid ON tracker_query USING btree (tracker_id, user_id);


--
-- TOC entry 246 (OID 96657)
-- Name: wikipage_secionrefidpagename; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX wikipage_secionrefidpagename ON wiki_page USING btree (section, ref_id, pagename);


--
-- TOC entry 248 (OID 96658)
-- Name: wikiversion_wikipageidpageversion; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX wikiversion_wikipageidpageversion ON wiki_version USING btree (wiki_page_id, page_version);


--
-- TOC entry 166 (OID 96659)
-- Name: forummessage_createdbypostdate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX forummessage_createdbypostdate ON forum_message USING btree (created_by, post_date);


--
-- TOC entry 239 (OID 96660)
-- Name: scmcommit_useridcommitdate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX scmcommit_useridcommitdate ON scm_commit USING btree (user_id, commit_date);


--
-- TOC entry 202 (OID 96661)
-- Name: trackeritem_lastmodbylastmoddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_lastmodbylastmoddate ON tracker_item USING btree (last_modified_by, last_modified_date);


--
-- TOC entry 201 (OID 96662)
-- Name: trackeritem_lastmodbyclosedate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_lastmodbyclosedate ON tracker_item USING btree (last_modified_by, close_date);


--
-- TOC entry 203 (OID 96663)
-- Name: trackeritem_submittedbyopendate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_submittedbyopendate ON tracker_item USING btree (submitted_by, open_date);


--
-- TOC entry 238 (OID 96664)
-- Name: scmcommit_projectiddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX scmcommit_projectiddate ON scm_commit USING btree (project_id, commit_date);


--
-- TOC entry 206 (OID 96665)
-- Name: trackeritem_trackeridopendate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_trackeridopendate ON tracker_item USING btree (tracker_id, open_date);


--
-- TOC entry 204 (OID 96666)
-- Name: trackeritem_trackeridclosedate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_trackeridclosedate ON tracker_item USING btree (tracker_id, close_date);


--
-- TOC entry 205 (OID 96667)
-- Name: trackeritem_trackeridlastmoddate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX trackeritem_trackeridlastmoddate ON tracker_item USING btree (tracker_id, last_modified_date);


--
-- TOC entry 252 (OID 96668)
-- Name: docmanfile_docmanfolderid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX docmanfile_docmanfolderid ON docman_file USING btree (docman_folder_id);


--
-- TOC entry 254 (OID 96669)
-- Name: docmanfileversion_docmanfileid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX docmanfileversion_docmanfileid ON docman_file_version USING btree (docman_file_version_id);


--
-- TOC entry 258 (OID 96670)
-- Name: cruisecontrolpublisher_projectidtrackerid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX cruisecontrolpublisher_projectidtrackerid ON cruisecontrol_publisher USING btree (project_id, tracker_id);


--
-- TOC entry 260 (OID 96671)
-- Name: cruisecontrolassignee_projectidassignee; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX cruisecontrolassignee_projectidassignee ON cruisecontrol_assignee USING btree (project_id, assignee);


--
-- TOC entry 263 (OID 96672)
-- Name: cruisecontrolmodule_projectidscmmoduleid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX cruisecontrolmodule_projectidscmmoduleid ON cruisecontrol_module USING btree (project_id, scm_module_id);


--
-- TOC entry 269 (OID 96673)
-- Name: projectactivity_projectidactivitydate; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX projectactivity_projectidactivitydate ON project_activity USING btree (project_id, activity_date);


--
-- TOC entry 268 (OID 96674)
-- Name: projectactivity_activitydatemeasure; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX projectactivity_activitydatemeasure ON project_activity USING btree (activity_date, measure);


--
-- TOC entry 196 (OID 96675)
-- Name: userproject_userprojectid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX userproject_userprojectid ON user_project USING btree (user_project_id);


--
-- TOC entry 272 (OID 96676)
-- Name: userprojectrole_userprojectidroleid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX userprojectrole_userprojectidroleid ON user_project_role USING btree (user_project_id, role_id);


--
-- TOC entry 271 (OID 96677)
-- Name: userprojectrole_roleiduserprojectid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE UNIQUE INDEX userprojectrole_roleiduserprojectid ON user_project_role USING btree (role_id, user_project_id);


--
-- TOC entry 274 (OID 96678)
-- Name: cruisecontrolplatform_projectid; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX cruisecontrolplatform_projectid ON cruisecontrol_platform USING btree (project_id);


--
-- TOC entry 276 (OID 96679)
-- Name: cruisecontrolplatformtrackeritem_cruisecontrolplatformidtracker; Type: INDEX; Schema: public; Owner: gforge
--

CREATE INDEX cruisecontrolplatformtrackeritem_cruisecontrolplatformidtracker ON cruisecontrol_platform_tracker_item USING btree (cruisecontrol_platform_id, tracker_item_id);


--
-- TOC entry 139 (OID 96680)
-- Name: deleted_project_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY deleted_project
    ADD CONSTRAINT deleted_project_pkey PRIMARY KEY (unix_group_name);


--
-- TOC entry 140 (OID 96682)
-- Name: project_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project
    ADD CONSTRAINT project_pkey PRIMARY KEY (project_id);


--
-- TOC entry 141 (OID 96684)
-- Name: project_unix_name_key; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project
    ADD CONSTRAINT project_unix_name_key UNIQUE (unix_name);


--
-- TOC entry 142 (OID 96686)
-- Name: country_code_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY country_code
    ADD CONSTRAINT country_code_pkey PRIMARY KEY (ccode);


--
-- TOC entry 143 (OID 96688)
-- Name: theme_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY theme
    ADD CONSTRAINT theme_pkey PRIMARY KEY (theme_id);


--
-- TOC entry 144 (OID 96690)
-- Name: language_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "language"
    ADD CONSTRAINT language_pkey PRIMARY KEY (language_id);


--
-- TOC entry 145 (OID 96692)
-- Name: user_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT user_pkey PRIMARY KEY (user_id);


--
-- TOC entry 146 (OID 96694)
-- Name: user_unix_name_key; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT user_unix_name_key UNIQUE (unix_name);


--
-- TOC entry 147 (OID 96696)
-- Name: site_admin_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY site_admin
    ADD CONSTRAINT site_admin_pkey PRIMARY KEY (user_id);


--
-- TOC entry 148 (OID 96698)
-- Name: filesystem_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY filesystem
    ADD CONSTRAINT filesystem_pkey PRIMARY KEY (filesystem_id);


--
-- TOC entry 150 (OID 96700)
-- Name: stats_project_page_view_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY stats_project_page_view
    ADD CONSTRAINT stats_project_page_view_pkey PRIMARY KEY (project_id, count_date);


--
-- TOC entry 151 (OID 96702)
-- Name: stats_site_page_view_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY stats_site_page_view
    ADD CONSTRAINT stats_site_page_view_pkey PRIMARY KEY (count_date);


--
-- TOC entry 152 (OID 96704)
-- Name: monitor_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY monitor
    ADD CONSTRAINT monitor_pkey PRIMARY KEY (section, ref_id, user_id);


--
-- TOC entry 154 (OID 96706)
-- Name: audit_trail_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY audit_trail
    ADD CONSTRAINT audit_trail_pkey PRIMARY KEY (audit_trail_id);


--
-- TOC entry 155 (OID 96708)
-- Name: unix_shell_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY unix_shell
    ADD CONSTRAINT unix_shell_pkey PRIMARY KEY (unix_shell_id);


--
-- TOC entry 156 (OID 96710)
-- Name: user_unix_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_unix
    ADD CONSTRAINT user_unix_pkey PRIMARY KEY (user_id);


--
-- TOC entry 157 (OID 96712)
-- Name: scm_server_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_server
    ADD CONSTRAINT scm_server_pkey PRIMARY KEY (scm_server_id);


--
-- TOC entry 158 (OID 96714)
-- Name: docman_folder_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_folder
    ADD CONSTRAINT docman_folder_pkey PRIMARY KEY (docman_folder_id);


--
-- TOC entry 160 (OID 96716)
-- Name: project_scm_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_scm
    ADD CONSTRAINT project_scm_pkey PRIMARY KEY (project_id);


--
-- TOC entry 161 (OID 96718)
-- Name: forum_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum
    ADD CONSTRAINT forum_pkey PRIMARY KEY (forum_id);


--
-- TOC entry 163 (OID 96720)
-- Name: forum_thread_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT forum_thread_pkey PRIMARY KEY (forum_thread_id);


--
-- TOC entry 165 (OID 96722)
-- Name: forum_message_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_message
    ADD CONSTRAINT forum_message_pkey PRIMARY KEY (forum_message_id);


--
-- TOC entry 168 (OID 96724)
-- Name: user_blog_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_blog
    ADD CONSTRAINT user_blog_pkey PRIMARY KEY (user_blog_id);


--
-- TOC entry 170 (OID 96726)
-- Name: frs_package_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY frs_package
    ADD CONSTRAINT frs_package_pkey PRIMARY KEY (frs_package_id);


--
-- TOC entry 172 (OID 96728)
-- Name: frs_release_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY frs_release
    ADD CONSTRAINT frs_release_pkey PRIMARY KEY (frs_release_id);


--
-- TOC entry 176 (OID 96730)
-- Name: mailman_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY mailman
    ADD CONSTRAINT mailman_pkey PRIMARY KEY (mailman_id);


--
-- TOC entry 178 (OID 96732)
-- Name: news_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY news
    ADD CONSTRAINT news_pkey PRIMARY KEY (news_id);


--
-- TOC entry 180 (OID 96734)
-- Name: user_session_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_session
    ADD CONSTRAINT user_session_pkey PRIMARY KEY (session_hash);


--
-- TOC entry 181 (OID 96736)
-- Name: snippet_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY snippet
    ADD CONSTRAINT snippet_pkey PRIMARY KEY (snippet_id);


--
-- TOC entry 182 (OID 96738)
-- Name: survey_question_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey_question
    ADD CONSTRAINT survey_question_pkey PRIMARY KEY (survey_question_id);


--
-- TOC entry 184 (OID 96740)
-- Name: survey_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey
    ADD CONSTRAINT survey_pkey PRIMARY KEY (survey_id);


--
-- TOC entry 186 (OID 96742)
-- Name: survey_response_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey_response
    ADD CONSTRAINT survey_response_pkey PRIMARY KEY (user_id, survey_id, question_id);


--
-- TOC entry 188 (OID 96744)
-- Name: trove_category_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_category
    ADD CONSTRAINT trove_category_pkey PRIMARY KEY (trove_category_id);


--
-- TOC entry 190 (OID 96746)
-- Name: trove_link_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_link
    ADD CONSTRAINT trove_link_pkey PRIMARY KEY (section, ref_id, trove_category_id);


--
-- TOC entry 192 (OID 96748)
-- Name: role_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY role
    ADD CONSTRAINT role_pkey PRIMARY KEY (role_id);


--
-- TOC entry 194 (OID 96750)
-- Name: role_setting_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY role_setting
    ADD CONSTRAINT role_setting_pkey PRIMARY KEY (role_id, section, ref_id);


--
-- TOC entry 195 (OID 96752)
-- Name: user_project_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_project
    ADD CONSTRAINT user_project_pkey PRIMARY KEY (user_id, project_id);


--
-- TOC entry 197 (OID 96754)
-- Name: user_preference_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_preference
    ADD CONSTRAINT user_preference_pkey PRIMARY KEY (user_id, preference_name);


--
-- TOC entry 198 (OID 96756)
-- Name: tracker_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker
    ADD CONSTRAINT tracker_pkey PRIMARY KEY (tracker_id);


--
-- TOC entry 200 (OID 96758)
-- Name: tracker_item_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT tracker_item_pkey PRIMARY KEY (tracker_item_id);


--
-- TOC entry 209 (OID 96760)
-- Name: tracker_time_code_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_time_code
    ADD CONSTRAINT tracker_time_code_pkey PRIMARY KEY (tracker_time_code_id);


--
-- TOC entry 210 (OID 96762)
-- Name: tracker_item_time_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT tracker_item_time_pkey PRIMARY KEY (tracker_item_time_id);


--
-- TOC entry 211 (OID 96764)
-- Name: tracker_item_relation_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT tracker_item_relation_pkey PRIMARY KEY (tracker_item_id, related_tracker_item_id);


--
-- TOC entry 213 (OID 96766)
-- Name: tracker_item_assignee_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT tracker_item_assignee_pkey PRIMARY KEY (tracker_item_id, assignee);


--
-- TOC entry 215 (OID 96768)
-- Name: tracker_item_message_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT tracker_item_message_pkey PRIMARY KEY (tracker_item_message_id);


--
-- TOC entry 217 (OID 96770)
-- Name: tracker_canned_response_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_canned_response
    ADD CONSTRAINT tracker_canned_response_pkey PRIMARY KEY (tracker_canned_response_id);


--
-- TOC entry 219 (OID 96772)
-- Name: notification_queue_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY notification_queue
    ADD CONSTRAINT notification_queue_pkey PRIMARY KEY (notification_queue_id);


--
-- TOC entry 220 (OID 96774)
-- Name: scm_user_stats_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT scm_user_stats_pkey PRIMARY KEY (stat_date, project_id, user_id);


--
-- TOC entry 221 (OID 96776)
-- Name: scm_project_stats_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_project_stats
    ADD CONSTRAINT scm_project_stats_pkey PRIMARY KEY (stat_date, project_id);


--
-- TOC entry 222 (OID 96778)
-- Name: plugin_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY plugin
    ADD CONSTRAINT plugin_pkey PRIMARY KEY (plugin_id);


--
-- TOC entry 224 (OID 96780)
-- Name: project_plugin_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT project_plugin_pkey PRIMARY KEY (project_id, plugin_id);


--
-- TOC entry 225 (OID 96782)
-- Name: user_plugin_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT user_plugin_pkey PRIMARY KEY (user_id, plugin_id);


--
-- TOC entry 226 (OID 96784)
-- Name: user_relation_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_relation
    ADD CONSTRAINT user_relation_pkey PRIMARY KEY (user_id, related_user_id);


--
-- TOC entry 227 (OID 96786)
-- Name: user_watched_project_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT user_watched_project_pkey PRIMARY KEY (user_id, project_id);


--
-- TOC entry 228 (OID 96788)
-- Name: tracker_extra_field_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field
    ADD CONSTRAINT tracker_extra_field_pkey PRIMARY KEY (tracker_extra_field_id);


--
-- TOC entry 230 (OID 96790)
-- Name: tracker_extra_field_element_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element
    ADD CONSTRAINT tracker_extra_field_element_pkey PRIMARY KEY (element_id);


--
-- TOC entry 232 (OID 96792)
-- Name: tracker_extra_field_data_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT tracker_extra_field_data_pkey PRIMARY KEY (tracker_extra_field_data_id);


--
-- TOC entry 234 (OID 96794)
-- Name: project_join_request_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT project_join_request_pkey PRIMARY KEY (project_id, user_id);


--
-- TOC entry 235 (OID 96796)
-- Name: scm_module_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_module
    ADD CONSTRAINT scm_module_pkey PRIMARY KEY (scm_module_id);


--
-- TOC entry 236 (OID 96798)
-- Name: scm_preference_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_preference
    ADD CONSTRAINT scm_preference_pkey PRIMARY KEY (project_id);


--
-- TOC entry 237 (OID 96800)
-- Name: scm_commit_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT scm_commit_pkey PRIMARY KEY (scm_commit_id);


--
-- TOC entry 241 (OID 96802)
-- Name: scm_commit_file_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_commit_file
    ADD CONSTRAINT scm_commit_file_pkey PRIMARY KEY (scm_commit_id, modified_file);


--
-- TOC entry 242 (OID 96804)
-- Name: tracker_query_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT tracker_query_pkey PRIMARY KEY (tracker_query_id);


--
-- TOC entry 244 (OID 96806)
-- Name: tracker_query_field_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_query_field
    ADD CONSTRAINT tracker_query_field_pkey PRIMARY KEY (tracker_query_id, query_field_type, query_field_id);


--
-- TOC entry 245 (OID 96808)
-- Name: wiki_page_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_page
    ADD CONSTRAINT wiki_page_pkey PRIMARY KEY (wiki_page_id);


--
-- TOC entry 247 (OID 96810)
-- Name: wiki_version_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT wiki_version_pkey PRIMARY KEY (wiki_version_id);


--
-- TOC entry 249 (OID 96812)
-- Name: wiki_page_link_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT wiki_page_link_pkey PRIMARY KEY (from_wiki_page_id, to_wiki_page_id);


--
-- TOC entry 250 (OID 96814)
-- Name: trove_link_count_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_link_count
    ADD CONSTRAINT trove_link_count_pkey PRIMARY KEY (trove_category_id, section);


--
-- TOC entry 251 (OID 96816)
-- Name: docman_file_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_file
    ADD CONSTRAINT docman_file_pkey PRIMARY KEY (docman_file_id);


--
-- TOC entry 253 (OID 96818)
-- Name: docman_file_version_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT docman_file_version_pkey PRIMARY KEY (docman_file_version_id);


--
-- TOC entry 255 (OID 96820)
-- Name: scm_module_user_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT scm_module_user_pkey PRIMARY KEY (scm_module_id, user_id);


--
-- TOC entry 256 (OID 96822)
-- Name: cruisecontrol_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT cruisecontrol_pkey PRIMARY KEY (project_id);


--
-- TOC entry 257 (OID 96824)
-- Name: cruisecontrol_publisher_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT cruisecontrol_publisher_pkey PRIMARY KEY (project_id, tracker_id);


--
-- TOC entry 259 (OID 96826)
-- Name: cruisecontrol_assignee_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT cruisecontrol_assignee_pkey PRIMARY KEY (project_id, assignee);


--
-- TOC entry 261 (OID 96828)
-- Name: cruisecontrol_preference_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_preference
    ADD CONSTRAINT cruisecontrol_preference_pkey PRIMARY KEY (project_id, name);


--
-- TOC entry 262 (OID 96830)
-- Name: cruisecontrol_module_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT cruisecontrol_module_pkey PRIMARY KEY (project_id, scm_module_id);


--
-- TOC entry 264 (OID 96832)
-- Name: tracker_extra_field_element_transition_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition
    ADD CONSTRAINT tracker_extra_field_element_transition_pkey PRIMARY KEY (tracker_extra_field_element_transition_id);


--
-- TOC entry 265 (OID 96834)
-- Name: tracker_extra_field_element_transition_role_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_role
    ADD CONSTRAINT tracker_extra_field_element_transition_role_pkey PRIMARY KEY (tracker_extra_field_element_transition_id, role_id);


--
-- TOC entry 266 (OID 96836)
-- Name: tracker_extra_field_element_transition_field_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_field
    ADD CONSTRAINT tracker_extra_field_element_transition_field_pkey PRIMARY KEY (tracker_extra_field_element_transition_id, required_tracker_extra_field_id);


--
-- TOC entry 175 (OID 96838)
-- Name: deleted_mailing_list_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY deleted_mailing_list
    ADD CONSTRAINT deleted_mailing_list_pkey PRIMARY KEY (mailing_list_name);


--
-- TOC entry 267 (OID 96840)
-- Name: project_activity_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_activity
    ADD CONSTRAINT project_activity_pkey PRIMARY KEY (activity_date, project_id);


--
-- TOC entry 270 (OID 96842)
-- Name: tracker_extra_field_element_transition_notify_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_notify
    ADD CONSTRAINT tracker_extra_field_element_transition_notify_pkey PRIMARY KEY (tracker_extra_field_element_transition_id, role_id);


--
-- TOC entry 223 (OID 96844)
-- Name: plugin_plugin_name_key; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY plugin
    ADD CONSTRAINT plugin_plugin_name_key UNIQUE (plugin_name);


--
-- TOC entry 273 (OID 96846)
-- Name: cruisecontrol_platform_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_platform
    ADD CONSTRAINT cruisecontrol_platform_pkey PRIMARY KEY (cruisecontrol_platform_id);


--
-- TOC entry 275 (OID 96848)
-- Name: cruisecontrol_platform_tracker_item_pkey; Type: CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_platform_tracker_item
    ADD CONSTRAINT cruisecontrol_platform_tracker_item_pkey PRIMARY KEY (cruisecontrol_platform_id, tracker_item_id);


--
-- TOC entry 371 (OID 96850)
-- Name: countrycode_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT countrycode_fk FOREIGN KEY (ccode) REFERENCES country_code(ccode);


--
-- TOC entry 372 (OID 96854)
-- Name: languageid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT languageid_fk FOREIGN KEY (language_id) REFERENCES "language"(language_id);


--
-- TOC entry 373 (OID 96858)
-- Name: themeid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT themeid_fk FOREIGN KEY (theme_id) REFERENCES theme(theme_id);


--
-- TOC entry 374 (OID 96862)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY site_admin
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 375 (OID 96866)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY filesystem
    ADD CONSTRAINT userid_fk FOREIGN KEY (posted_by) REFERENCES "user"(user_id);


--
-- TOC entry 377 (OID 96870)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY audit_trail
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 378 (OID 96874)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_unix
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 379 (OID 96878)
-- Name: unixshellid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_unix
    ADD CONSTRAINT unixshellid_fk FOREIGN KEY (unix_shell_id) REFERENCES unix_shell(unix_shell_id);


--
-- TOC entry 380 (OID 96882)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_folder
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 381 (OID 96886)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_scm
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 382 (OID 96890)
-- Name: scmserverid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_scm
    ADD CONSTRAINT scmserverid_fk FOREIGN KEY (scm_server_id) REFERENCES scm_server(scm_server_id);


--
-- TOC entry 383 (OID 96894)
-- Name: forumid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT forumid_fk FOREIGN KEY (forum_id) REFERENCES forum(forum_id) ON DELETE CASCADE;


--
-- TOC entry 384 (OID 96898)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);


--
-- TOC entry 385 (OID 96902)
-- Name: forumthreadid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_message
    ADD CONSTRAINT forumthreadid_fk FOREIGN KEY (forum_thread_id) REFERENCES forum_thread(forum_thread_id) ON DELETE CASCADE;


--
-- TOC entry 386 (OID 96906)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY forum_message
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);


--
-- TOC entry 387 (OID 96910)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_blog
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 388 (OID 96914)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY frs_package
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 389 (OID 96918)
-- Name: frspackageid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY frs_release
    ADD CONSTRAINT frspackageid_fk FOREIGN KEY (frs_package_id) REFERENCES frs_package(frs_package_id) ON DELETE CASCADE;


--
-- TOC entry 390 (OID 96922)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY frs_release
    ADD CONSTRAINT userid_fk FOREIGN KEY (released_by) REFERENCES "user"(user_id);


--
-- TOC entry 391 (OID 96926)
-- Name: filesystemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY filesystem_download
    ADD CONSTRAINT filesystemid_fk FOREIGN KEY (filesystem_id) REFERENCES filesystem(filesystem_id) ON DELETE CASCADE;


--
-- TOC entry 392 (OID 96930)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY mailman
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 393 (OID 96934)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY mailman
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);


--
-- TOC entry 394 (OID 96938)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY news
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 395 (OID 96942)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY news
    ADD CONSTRAINT userid_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);


--
-- TOC entry 396 (OID 96946)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_session
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 397 (OID 96950)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY snippet
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);


--
-- TOC entry 398 (OID 96954)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey_question
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 399 (OID 96958)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 400 (OID 96962)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY survey_response
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 401 (OID 96966)
-- Name: parenttrovecatid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_category
    ADD CONSTRAINT parenttrovecatid_fk FOREIGN KEY (parent_trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;


--
-- TOC entry 402 (OID 96970)
-- Name: trovecategoryid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_link
    ADD CONSTRAINT trovecategoryid_fk FOREIGN KEY (trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;


--
-- TOC entry 403 (OID 96974)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY role
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 404 (OID 96978)
-- Name: roleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY role_setting
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- TOC entry 405 (OID 96982)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_project
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 406 (OID 96986)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_project
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 407 (OID 96990)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_preference
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 408 (OID 96994)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 409 (OID 96998)
-- Name: trackerid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;


--
-- TOC entry 410 (OID 97002)
-- Name: submittedby_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT submittedby_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);


--
-- TOC entry 411 (OID 97006)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 412 (OID 97010)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 413 (OID 97014)
-- Name: trackertimecodeid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT trackertimecodeid_fk FOREIGN KEY (tracker_time_code_id) REFERENCES tracker_time_code(tracker_time_code_id) ON DELETE CASCADE;


--
-- TOC entry 414 (OID 97018)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 415 (OID 97022)
-- Name: relatedtrackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT relatedtrackeritemid_fk FOREIGN KEY (related_tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 416 (OID 97026)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 417 (OID 97030)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT userid_fk FOREIGN KEY (assignee) REFERENCES "user"(user_id);


--
-- TOC entry 418 (OID 97034)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 419 (OID 97038)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT userid_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);


--
-- TOC entry 420 (OID 97042)
-- Name: trackerid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_canned_response
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;


--
-- TOC entry 421 (OID 97046)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY notification_queue
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 422 (OID 97050)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 423 (OID 97054)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 424 (OID 97058)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_project_stats
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 425 (OID 97062)
-- Name: pluginid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY plugin_dependency
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;


--
-- TOC entry 426 (OID 97066)
-- Name: dependsonpluginid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY plugin_dependency
    ADD CONSTRAINT dependsonpluginid_fk FOREIGN KEY (dependson_plugin_id) REFERENCES plugin(plugin_id);


--
-- TOC entry 427 (OID 97070)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 428 (OID 97074)
-- Name: pluginid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;


--
-- TOC entry 429 (OID 97078)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 430 (OID 97082)
-- Name: pluginid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;


--
-- TOC entry 431 (OID 97086)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_relation
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 432 (OID 97090)
-- Name: relateduserid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_relation
    ADD CONSTRAINT relateduserid_fk FOREIGN KEY (related_user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 433 (OID 97094)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 434 (OID 97098)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 435 (OID 97102)
-- Name: trackerid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;


--
-- TOC entry 436 (OID 97106)
-- Name: trackerextrafieldid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element
    ADD CONSTRAINT trackerextrafieldid_fk FOREIGN KEY (tracker_extra_field_id) REFERENCES tracker_extra_field(tracker_extra_field_id) ON DELETE CASCADE;


--
-- TOC entry 438 (OID 97110)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 439 (OID 97114)
-- Name: trackerextrafieldid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT trackerextrafieldid_fk FOREIGN KEY (tracker_extra_field_id) REFERENCES tracker_extra_field(tracker_extra_field_id) ON DELETE CASCADE;


--
-- TOC entry 440 (OID 97118)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 441 (OID 97122)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 442 (OID 97126)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_module
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 443 (OID 97130)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_preference
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 444 (OID 97134)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 445 (OID 97138)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 446 (OID 97142)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_scm_commit
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 447 (OID 97146)
-- Name: scmcommitid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_item_scm_commit
    ADD CONSTRAINT scmcommitid_fk FOREIGN KEY (scm_commit_id) REFERENCES scm_commit(scm_commit_id) ON DELETE CASCADE;


--
-- TOC entry 448 (OID 97150)
-- Name: scmcommitid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_commit_file
    ADD CONSTRAINT scmcommitid_fk FOREIGN KEY (scm_commit_id) REFERENCES scm_commit(scm_commit_id) ON DELETE CASCADE;


--
-- TOC entry 449 (OID 97154)
-- Name: trackerid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;


--
-- TOC entry 450 (OID 97158)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);


--
-- TOC entry 451 (OID 97162)
-- Name: trackerqueryid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_query_field
    ADD CONSTRAINT trackerqueryid_fk FOREIGN KEY (tracker_query_id) REFERENCES tracker_query(tracker_query_id) ON DELETE CASCADE;


--
-- TOC entry 452 (OID 97166)
-- Name: wikipageid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT wikipageid_fk FOREIGN KEY (wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;


--
-- TOC entry 453 (OID 97170)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT userid_fk FOREIGN KEY (posted_by) REFERENCES "user"(user_id);


--
-- TOC entry 454 (OID 97174)
-- Name: fromwikipageid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT fromwikipageid_fk FOREIGN KEY (from_wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;


--
-- TOC entry 455 (OID 97178)
-- Name: towikipageid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT towikipageid_fk FOREIGN KEY (to_wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;


--
-- TOC entry 456 (OID 97182)
-- Name: trovecategory_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY trove_link_count
    ADD CONSTRAINT trovecategory_fk FOREIGN KEY (trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;


--
-- TOC entry 457 (OID 97186)
-- Name: docmanfolderid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_file
    ADD CONSTRAINT docmanfolderid_fk FOREIGN KEY (docman_folder_id) REFERENCES docman_folder(docman_folder_id) ON DELETE CASCADE;


--
-- TOC entry 458 (OID 97190)
-- Name: docmanfileid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT docmanfileid_fk FOREIGN KEY (docman_file_id) REFERENCES docman_file(docman_file_id) ON DELETE CASCADE;


--
-- TOC entry 459 (OID 97194)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 460 (OID 97198)
-- Name: scmmoduleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT scmmoduleid_fk FOREIGN KEY (scm_module_id) REFERENCES scm_module(scm_module_id) ON DELETE CASCADE;


--
-- TOC entry 461 (OID 97202)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 462 (OID 97206)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 463 (OID 97210)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT userid_fk FOREIGN KEY (developer) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 464 (OID 97214)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 465 (OID 97218)
-- Name: trackerid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;


--
-- TOC entry 466 (OID 97222)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 467 (OID 97226)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT userid_fk FOREIGN KEY (assignee) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 468 (OID 97230)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_preference
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 469 (OID 97234)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 470 (OID 97238)
-- Name: scmmoduleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT scmmoduleid_fk FOREIGN KEY (scm_module_id) REFERENCES scm_module(scm_module_id) ON DELETE CASCADE;


--
-- TOC entry 376 (OID 97242)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY monitor
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;


--
-- TOC entry 437 (OID 97246)
-- Name: userid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element
    ADD CONSTRAINT userid_fk FOREIGN KEY (auto_assign_to) REFERENCES "user"(user_id);


--
-- TOC entry 471 (OID 97250)
-- Name: elementid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition
    ADD CONSTRAINT elementid_fk FOREIGN KEY (element_id) REFERENCES tracker_extra_field_element(element_id) ON DELETE CASCADE;


--
-- TOC entry 472 (OID 97254)
-- Name: toelementid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition
    ADD CONSTRAINT toelementid_fk FOREIGN KEY (to_element_id) REFERENCES tracker_extra_field_element(element_id) ON DELETE CASCADE;


--
-- TOC entry 473 (OID 97258)
-- Name: elementtransitionid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_role
    ADD CONSTRAINT elementtransitionid_fk FOREIGN KEY (tracker_extra_field_element_transition_id) REFERENCES tracker_extra_field_element_transition(tracker_extra_field_element_transition_id) ON DELETE CASCADE;


--
-- TOC entry 474 (OID 97262)
-- Name: roleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_role
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- TOC entry 475 (OID 97266)
-- Name: elementtransitionid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_field
    ADD CONSTRAINT elementtransitionid_fk FOREIGN KEY (tracker_extra_field_element_transition_id) REFERENCES tracker_extra_field_element_transition(tracker_extra_field_element_transition_id) ON DELETE CASCADE;


--
-- TOC entry 476 (OID 97270)
-- Name: requiredtrackerextrafieldid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_field
    ADD CONSTRAINT requiredtrackerextrafieldid_fk FOREIGN KEY (required_tracker_extra_field_id) REFERENCES tracker_extra_field(tracker_extra_field_id) ON DELETE CASCADE;


--
-- TOC entry 477 (OID 97274)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY project_activity
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 478 (OID 97278)
-- Name: elementtransitionid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_notify
    ADD CONSTRAINT elementtransitionid_fk FOREIGN KEY (tracker_extra_field_element_transition_id) REFERENCES tracker_extra_field_element_transition(tracker_extra_field_element_transition_id) ON DELETE CASCADE;


--
-- TOC entry 479 (OID 97282)
-- Name: roleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY tracker_extra_field_element_transition_notify
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- TOC entry 480 (OID 97286)
-- Name: userprojectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_project_role
    ADD CONSTRAINT userprojectid_fk FOREIGN KEY (user_project_id) REFERENCES user_project(user_project_id) ON DELETE CASCADE;


--
-- TOC entry 481 (OID 97290)
-- Name: roleid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY user_project_role
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- TOC entry 482 (OID 97294)
-- Name: projectid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_platform
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;


--
-- TOC entry 483 (OID 97298)
-- Name: cruisecontrolplatformid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_platform_tracker_item
    ADD CONSTRAINT cruisecontrolplatformid_fk FOREIGN KEY (cruisecontrol_platform_id) REFERENCES cruisecontrol_platform(cruisecontrol_platform_id) ON DELETE CASCADE;


--
-- TOC entry 484 (OID 97302)
-- Name: trackeritemid_fk; Type: FK CONSTRAINT; Schema: public; Owner: gforge
--

ALTER TABLE ONLY cruisecontrol_platform_tracker_item
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;


--
-- TOC entry 485 (OID 97306)
-- Name: forum_message_insertdelete_trigg; Type: TRIGGER; Schema: public; Owner: gforge
--

CREATE TRIGGER forum_message_insertdelete_trigg
    AFTER INSERT OR DELETE ON forum_message
    FOR EACH ROW
    EXECUTE PROCEDURE forum_insertdelete_agg();


--
-- TOC entry 486 (OID 97307)
-- Name: tracker_item_update_trigg; Type: TRIGGER; Schema: public; Owner: gforge
--

CREATE TRIGGER tracker_item_update_trigg
    AFTER UPDATE ON tracker_item
    FOR EACH ROW
    EXECUTE PROCEDURE tracker_update_agg();


--
-- TOC entry 487 (OID 97308)
-- Name: project_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE project_delete_rule AS ON DELETE TO project DO INSERT INTO deleted_project (unix_group_name) VALUES (old.unix_name);


--
-- TOC entry 489 (OID 97309)
-- Name: forum_thread_insert_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE forum_thread_insert_rule AS ON INSERT TO forum_thread DO UPDATE forum SET thread_count = (forum.thread_count + 1), most_recent_date = now() WHERE (forum.forum_id = new.forum_id);


--
-- TOC entry 490 (OID 97310)
-- Name: forum_thread_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE forum_thread_delete_rule AS ON DELETE TO forum_thread DO UPDATE forum SET thread_count = (forum.thread_count - 1) WHERE (forum.forum_id = old.forum_id);


--
-- TOC entry 494 (OID 97311)
-- Name: user_blog_insert_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE user_blog_insert_forum_rule AS ON INSERT TO user_blog DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('userblog'::character varying, new.user_blog_id, ('userblog-'::text || (new.user_blog_id)::text), new.subject);


--
-- TOC entry 495 (OID 97312)
-- Name: user_blog_delete_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE user_blog_delete_forum_rule AS ON DELETE TO user_blog DO DELETE FROM forum WHERE (((forum.section)::text = 'userblog'::text) AND (forum.ref_id = old.user_blog_id));


--
-- TOC entry 491 (OID 97313)
-- Name: forum_message_insert_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE forum_message_insert_rule AS ON INSERT TO forum_message DO UPDATE forum_thread SET message_count = (forum_thread.message_count + 1), most_recent_date = now() WHERE (forum_thread.forum_thread_id = new.forum_thread_id);


--
-- TOC entry 492 (OID 97314)
-- Name: forum_message_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE forum_message_delete_rule AS ON DELETE TO forum_message DO UPDATE forum_thread SET message_count = (forum_thread.message_count - 1) WHERE (forum_thread.forum_thread_id = old.forum_thread_id);


--
-- TOC entry 497 (OID 97315)
-- Name: filesystem_download_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE filesystem_download_rule AS ON INSERT TO filesystem_download DO UPDATE filesystem SET download_count = (filesystem.download_count + 1) WHERE (filesystem.filesystem_id = new.filesystem_id);


--
-- TOC entry 498 (OID 97316)
-- Name: mailman_insert_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE mailman_insert_forum_rule AS ON INSERT TO mailman DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('mailman'::character varying, new.mailman_id, ('mailman-'::text || (new.mailman_id)::text), new.list_name);


--
-- TOC entry 499 (OID 97317)
-- Name: mailman_delete_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE mailman_delete_forum_rule AS ON DELETE TO mailman DO DELETE FROM forum WHERE (((forum.section)::text = 'mailman'::text) AND (forum.ref_id = old.mailman_id));


--
-- TOC entry 501 (OID 97318)
-- Name: news_insert_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE news_insert_forum_rule AS ON INSERT TO news DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('news'::character varying, new.news_id, ('news-'::text || (new.news_id)::text), new.summary);


--
-- TOC entry 502 (OID 97319)
-- Name: news_delete_forum_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE news_delete_forum_rule AS ON DELETE TO news DO DELETE FROM forum WHERE (((forum.section)::text = 'news'::text) AND (forum.ref_id = old.news_id));


--
-- TOC entry 504 (OID 97320)
-- Name: trackeritem_insert_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE trackeritem_insert_rule AS ON INSERT TO tracker_item DO UPDATE tracker SET item_total = (tracker.item_total + 1), open_count = (tracker.open_count + 1) WHERE (tracker.tracker_id = new.tracker_id);


--
-- TOC entry 505 (OID 97321)
-- Name: tracker_item_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE tracker_item_delete_rule AS ON DELETE TO tracker_item DO UPDATE tracker SET item_total = (tracker.item_total - 1), open_count = CASE WHEN (old.status_id = 1) THEN (tracker.open_count - 1) ELSE tracker.open_count END WHERE (tracker.tracker_id = old.tracker_id);


--
-- TOC entry 503 (OID 97322)
-- Name: snippet_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE snippet_delete_rule AS ON DELETE TO snippet DO UPDATE filesystem SET deleted = true WHERE (((filesystem.section)::text = 'snippet'::text) AND (filesystem.ref_id = old.snippet_id));


--
-- TOC entry 506 (OID 97323)
-- Name: tracker_item_deletefiles_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE tracker_item_deletefiles_rule AS ON DELETE TO tracker_item DO UPDATE filesystem SET deleted = true WHERE (((filesystem.section)::text = 'trackeritem'::text) AND (filesystem.ref_id = old.tracker_item_id));


--
-- TOC entry 493 (OID 97324)
-- Name: forum_message_deletefiles_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE forum_message_deletefiles_rule AS ON DELETE TO forum_message DO UPDATE filesystem SET deleted = true WHERE (((filesystem.section)::text = 'forummessage'::text) AND (filesystem.ref_id = old.forum_message_id));


--
-- TOC entry 507 (OID 97325)
-- Name: docman_file_version_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE docman_file_version_delete_rule AS ON DELETE TO docman_file_version DO UPDATE filesystem SET deleted = true WHERE (((filesystem.section)::text = 'docmanfileversion'::text) AND (filesystem.ref_id = old.docman_file_version_id));


--
-- TOC entry 496 (OID 97326)
-- Name: frs_release_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE frs_release_delete_rule AS ON DELETE TO frs_release DO UPDATE filesystem SET deleted = true WHERE (((filesystem.section)::text = 'frsrelease'::text) AND (filesystem.ref_id = old.frs_release_id));


--
-- TOC entry 488 (OID 97327)
-- Name: project_forum_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE project_forum_delete_rule AS ON DELETE TO project DO DELETE FROM forum WHERE (((forum.section)::text = 'project'::text) AND (forum.ref_id = old.project_id));


--
-- TOC entry 500 (OID 97328)
-- Name: mailman_delete_rule; Type: RULE; Schema: public; Owner: gforge
--

CREATE RULE mailman_delete_rule AS ON DELETE TO mailman DO INSERT INTO deleted_mailing_list (mailing_list_name) VALUES (old.list_name);


--
-- TOC entry 97 (OID 94764)
-- Name: project_project_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('project_project_id_seq', 3, true);


--
-- TOC entry 98 (OID 94778)
-- Name: theme_theme_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('theme_theme_id_seq', 1, true);


--
-- TOC entry 99 (OID 94786)
-- Name: language_language_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('language_language_id_seq', 5, true);


--
-- TOC entry 100 (OID 94794)
-- Name: user_user_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('user_user_id_seq', 101, true);


--
-- TOC entry 101 (OID 94807)
-- Name: filesystem_filesystem_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('filesystem_filesystem_id_seq', 3, true);


--
-- TOC entry 102 (OID 94824)
-- Name: audit_trail_audit_trail_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('audit_trail_audit_trail_id_seq', 1, false);


--
-- TOC entry 103 (OID 94834)
-- Name: unix_shell_unix_shell_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('unix_shell_unix_shell_id_seq', 2, true);


--
-- TOC entry 104 (OID 94850)
-- Name: scm_server_scm_server_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('scm_server_scm_server_id_seq', 2, true);


--
-- TOC entry 105 (OID 94858)
-- Name: docman_folder_docman_folder_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('docman_folder_docman_folder_id_seq', 1, false);


--
-- TOC entry 106 (OID 94876)
-- Name: forum_forum_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('forum_forum_id_seq', 6, true);


--
-- TOC entry 107 (OID 94889)
-- Name: forum_thread_forum_thread_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('forum_thread_forum_thread_id_seq', 1, false);


--
-- TOC entry 108 (OID 94899)
-- Name: forum_message_forum_message_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('forum_message_forum_message_id_seq', 1, false);


--
-- TOC entry 109 (OID 94910)
-- Name: user_blog_user_blog_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('user_blog_user_blog_id_seq', 1, false);


--
-- TOC entry 110 (OID 94919)
-- Name: frs_package_frs_package_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('frs_package_frs_package_id_seq', 1, false);


--
-- TOC entry 111 (OID 94930)
-- Name: frs_release_frs_release_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('frs_release_frs_release_id_seq', 101, false);


--
-- TOC entry 112 (OID 94954)
-- Name: mailman_mailman_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('mailman_mailman_id_seq', 2, true);


--
-- TOC entry 113 (OID 94965)
-- Name: news_news_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('news_news_id_seq', 1, false);


--
-- TOC entry 114 (OID 94978)
-- Name: snippet_snippet_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('snippet_snippet_id_seq', 1, false);


--
-- TOC entry 115 (OID 94987)
-- Name: survey_question_survey_question_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('survey_question_survey_question_id_seq', 1, false);


--
-- TOC entry 116 (OID 94995)
-- Name: survey_survey_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('survey_survey_id_seq', 1, false);


--
-- TOC entry 117 (OID 95012)
-- Name: trove_category_trove_category_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('trove_category_trove_category_id_seq', 306, false);


--
-- TOC entry 118 (OID 95022)
-- Name: role_role_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('role_role_id_seq', 17, true);


--
-- TOC entry 119 (OID 95042)
-- Name: tracker_tracker_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_tracker_id_seq', 11, true);


--
-- TOC entry 120 (OID 95056)
-- Name: tracker_item_tracker_item_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_item_tracker_item_id_seq', 1, false);


--
-- TOC entry 121 (OID 95071)
-- Name: tracker_time_code_tracker_time_code_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_time_code_tracker_time_code_id_seq', 1, false);


--
-- TOC entry 122 (OID 95079)
-- Name: tracker_item_time_tracker_item_time_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_item_time_tracker_item_time_id_seq', 1, false);


--
-- TOC entry 123 (OID 95091)
-- Name: tracker_item_message_tracker_item_message_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_item_message_tracker_item_message_id_seq', 1, false);


--
-- TOC entry 124 (OID 95100)
-- Name: tracker_canned_response_tracker_canned_response_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_canned_response_tracker_canned_response_id_seq', 1, false);


--
-- TOC entry 125 (OID 95110)
-- Name: notification_queue_notification_queue_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('notification_queue_notification_queue_id_seq', 1, false);


--
-- TOC entry 126 (OID 95132)
-- Name: plugin_plugin_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('plugin_plugin_id_seq', 16, true);


--
-- TOC entry 127 (OID 95158)
-- Name: tracker_extra_field_tracker_extra_field_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_extra_field_tracker_extra_field_id_seq', 90, true);


--
-- TOC entry 128 (OID 95174)
-- Name: tracker_extra_field_element_element_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_extra_field_element_element_id_seq', 335, true);


--
-- TOC entry 129 (OID 95186)
-- Name: tracker_extra_field_data_tracker_extra_field_data_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_extra_field_data_tracker_extra_field_data_id_seq', 1, false);


--
-- TOC entry 130 (OID 95201)
-- Name: scm_module_scm_module_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('scm_module_scm_module_id_seq', 1, false);


--
-- TOC entry 131 (OID 95213)
-- Name: scm_commit_scm_commit_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('scm_commit_scm_commit_id_seq', 1, false);


--
-- TOC entry 132 (OID 95229)
-- Name: tracker_query_tracker_query_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_query_tracker_query_id_seq', 1, false);


--
-- TOC entry 133 (OID 95243)
-- Name: wiki_page_wiki_page_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('wiki_page_wiki_page_id_seq', 1, false);


--
-- TOC entry 134 (OID 95248)
-- Name: wiki_version_wiki_version_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('wiki_version_wiki_version_id_seq', 1, false);


--
-- TOC entry 135 (OID 95265)
-- Name: docman_file_docman_file_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('docman_file_docman_file_id_seq', 1, false);


--
-- TOC entry 136 (OID 95274)
-- Name: docman_file_version_docman_file_version_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('docman_file_version_docman_file_version_id_seq', 1, false);


--
-- TOC entry 137 (OID 95308)
-- Name: tracker_extra_field_element_t_tracker_extra_field_element_t_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('tracker_extra_field_element_t_tracker_extra_field_element_t_seq', 1, false);


--
-- TOC entry 6 (OID 95324)
-- Name: user_project_user_project_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('user_project_user_project_id_seq', 1, true);


--
-- TOC entry 138 (OID 95328)
-- Name: cruisecontrol_platform_cruisecontrol_platform_id_seq; Type: SEQUENCE SET; Schema: public; Owner: gforge
--

SELECT pg_catalog.setval('cruisecontrol_platform_cruisecontrol_platform_id_seq', 1, false);


--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


