<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli <marcelo@gforgegroup.com>
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('core/Language.php');
require_once('html/Paginator.php');

class StatsRenderer {
	private $rs;
	private $project;
	private $paginator;

	/**
	 * $rs must be a ResultSet obtained by querying the project_activity_vw table
	 */
	public function __construct(Project $project, $rs=null, $paginator=null) {
		$this->rs = $rs;
		$this->project = $project;
		$this->paginator = $paginator;
	}
	
	public function getStatsTable() {
		$Language = Language::getSessLang();
		$template = Session::getSession()->getTheme();
		$res = '';

		$theader=array();
		
		$theader[]=$Language->getText('ProjectActivity.HeaderTime');
		$theader[]=$Language->getText('ProjectActivity.HeaderActivity');
		if(is_null($this->paginator)) {
			$theader[]=$Language->getText('ProjectActivity.HeaderPerson');
		} else {
			$theader[]=$this->paginator->insertLimitOptions($Language->getText('ProjectActivity.HeaderPerson'));
		}
		$res .= $template->tableTop($theader);
	
		$j=0;
		$last_day=0;
	
		while ($this->rs->next()) {
			$j++;
			$arr = $this->rs->getRow();
			if ($last_day != date('Y-M-d',strtotime($arr['activity_date']))) {
				$res .= $template->tableFullRow(date('Y-M-d',strtotime($arr['activity_date'])));
				$last_day=date('Y-M-d',strtotime($arr['activity_date']));
			}

			$userlink=UserPeer::retrieveByPk($arr['user_id'])->getUserLink();

			switch ($arr['section']) {
				case 'scm': {
					$description = $arr['description1'];
					// CVS commits for initial imports may be huge, so we trim it
					$description = StringUtils::trimString($description, 256);
					$activity_desc=$Language->getText('ProjectActivity.CommitDescription', array($description));
					
					$scmplugin = $this->project->getExclusiveTypePlugin('scm');
					if (is_null($scmplugin)) continue;		// shouldn't happen... means SCM was disabled in the project
					$url='<a href="'.GFUrl::getURL()->projectURL($this->project, 'ScmCommitDetail', $scmplugin->getName(), '', array('scm_commit_id'=>$arr['ref_id'])).'">'.$activity_desc.'</a>';
					break;
				}
				case 'trackeritem': {
					$action = $arr['action'];
					switch ($action) {
					case 'create':
						$activity_desc = $Language->getText('ProjectActivity.TrackerItemCreate', array($arr['description1']));
						$url='<a href="'.GFUrl::getURL()->projectURL($this->project, 'TrackerItemEdit', 'tracker', '', array('tracker_item_id'=>$arr['ref_id'],'tracker_id'=>$arr['ref_id'])).'">'.$activity_desc.'</a>';
						break;
					case 'delete':
						// We can't link to the item since it was deleted
						$activity_desc = $Language->getText('ProjectActivity.TrackerItemDelete', array($arr['description1']));
						$url = $activity_desc;
						break;
					case 'statuschange':
						$activity_desc = $Language->getText('ProjectActivity.TrackerItemStatusChange', array($arr['description1'], $arr['description2']));
						$url='<a href="'.GFUrl::getURL()->projectURL($this->project, 'TrackerItemEdit', 'tracker', '', array('tracker_item_id' => $arr['ref_id'],'tracker_id'=>$arr['ref_id'])).'">'.$activity_desc.'</a>';
						break;
					default:
						continue;
					}
					break;
				}
				case 'forum': {
					$activity_desc = $Language->getText('ProjectActivity.ForumPostDescription', array($arr['description1']));
					$url='<a href="'.GFUrl::getURL()->projectURL($this->project, 'ForumBrowse', 'forum', '', array('_forum_action'=>'MessageReply','message_id'=>$arr['subref_id'])).'">'.$activity_desc.'</a>';
					break;
				}
				default: {
					// Not handled
					continue;
				}
			}
			$trow=array();
			$trow[]='&nbsp;&nbsp;&nbsp;'.date('H:i:s',strtotime($arr['activity_date']));
			$trow[]=$url;
			$trow[]=$userlink;
			$res .= $template->tableRow($trow);
			unset($trow);
		}
		if ($j==0) {
			$res .= $template->tableFullRow($Language->getText('ProjectActivity.NoneFound'));
		}
		$res .= $template->tableBottom();
		return $res;
	}
}
?>
