<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: index.php 3226 2008-08-06 17:58:08Z bigdisk $
 * @author Tim Perdue tim@gforge.org
 * @date 2006-02-27
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('GFUrl.php');
require_once('plugins/scmgit/lib/html/ScmgitTemplate.php');
require_once('plugins/scmgit/lib/GITRepository.php');
require_once('plugins/scmgit/lib/GitwebBrowser.php');

$project = GFUrl::getUrl()->getProject();
$session = Session::getSession();
$gitplugin = $project->getPluginByName('scmgit');
if (is_null($gitplugin)) {
	throw new InvalidPluginException('scmgit');
}

// Check Permission
$c = new Criteria();
$c->add(ProjectScmPeer::PROJECT_ID, $project->getProjectId());
$project_scm = ProjectScmPeer::doSelectOne($c);

if (!$project->isPublic() || !$project_scm->getEnableAnonread()) {
	// Private SCM -- Check for permissions
	if (!$session->isLoggedIn() || !$project->getPermission()->check(ScmPlugin::SECTION, 0, ScmPlugin::READ)) {
		throw new PermissionDeniedException();
	}
}

$lang = $session->getLanguage();

$template = new ScmgitTemplate();

$params = array(
	'selectedbottomtab'	=> 'scmgit',
	'project' => $project,
	'action' => isset($action) ? $action : '',
	'feedback' => isset($_REQUEST['feedback']) ? $_REQUEST['feedback'] : (isset($feedback) ? $feedback : ''),
	'title' => $lang->getText('Scmgit.BrowseTitle')
	);

// See if SCM is configured for this project
$repos = new GitRepository($project);
if ($repos->isConfigured()) {
	if ($repos->getScmConfiguration()->getControlled()) {
		// Repository is controlled by GForge
		if ($repos->isCreated()) {
			$browser = new GitwebBrowser($repos);
			$browser->parseQuery($_SERVER['QUERY_STRING']);
			
			
			if ($browser->isHtml()) {
				$template->header($params);
				$browse_text = $repos->getScmConfiguration()->getBrowseText();
				if (!empty($browse_text)){
					echo $browse_text.'<br /><br />';
				}
		
				echo $browser->getContents();
				$template->footer($params);
		
			} else {
				$headers = $browser->getHTTPHeaders();
				foreach ($headers as $header) {
					header($header);
				}
				
				echo $browser->getContents();
			}
		} else {
			$template->header($params);
			// Repository wasn't created yet
			echo '<p><h3>'.$lang->getText('Scm.RepositoryNotCreatedTitle').'</h3></p>';
			echo '<p>'.$lang->getText('Scm.RepositoryNotCreatedDescription').'</p>';
			$template->footer($params);
		}
	} else {
		// Repository is externally controlled
		$template->header($params);
		$browse_text = $repos->getScmConfiguration()->getBrowseText();
		if (!empty($browse_text)){
			echo $browse_text.'<br /><br />';
		}
		
		$external_url = $repos->getScmConfiguration()->getExternalBrowseUrl();
		if (!empty($external_url)) {
			echo $lang->getText('Scm.RemoteBrowseUrl', array($external_url));
		}
		$template->footer($params);
	}
	
} else {		// SCM is not configured for this project
	$template->header($params);
?>
	<a href="<?php echo GFUrl::getUrl()->projectURL($project, '', 'scmgit', 'admin'); ?>"><?php echo $lang->getText('Scm.Admin'); ?></a>
	
	<p><h3><?php echo $lang->getText('Scm.AdminTitle'); ?></h3></p>
	
	<p><?php echo $lang->getText('Scm.NotConfigured') ?></p>

<?php
	$template->footer($params);
}

?>
