<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 * @date 2005-11-11
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
require_once('plugins/tracker/lib/om/BaseTrackerQuery.php');
require_once("plugin/ActionManager.php");
require_once('plugin/ActionManager.php');
require_once('plugins/tracker/lib/om/BaseTrackerQueryFieldPeer.php');
require_once('plugins/tracker/lib/TrackerItemQuery.php');

/** 
 * The skeleton for this class was autogenerated by Propel  on:
 *
 * [Wed Nov 16 20:42:33 2005]
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package plugins.tracker.lib 
 */
class TrackerQuery extends BaseTrackerQuery {

	/**
	 * Removes this object from datastore and sets delete attribute. Informs the plugin manager.
	 * This method was added by propel_customizer.php.
	 * 
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 * @see TrackerQuery::setDeleted()
	 * @see TrackerQuery::isDeleted()
	 */
	function delete($con = null) {
		$session = Session::getSession();
		if (!$session->isLoggedIn() || 
			($this->getUser()->getUserId() != $session->getUser()->getUserId() && !$session->isSiteAdmin())) {
			throw new PermissionDeniedException();
		}
		ActionManager::notify("TRACKER_QUERY_DELETE", $this);
		parent::delete($con);		
	}

	/**
	 * Stores the object in the database using the Propel methods. Informs the plugin manager.
	 * This method was added by propel_customizer.php.
	 *
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 */
	function save($con = null) {
		$session = Session::getSession();
		if (!$session->isLoggedIn() || 
			($this->getUser()->getUserId() != $session->getUser()->getUserId() && !$session->isSiteAdmin())) {
			throw new PermissionDeniedException();
		}
		$errors=array();
		if (strlen($this->query_name) < 4) {
			$errors['query_name'] = Language::getSessText('TrackerQuery.EmptyQueryName');
		}
		if (count($errors) > 0) {
			throw new InvalidDataException($errors);
		}
		parent::save($con);
		ActionManager::notify("TRACKER_QUERY_SAVE", $this);
	}

//NOT SURE IF THIS IS A GOOD SOLUTION
//The problem is you have to delete some related elements and not others
//It's easier to delete everything and reset everything
	function setQueryFields($assignee, $extra_fields, $moddaterange, $opendaterange, $closedaterange, $sortord, $sortcol, $fieldlist, $priority) {
//echo "$moddaterange, $opendaterange, $closedaterange, $sortord, $sortcol,";
//exit;
		//delete related items before setting them all again
		if (!$this->isNew()) {
//MAY WANT TO JUST ITERATE THE ATTACHED FIELDS AND DELETE ONE-BY-ONE
			$crit = new Criteria();
			$crit->add(TrackerQueryFieldPeer::TRACKER_QUERY_ID, $this->getTrackerQueryId());
			TrackerQueryFieldPeer::doDelete($crit);
		}
		//save assignees
		if (isset($assignee) && is_array($assignee)) {
			for($e=0; $e<count($assignee); $e++) {
				$assignee[$e]=intval($assignee[$e]);
			}
			$assignee=implode(',',$assignee);
		} else {
			$assignee = intval($assignee);
		}
		$qf = new TrackerQueryField();
		$qf->setQueryFieldType(TrackerItemQuery::FIELD_ASSIGNEE);
		$qf->setQueryFieldId(0);
		$qf->setQueryFieldValues($assignee);
		$this->addTrackerQueryField($qf);

		//priority
		if (isset($priority) && is_array($priority)) {
			for($e=0; $e<count($priority); $e++) {
				$priority[$e]=intval($priority[$e]);
			}
			$priority=implode(',',$priority);
		} else {
			$priority = intval($priority);
		}
		$qf = new TrackerQueryField();
		$qf->setQueryFieldType(TrackerItemQuery::FIELD_PRIORITY);
		$qf->setQueryFieldValues($priority);
		$qf->setQueryFieldId(0);
		$this->addTrackerQueryField($qf);

		//MOD DATE RANGE  YYYY-MM-DD YYYY-MM-DD format
		if (isset($moddaterange) && (strlen($moddaterange) < 18 || !self::validateDateRange($moddaterange))) {
			$moddaterange='';
//			throw new Exception('Invalid Mod Date Range');
		} else {
			$qf = new TrackerQueryField();
			$qf->setQueryFieldType(TrackerItemQuery::FIELD_MODDATE);
			$qf->setQueryFieldValues($moddaterange);
			$qf->setQueryFieldId(0);
			$this->addTrackerQueryField($qf);
		}

		//OPEN DATE RANGE YYYY-MM-DD YYYY-MM-DD format
		if (isset($opendaterange) && (strlen($opendaterange) < 18 || !self::validateDateRange($opendaterange))) {
			$moddaterange='';
//			throw new Exception('Invalid Open Date Range');
		} else {
			$qf = new TrackerQueryField();
			$qf->setQueryFieldType(TrackerItemQuery::FIELD_OPENDATE);
			$qf->setQueryFieldValues($opendaterange);
			$qf->setQueryFieldId(0);
			$this->addTrackerQueryField($qf);
		}

		//CLOSE DATE RANGE YYYY-MM-DD YYYY-MM-DD format
		if (isset($closedaterange) && (strlen($closedaterange) < 18 || !self::validateDateRange($closedaterange))) {
			$closedaterange='';
//			throw new Exception('Invalid Close Date Range');
		} else {
			$qf = new TrackerQueryField();
			$qf->setQueryFieldType(TrackerItemQuery::FIELD_CLOSEDATE);
			$qf->setQueryFieldValues($closedaterange);
			$qf->setQueryFieldId(0);
			$this->addTrackerQueryField($qf);
		}

		if (!isset($extra_fields)) {
			$extra_fields=array();
		}

		$keys=array_keys($extra_fields);
		$vals=array_values($extra_fields);
		for ($i=0; $i<count($keys); $i++) {
			//get the field so we can test if it's a date or numeric field
			$tef=TrackerExtraFieldPeer::retrieveByPK($keys[$i]);
			if (!is_object($tef) || $tef->getTrackerId() != $this->getTrackerId()) {
				continue;
			}
			if (!$vals[$i]) {
				continue;
			}
			//
			//  Checkboxes and multi-select may be arrays so store it comma-separated
			//
			$saveField = true;
			switch($tef->getFieldType()) {
				case TrackerExtraField::TYPE_DATE: {
					if (!isset($vals[$i][0]) || !isset($vals[$i][1])) {
						$saveField = false;
						break;
				//		continue;
					}
										
					if (!self::validateDateRange($vals[$i][0].' '.$vals[$i][1])) {
						$saveField = false;
						break;
				//		continue;
					}
					
					// Enforce a common format MMM DD YYYY
					$vals[$i][0] = strftime('%b %d %Y', strtotime($vals[$i][0]));
					$vals[$i][1] = strftime('%b %d %Y', strtotime($vals[$i][1]));
					
					$vals[$i] = $vals[$i][0].','.$vals[$i][1];
					break;
				}
				case TrackerExtraField::TYPE_SERIAL: 
				case TrackerExtraField::TYPE_NUMERIC: {
					if (!isset($vals[$i][0]) || !isset($vals[$i][1])) {
						$saveField = false;
						break;
				//		continue;
					}
					if (!is_numeric($vals[$i][0]) || !is_numeric($vals[$i][1])) {
						$saveField = false;
						break;
				//		continue;
					}
					$vals[$i] = $vals[$i][0].','.$vals[$i][1];
					break;
				}
				default : {
					if (is_array($vals[$i])) {
						for($e=0; $e<count($vals[$i]); $e++) {
							$vals[$i][$e]=intval($vals[$i][$e]);
						}
						$vals[$i]=implode(',',$vals[$i]);
					} else {
						$vals[$i] =  intval($vals[$i]);
					}
				}
			}
			if($saveField) {
				$qf = new TrackerQueryField();
				$qf->setQueryFieldType(TrackerItemQuery::FIELD_EXTRAFIELD);
				$qf->setQueryFieldId($keys[$i]);
				$qf->setQueryFieldValues($vals[$i]);
				$this->addTrackerQueryField($qf);
			}
		}

		//sort ord
		if ($sortord != 'ASC') {
			$sortord='DESC';
		}
		$qf = new TrackerQueryField();
		$qf->setQueryFieldType(TrackerItemQuery::FIELD_SORTORD);
		$qf->setQueryFieldValues($sortord);
		$qf->setQueryFieldId(0);
		$this->addTrackerQueryField($qf);

		//sort col
//TODO validate field names to avoid SQL inject
		$qf = new TrackerQueryField();
		$qf->setQueryFieldType(TrackerItemQuery::FIELD_SORTCOL);
		$qf->setQueryFieldValues($sortcol);
		$qf->setQueryFieldId(0);
		$this->addTrackerQueryField($qf);
		
	}

	function setIsShared($is_shared) {
		if ($this->getTracker()->userIsAdmin()) {
			parent::setIsShared($is_shared);
		}
	}

	static function validateDateRange($daterange) {
		return preg_match('/[a-zA-Z]{3} [0-9]{1,2} [0-9]{4} [a-zA-Z]{3} [0-9]{1,2} [0-9]{4}/',$daterange);
	}

}

?>
