<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code lists TrackerItem
//
require_once('plugins/tracker/lib/TrackerItemPeer.php');
require_once('plugins/tracker/lib/TrackerItemSavedQuery.php');
require_once('plugins/tracker/lib/TrackerItemQuickQuery.php');
require_once('plugins/tracker/lib/TrackerQuery.php');
require_once('plugins/tracker/lib/TrackerItem.php');
require_once('plugins/tracker/lib/html/TrackerExtraFieldRenderer.php');
require_once('exceptions/PermissionDeniedException.php');

$session = Session::getSession();
$Lang = $session->getLanguage();

require_once('plugins/tracker/lib/html/TrackerTemplate.php');
$theme = new TrackerTemplate();

$Project = GFUrl::getUrl()->getProject();
$Tracker = TrackerPeer::retrieveByPk($_REQUEST['tracker_id']);
if (!$Tracker || !is_object($Tracker) || $Tracker->getProject()->getProjectId() != $Project->getProjectId() || !$Tracker->userCanRead()) {
        throw new PermissionDeniedException();
}

$params = array(
		'project' => $Project,
		'tracker' => $Tracker,
		'action' => isset($action) ? $action : '',
		'feedback' => isset($_REQUEST['feedback']) ? $_REQUEST['feedback'] : (isset($feedback) ? $feedback : ''),
		'title' => $Lang->getText('TrackerItem.BrowsePageTitle')
		);
$theme->header($params);

/* There are 3 ways of retrieving the tracker items:
 * 1) Running a query
 * 2) "Remembering" the last query used,
 * 3) Using the "Quick query" menu.
 * 
 * The logic goes like this: if a query is run, rememer the query_id and the current page so the
 * user can come back to the same page if he, for example, adds a new tracker item.
 * If a quick query is run, forget the query_id and remember the parameters of the quick query instead.
 */

// Saved query logic
$preference_name = 'trkquery'.$Tracker->getTrackerId();
if ($session->isLoggedIn()) {
	$user = $session->getUser();
	if (!isset($_POST['quickquery']) && !isset($_GET['tracker_query_id']) && !isset($_GET['forget_query'])) {
		$saved_query = $user->getPreference($preference_name);
		if ($saved_query) {
			// Emulate a query using the saved query information
			$saved_query = unserialize($saved_query);
			$_REQUEST['tracker_query_id'] = $_GET['tracker_query_id'] = $saved_query['tracker_query_id'];
			$_REQUEST['show'] = $_GET['show'] = $saved_query['show'];
			$_REQUEST['start'] = $_GET['start'] = $saved_query['start'];
		}
	} else {
		// If using quick query, delete the saved query ID
		$user->deletePreference($preference_name);
	}
}

if (isset($_GET['tracker_query_id'])) {
	if (!$session->isLoggedIn()) {
		throw new PermissionDeniedException();
	}
	$tracker_query_id = Validator::sanitizeInt($_GET['tracker_query_id']);
	$tsq = TrackerQueryPeer::retrieveByPk($tracker_query_id);
	if (!$tsq) {
		// The query got deleted for some reason
		$tq = new TrackerItemQuickQuery($Tracker);
	} elseif (!$tsq->getIsShared() && $tsq->getUserId() != $session->getUser()->getUserId()) {
		throw new PermissionDeniedException();
	} else {
		$tq = new TrackerItemSavedQuery($Tracker,$tsq);
	}
} else {
	$tq = new TrackerItemQuickQuery($Tracker);
}

//
//	build the query
//
$show=((isset($_REQUEST['show'])) ? intval($_REQUEST['show']) : 25 );
if (!isset($_GET['start'])) {
	$start=0;
} else {
	$start=$_GET['start'];
}
$totalcount=$tq->getTrackerItemCount();
$arr=$tq->getTrackerItems($show,$start);

// Save the tracker_query info, if any
if (isset($_GET['tracker_query_id']) && $session->isLoggedIn()) {
	$saved_query = array('tracker_query_id' => $_GET['tracker_query_id'], 'show' => $show, 'start' => $start);
	$session->getUser()->setPreference($preference_name, serialize($saved_query));
}

//
//	Show the quick-browse pop-ups
//
echo '<form action="'.GFUrl::getUrl()->currentBaseUrl('TrackerItemBrowse').'&amp;tracker_id='.$Tracker->getTrackerId().'" method="post">
		<input type="hidden" name="quickquery" value="1" /><table width="50%"><tr>';
echo '<td><strong>'.$Lang->getText('TrackerItem.TrackerItemIdName').'</strong><br /><input type="text" name="tracker_item_id" value="'.$tq->getTrackerItemId().'" size="4" maxlength="8" /></td>';
echo '<td><strong>'.$Lang->getText('TrackerItem.SummaryName').'</strong><br /><input type="text" name="summary" value="'.$tq->getSummary().'" size="10" maxlength="40" /></td>';
$tefr = new TrackerExtraFieldRenderer($Tracker);
echo $tefr->renderFields('QUICKBROWSE',null,$tq);
echo '<td><strong>'.$Lang->getText('Tracker.SortCol').'</strong><br />'.HTMLWidget::selectBoxFromAssoc($tq->getAvailableSortColumns(),'sortcol',$tq->getSortCol(),false,false).'</td>';
echo '<td><strong>'.$Lang->getText('Tracker.SortOrd').'</strong><br />'.HTMLWidget::selectBoxFromAssoc($tq->getAvailableSortOrd(),'sortord',$tq->getSortOrd(),false,false).'</td>';
echo '<td>'.HTMLWidget::button("submit",$Lang->getText('Common.Browse'),"browse","","").'</td></tr></table></form>';

//show a list of saved queries
if ($session->isLoggedIn()) {
	// Retrieve the objects array
	$crit = new Criteria();
	$cton1=$crit->getNewCriterion(TrackerQueryPeer::USER_ID, $session->getUser()->getID());
	$cton2=$crit->getNewCriterion(TrackerQueryPeer::IS_SHARED, true);
	$cton1->addOr($cton2);
	$crit->add($cton1);
	$queries = $Tracker->getTrackerQuerys($crit);

	echo '<br /><form name="querynavform" action="">
	<select name="querynav" onchange="location.href=document.querynavform.querynav.value">
	<option value="'.GFUrl::getUrl()->currentBaseUrl('TrackerItemBrowse', array('tracker_id' => $Tracker->getTrackerId(), 'forget_query' => 1)).'">'.$Lang->getText('Tracker.Filter').'</option>
	<option value="'.GFUrl::getUrl()->currentBaseUrl('TrackerQueryAdd').'&amp;tracker_id='.$Tracker->getTrackerId().'">'.$Lang->getText('Tracker.FilterAdd').'</option>'."\n";
	$url=GFUrl::getUrl()->currentBaseUrl('TrackerItemBrowse').'&amp;tracker_id='.$Tracker->getTrackerId().'&amp;tracker_query_id=';
	
	foreach ($queries as $query) {
		echo '	<option value="'.$url.$query->getTrackerQueryId().'" '.((isset($_REQUEST['tracker_query_id']) && $_REQUEST['tracker_query_id']==$query->getTrackerQueryId()) ? 'selected="selected"': '').'>'.$query->getQueryName().'</option>'."\n";
	}
	
	echo '	</select>
		</form><br />
	';

}

$IS_ADMIN=$Tracker->userIsAdmin();
$IS_TASK=$Tracker->getDatatype()==Tracker::DATATYPE_TASK;

//
//	Show the browse instructions. 
//
if (strlen($Tracker->getBrowseInstructions()) > 0) {
	echo "<br><strong>".$Tracker->getBrowseInstructions()."</strong><br>";
}

//
//	Show the list of items that match the query.
//

	$theader = array();

	$theader[] = $Lang->getText('TrackerItem.TrackerItemIdName');
	$theader[] = $Lang->getText('TrackerItem.SummaryName');
	if ($IS_ADMIN)
		$theader[] = $Lang->getText('Delete');
//	$theader[] = $Lang->getText('TrackerItem.StatusIdName');
	if ($tq->showColumn('priority'))
		$theader[] = $Lang->getText('TrackerItem.PriorityName');
	if ($tq->showColumn('assigned_to'))
		$theader[] = $Lang->getText('TrackerItem.AssignedTo');
	if ($tq->showColumn('submitted_by'))
		$theader[] = $Lang->getText('TrackerItem.SubmittedByName');
	$efs=$Tracker->getTrackerExtraFields();
	foreach ($efs as $ef) {
		$efcache[$ef->getTrackerExtraFieldId()]=$ef;
		if ($ef->getUseInQuickBrowse()) {
			$theader[] = $ef->getFieldName();
		}
	}
	if ($tq->showColumn('open_date'))
		$theader[] = $Lang->getText('TrackerItem.OpenDateName');
	if ($tq->showColumn('close_date'))
		$theader[] = $Lang->getText('TrackerItem.CloseDateName');
	if ($tq->showColumn('last_modified_date'))
		$theader[] = $Lang->getText('TrackerItem.LastModifiedDateName');

	echo '<form action="'.GFUrl::getUrl()->currentBaseUrl('TrackerItemMassUpdateAction').'&amp;tracker_id='.$Tracker->getTrackerId().'" method="post">';
//echo "theader count: ".count($theader);
	echo $theme->tableTop($theader);


//	$max = (($totalcount > ($start + $show)) ? ($start+$show) : $totalcount );
//echo "max: $max";
if (count($arr) == 0 ) {
	echo $theme->tableFullRow($Lang->getText('TrackerItem.NoneFound'));
} else {
	$editurl=GFUrl::getUrl()->currentBaseUrl('TrackerItemEdit');
	$deleteurl=GFUrl::getUrl()->currentBaseUrl('TrackerItemDelete');
	for ($i=0; $i<count($arr); $i++) {
		$trow = array();
		$tmod = array();
		$trow[]=(($IS_ADMIN) ? '<input type="checkbox" name="tid[]" value="'.$arr[$i]->getTrackerItemId().'" />' : '' ).' '.$arr[$i]->getTrackerItemId();
		$tmod[]='';
		
		// Text that will be used on the tooltip
		$tooltip = StringUtils::trimString($arr[$i]->getDetails(), 500);
		$tooltip = StringUtils::generateTooltip($tooltip);
		
		$trow[]='<a href="'. $editurl .'&amp;tracker_item_id='.$arr[$i]->getTrackerItemID() .'&amp;start='. $start .'" onmouseover="tooltip(\''.$tooltip.'\');" onmouseout="tooltipexit()">'. $arr[$i]->getSummary().'</a>';
		$tmod[]='';
		if ($IS_ADMIN) {
			$trow[]='<a href="'. $deleteurl .'&amp;tracker_item_id='.$arr[$i]->getTrackerItemID() .'">'. $Lang->getText('Delete').'</a>';
			$tmod[]='';
		}
//		$trow[]=$arr[$i]->getStatusId();;
		if ($tq->showColumn('priority')) {
			$trow[]=$arr[$i]->getPriority();
			$tmod[]='bgcolor="'.$theme->getPriorityColor($arr[$i]->getPriority()).'"';
		}
		if ($tq->showColumn('assigned_to')) {
			$asses = $arr[$i]->getTrackerItemAssignees();
			$assignees = '';
			foreach ($asses as $ass) {
				$assignees .= $ass->getUser()->getUserLink().'<br />';
			}
			$trow[]=$assignees;
			$tmod[]='';
			unset($assignees);
		}
		if ($tq->showColumn('submitted_by')) {
			$trow[]=UserPeer::retrieveByPk($arr[$i]->getSubmittedBy())->getUserLink();
			$tmod[]='';
		}
		$colarray=array();
		$efdatas=$arr[$i]->getTrackerExtraFieldDatas();

		foreach($efdatas as $efdata) {
			if (is_object($efcache[$efdata->getTrackerExtraFieldId()])) {
				$colarray[$efdata->getTrackerExtraFieldId()][]=$efcache[$efdata->getTrackerExtraFieldId()]->translateFieldDataToName($efdata->getFieldData());
			}
		}
		reset($efs);
		foreach ($efs as $ef) {
			if ($ef->getUseInQuickBrowse()) {
				if (isset($colarray[$ef->getTrackerExtraFieldId()]) && count($colarray[$ef->getTrackerExtraFieldId()]) > 1) {
					$trow[] = implode('<br />',$colarray[$ef->getTrackerExtraFieldId()]);
					$tmod[]='';
				} else {
					if (isset($colarray[$ef->getTrackerExtraFieldId()])) {
						if($ef->getFieldType() == TrackerExtraField::TYPE_DATE){
							if ($colarray[$ef->getTrackerExtraFieldId()][0] != "") {
								$dt = date('Y-m-d',  strtotime($colarray[$ef->getTrackerExtraFieldId()][0]));
								$trow[] = $dt;
							} else {
								$trow[] = '--';
							}
						} else {
							$trow[] =  $colarray[$ef->getTrackerExtraFieldId()][0];
						}
							$tmod[]='';
					} else {
						$trow[] = '--';
						$tmod[]='';
					}
				}
			}
		}
		if ($tq->showColumn('open_date')) {
			$trow[]=$arr[$i]->getOpenDate('Y-m-d');
			$tmod[]='';
		}
		if ($tq->showColumn('close_date')) {
			$trow[]=(($arr[$i]->getStatusId()==Tracker::STATUS_CLOSED || $IS_TASK) ? $arr[$i]->getCloseDate('Y-m-d') : '&nbsp;');
			$tmod[]='';
		}
		if ($tq->showColumn('last_modified_date')) {
			$trow[]=$arr[$i]->getLastModifiedDate('Y-m-d');
			$tmod[]='';
		}

//echo "trow count: ".count($trow);
		echo $theme->tableRow($trow,$tmod,false);
		unset($trow);
		unset($tmod);
	}
}

if ($Tracker->userCanRead() && Session::getSession()->isLoggedIn()) {
	$button_enabled = true;
} else {
	$button_enabled = false;
}

echo $theme->tableBottom(array(GFUrl::getUrl()->currentBaseUrl('TrackerItemAdd').'&amp;tracker_id='.$Tracker->getTrackerId()=>$Lang->getText('TrackerItem.AddNew')),array($button_enabled));

	//
	//	Pagination code
	//
	$pages = $totalcount / $show;
	$currentpage = intval($start / $show);
	$skipped_pages=false;
	for ($j=0; $j<$pages; $j++) {
		if ($pages > 20) {
			if ((($j > 4) && ($j < ($currentpage-5))) || (($j > ($currentpage+5)) && ($j < ($pages-5)))) {
				if (!$skipped_pages) {
					$skipped_pages=true;
					echo "....&nbsp;";
				}
				continue;
			} else {
				$skipped_pages=false;
			}
		}
		if ($j == $currentpage) {
			echo '<strong>'.($j+1).'</strong>&nbsp;';
		} else {
			if (isset($_GET['tracker_query_id'])) {
				echo '<a href="'.GFUrl::getUrl()->currentBaseUrl('TrackerItemBrowse').'&amp;tracker_id='.$Tracker->getTrackerId().'&amp;tracker_query_id='.$tracker_query_id.'&amp;start='.($j*$show).'">'.($j+1).'</a>&nbsp;';
			} else {
				echo '<a href="'.GFUrl::getUrl()->currentBaseUrl('TrackerItemBrowse').'&amp;tracker_id='.$Tracker->getTrackerId().'&amp;start='.($j*$show).'">'.($j+1).'</a>&nbsp;';
			}
		}
	}

	//
	//	Mass update code
	//
if ($IS_ADMIN) {
	echo '<table width="100%" style="clear:left;">';
	$tefr = new TrackerExtraFieldRenderer($Tracker);
	echo $tefr->renderFields('MASSUPDATE');
	echo '<tr><td>'.HTMLWidget::button("submit",$Lang->getText('Tracker.MassUpdate'),"browse","","").'</td></tr></table></form>';
}
$theme->footer($params);
?>
