<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code shows a form for editing TrackerItemMessage
//
require_once('plugins/tracker/lib/TrackerItemScmCommit.php');
require_once('plugins/tracker/lib/TrackerItemScmCommitPeer.php');
require_once('plugins/scm/lib/ScmCommitFile.php');
require_once('plugins/scm/lib/RepositoryBrowser.php');
require_once('plugins/scm/lib/SCMRepositoryFactory.php');

$project = GFUrl::getUrl()->getProject();
$repository = SCMRepositoryFactory::getRepository($project);

if (!is_null($repository)) {		// Project doesn't have a repository
	try {
		$browser = new RepositoryBrowser($repository); 
	} catch (Exception $e) {
		// SCM other than CVS or SVN
		$browser = null;
	}
	$arr = $TrackerItem->getTrackerItemScmCommitsJoinScmCommit();
} else {
	$arr = array();		// No commits if there isn't a repository
}



$theader = array();
$theader[] = $Lang->getText('TrackerItemScmCommit.ModifiedFile');
$theader[] = $Lang->getText('TrackerItemScmCommit.CommitDate');
$theader[] = $Lang->getText('TrackerItemScmCommit.PreviousVersion');
$theader[] = $Lang->getText('TrackerItemScmCommit.NewVersion');
$theader[] = $Lang->getText('TrackerItemScmCommit.MessageLog');	
$theader[] = $Lang->getText('TrackerItemScmCommit.SubmittedByName');	

echo $theme->tableTop($theader);

if (count($arr) < 1) {
	echo $theme->tableFullRow($Lang->getText('TrackerItemScmCommit.NoneFound'));
} else {
	foreach ($arr as $item) {		
		$c = new Criteria();
		$c->add(ScmCommitFilePeer::SCM_COMMIT_ID, $item->getScmCommit()->getScmCommitId());
		$files = ScmCommitFilePeer::doSelectJoinScmCommit($c); 
		
		
		foreach ($files as $file) {
			$prevVersion = $file->getPrevVersion();
			$newVersion = $file->getNewVersion();

			$trow = array();
			if (!is_null($browser)) {
				$trow[] = '<a href="'.$browser->getBrowsePathUrl($file).'">'.$file->getModifiedFile().'</a>';
			} else {
				$trow[] = $file->getModifiedFile();
			}
			$trow[] = $item->getScmCommit()->getCommitDate();

			if (strtolower($newVersion) == 'none' || empty($newVersion)) {
				// This happens when the file is deleted. In that case, we don't have a diff.
				$trow[] = $prevVersion;
			} elseif ($prevVersion == 'none' || empty($prevVersion)) {
				$trow[] = '';
			} else {
				if (!is_null($browser)) {
					// Show diff link
					$trow[] = '<a href="'.$browser->getDiffUrl($file->getModifiedFile(), $prevVersion, $newVersion).'">'.$Lang->getText('TrackerItemScmCommit.DiffTo').' '.$prevVersion.'</a>';
				} else {
					$trow[] = $prevVersion;
				}
			}
			$trow[] = $file->getNewVersion();
			$log = $item->getScmCommit()->getMessageLog();
			// Log is trimmed because CVS import logs may be huge
			$trow[] = StringUtils::trimString($log, 256);
			
			$user = $item->getScmCommit()->getUser();
			if ($user->isUndefinedUser()) {
				$trow[] = $Lang->getText('Common.UnknownUser');
			} else {
				$trow[] = $user->getUserLink();			
			}
			echo $theme->tableRow($trow);
		}
	}
}
echo $theme->tableBottom();

?>
