<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code edits a TrackerExtraField and saves it to the 
// database
//
require_once('plugins/tracker/lib/TrackerExtraField.php');
require_once('Validator.php');
require_once('exceptions/PermissionDeniedException.php');
require_once('core/Language.php');

if ($_SERVER['REQUEST_METHOD'] != 'POST') {
	throw new PermissionDeniedException();
}

$TrackerExtraField = TrackerExtraFieldPeer::retrieveByPk($_POST['tracker_extra_field_id']);
$Tracker = $TrackerExtraField->getTracker();
if (!is_object($Tracker) || !$Tracker->userIsAdmin()) {
	throw new PermissionDeniedException();
}

$errors = array();
$language = Language::getSessLang();

//
// TODO Validate the values passed by $_POST. Store the errors in $error like
// $errors["field_name"] = error_description
//

if (count($errors) == 0) {
	$type = $TrackerExtraField->getFieldType();
	
	if ($type == TrackerExtraField::TYPE_TEXT) {
		$attribute1 = (isset($_POST['attribute1']) && !empty($_POST['attribute1'])) ? Validator::sanitizeInt($_POST['attribute1']) : 50;
		$attribute2 = (isset($_POST['attribute2']) && !empty($_POST['attribute2'])) ? Validator::sanitizeInt($_POST['attribute2']) : 50;
		$default_value = (isset($_POST['default_value']) ? Validator::sanitizeString($_POST['default_value']) : '');
	} elseif ($type == TrackerExtraField::TYPE_TEXTAREA) {
		$attribute1 = (isset($_POST['attribute1']) && !empty($_POST['attribute1'])) ? Validator::sanitizeInt($_POST['attribute1']) : 5;
		$attribute2 = (isset($_POST['attribute2']) && !empty($_POST['attribute2'])) ? Validator::sanitizeInt($_POST['attribute2']) : 40;
	} elseif ($type == TrackerExtraField::TYPE_NUMERIC) {
		$default_value = (isset($_POST['default_value']) && is_numeric($_POST['default_value'])) ? Validator::sanitizeString($_POST['default_value']) : '';
		$attribute1 = (isset($_POST['attribute1'])) ? Validator::sanitizeInt($_POST['attribute1']) : 0;
		$attribute2 = (isset($_POST['attribute2'])) ? Validator::sanitizeInt($_POST['attribute2']) : 0;
	} else {
		$attribute1 = (isset($_POST['attribute1'])) ? Validator::sanitizeInt($_POST['attribute1']) : 0;
		$attribute2 = (isset($_POST['attribute2'])) ? Validator::sanitizeInt($_POST['attribute2']) : 0;
		$default_value = '';
	}
	
	$TrackerExtraField->setFieldName( Validator::sanitizeString($_POST['field_name']) );
	$TrackerExtraField->setAttribute1($attribute1);
	$TrackerExtraField->setAttribute2($attribute2);
	$TrackerExtraField->setIsRequired( isset($_POST['is_required']) ? 1 : 0 );
	//$TrackerExtraField->setAlias( Validator::sanitizeString($_POST['alias']) );
	$TrackerExtraField->setFieldOrder( Validator::sanitizeInt($_POST['field_order']) );
	$TrackerExtraField->setUseInQuickBrowse( isset($_POST['use_in_quick_browse']) ? 1 : 0 );
	$TrackerExtraField->setShowOnSubmit( isset($_POST['show_on_submit']) ? 1 : 0 );
	$TrackerExtraField->setDefaultValue($default_value);
	
	try {	
		$TrackerExtraField->save();
		GFUrl::getUrl()->redirect(GFUrl::getUrl()->currentBaseURL('TrackerExtraFieldBrowse'), array('feedback' => $language->getText('TrackerExtraField.EditFeedback'),'tracker_id'=>$Tracker->getTrackerId()));
	} catch (InvalidDataException $ex) {
		$errors = array_merge($errors, $ex->getErrors());               // attach object errors to validation errors
		$feedback = implode('<br />', $errors);
		include('TrackerExtraFieldEdit.php');
	}
} else {
	$feedback = implode('<br />', $errors);
	include('TrackerExtraFieldEdit.php');
}

?>
