<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Ruben Gutierrez	ruben@gforgegroup.com
 * @date 2006-03-16
 *
 * SOAP plugin for GForge5.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */


require_once('plugins/xmlcompatibility/lib/soap/common/GroupTypes.php');
require_once('plugins/scm/lib/ProjectScmPeer.php');
require_once('lib/core/ProjectPeer.php');

//getGroups (id array)
$server->register(
    'getGroups',
    array(
    	'session_ser'=>'xsd:string',
    	'group_ids'=>'tns:ArrayOfint'
    ),
    array(
    	'return'=>'tns:ArrayOfGroup'
    ),
    $uri,
    $uri.'#getGroups','rpc','encoded'
);

//getGroupsByName (unix_name array)
$server->register(
    'getGroupsByName',
    array(
    	'session_ser'=>'xsd:string',
    	'group_names'=>'tns:ArrayOfstring'
    ),
    array(
    	'return'=>'tns:ArrayOfGroup'
    ),
    $uri,
    $uri.'#getGroupsByName','rpc','encoded'
);

//getPublicProjectNames ()
$server->register(
    'getPublicProjectNames',
    array(
    	'session_ser'=>'xsd:string'
    ),
    array(
    	'return'=>'tns:ArrayOfstring'
    ),
    $uri,
    $uri.'#getPublicProjectNames','rpc','encoded'
);

function getGroups($session_ser, $group_ids) {
	try {
		$session = continueSession($session_ser);
		$projects = array();
		
		for ($i=0; $i<count($group_ids); $i++) {
			$projectId = $group_ids[$i];
			$project = ProjectPeer::retrieveByPk($projectId);
			if ($project != null) {
				$projects[] = $project;
			}
		}
		return projectsToSoap($projects);
	} catch (Exception $ex) {
		return new soap_fault('2001', 'group', 'Could Not Get Groups by Id', $ex->getMessage());
	}
}

// Apparently, not needed
function getGroupsByName($session_ser, $group_names) {
	try {
		$session = continueSession($session_ser);
		$projects = array();
		
		for ($i=0; $i<count($group_names); $i++) {
			$projectName = $group_names[$i];
			$project = ProjectPeer::retrieveByUnixName($projectName);
			if ($project != null) {
				$projects[] = $project;
			}
		}
		return projectsToSoap($projects);
	} catch (Exception $ex) {
		return new soap_fault('2002', 'group', 'Could Not Get Groups by Name', $ex->getMessage());
	}
}

// Apparently, not needed
function getPublicProjectNames($session_ser) {
	try {
		$session = continueSession($session_ser);
		$c = new Criteria();
		$c->add(ProjectPeer::IS_PUBLIC, true);
		$projects = ProjectPeer::doSelect($c);
		$project_names = array();
	
		for ($i=0;$i<count($projects);$i++) {
			$project_names[] = $projects[$i]->getUnixName();
		}
		return $project_names;	
	} catch (Exception $ex) {
		return new soap_fault('2003', 'group', 'Could Not Get Public Group Names', $ex->getMessage());
	}
}


/*
	Converts an array of Group objects to soap data
*/
function projectsToSoap($projects) {
	$return = array();

	foreach ($projects as $project) {
		if (get_class($project) == 'UserProject') {
			$project = $project->getProject();
		}
		$project_scm = ProjectScmPeer::retrieveByPk($project->getId());
		if ($project_scm && is_object($project_scm)) {
			$scm_box = $project_scm->getHostname();
		} else {
			$scm_box = '';
		}
		//build an array of just the fields we want
		$return[] = array(
			'group_id'=>$project->getId(), 
			'group_name'=>$project->getName(),
			'homepage'=>$project->getHomepageUrl(),
			'is_public'=>($project->isPublic()==1) ? '1' : '0',
			'status'=>getOldProjectStatus($project->getStatus()),
			'unix_group_name'=>$project->getUnixName(),
			'short_description'=>$project->getDescription(),
			'scm_box'=>$scm_box,
			'register_time'=>$project->getCreateDate(null)
		);
	}
	return $return;
}

function getOldProjectStatus($status) {
	if ($status == 0) {
		return "P";
	}
	else if ($status == 1) {
		return "A";
	}
	else {
		return "S";
	}
	
}
?>
